<?php
/************************************************************************/
/* This software is made available under the Living Stones Software     */
/* License Agreement available here:                                    */
/* http://www.lstones.com/Living-Stones-Software-License-Agreement.html */
/************************************************************************/
/* Living Stones Bible Functions                                        */
/*                                                                      */
/*----------------------------------------------------------------------*/
/* Bible functions - enables browsing and searching the bible           */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* check_booknames() - identifies a Bible book name in the passed string*/
/*                                                                      */
/* parse_reference() - parse out # or #:# or Book # or Book #:#         */
/*                                                                      */
/* parse_refstring() - parse out ref or ref-ref                         */
/*                                                                      */
/* display_passage() - prints out the requested passage                 */
/*                                                                      */
/* display_search() - prints out results from searching the Bible       */
/*                                                                      */
/************************************************************************/


/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function check_booknames                                             */
/*                                                                      */
/* Looks at the beginning of the string passed in for a Bible book name.*/
/* The passed in string should have all spaces stripped out.            */
/*                                                                      */
/* Returns an array with two elements:                                  */
/*   ['num'] will contain the book number 1=Genesis 66=Revelations      */
/*   ['len'] will contain the length of the found book name -           */
/*                  this allows the calling software to move to the end */
/*                  of the bookname in the passed in string for further */
/*                  parsing.                                            */
/*                                                                      */
/*----------------------------------------------------------------------*/
function check_booknames($ref)
	{

	/* assumes no spaces */
	$book['num'] = 0;
	$book['len'] = 0;

	/* take case out of it */
	$ref = strtolower($ref);

	if(!strncmp($ref,"genesis",strlen("genesis"))) 
		{$book['num']=1;$book['len']=strlen("genesis");return $book;}
	if(!strncmp($ref,"genesi",strlen("genesi"))) 
		{$book['num']=1;$book['len']=strlen("genesi");return $book;}
	if(!strncmp($ref,"genes",strlen("genes"))) 
		{$book['num']=1;$book['len']=strlen("genes");return $book;}
	if(!strncmp($ref,"gene",strlen("gene"))) 
		{$book['num']=1;$book['len']=strlen("gene");return $book;}
	if(!strncmp($ref,"gen",strlen("gen"))) 
		{$book['num']=1;$book['len']=strlen("gen");return $book;}
	if(!strncmp($ref,"ge",strlen("ge"))) 
		{$book['num']=1;$book['len']=strlen("ge");return $book;}
	if(!strncmp($ref,"gn",strlen("gn"))) 
		{$book['num']=1;$book['len']=strlen("gn");return $book;}

	if(!strncmp($ref,"exodus",strlen("exodus"))) 
		{$book['num']=2;$book['len']=strlen("exodus");return $book;}
	if(!strncmp($ref,"exudus",strlen("exudus"))) 
		{$book['num']=2;$book['len']=strlen("exudus");return $book;}
	if(!strncmp($ref,"exodu",strlen("exodu"))) 
		{$book['num']=2;$book['len']=strlen("exodu");return $book;}
	if(!strncmp($ref,"exod",strlen("exod"))) 
		{$book['num']=2;$book['len']=strlen("exod");return $book;}
	if(!strncmp($ref,"exo",strlen("exo"))) 
		{$book['num']=2;$book['len']=strlen("exo");return $book;}
	if(!strncmp($ref,"ex",strlen("ex"))) 
		{$book['num']=2;$book['len']=strlen("ex");return $book;}

	if(!strncmp($ref,"leviticus",strlen("leviticus"))) 
		{$book['num']=3;$book['len']=strlen("leviticus");return $book;}
	if(!strncmp($ref,"levitacus",strlen("levitacus"))) 
		{$book['num']=3;$book['len']=strlen("levitacus");return $book;}
	if(!strncmp($ref,"leviticu",strlen("leviticu"))) 
		{$book['num']=3;$book['len']=strlen("leviticu");return $book;}
	if(!strncmp($ref,"levitic",strlen("levitic"))) 
		{$book['num']=3;$book['len']=strlen("levitic");return $book;}
	if(!strncmp($ref,"leviti",strlen("leviti"))) 
		{$book['num']=3;$book['len']=strlen("leviti");return $book;}
	if(!strncmp($ref,"levit",strlen("levit"))) 
		{$book['num']=3;$book['len']=strlen("levit");return $book;}
	if(!strncmp($ref,"levi",strlen("levi"))) 
		{$book['num']=3;$book['len']=strlen("levi");return $book;}
	if(!strncmp($ref,"lev",strlen("lev"))) 
		{$book['num']=3;$book['len']=strlen("lev");return $book;}
	if(!strncmp($ref,"le",strlen("le"))) 
		{$book['num']=3;$book['len']=strlen("le");return $book;}
	if(!strncmp($ref,"lv",strlen("lv"))) 
		{$book['num']=3;$book['len']=strlen("lv");return $book;}

	if(!strncmp($ref,"numbers",strlen("numbers"))) 
		{$book['num']=4;$book['len']=strlen("numbers");return $book;}
	if(!strncmp($ref,"number",strlen("number"))) 
		{$book['num']=4;$book['len']=strlen("number");return $book;}
	if(!strncmp($ref,"numbe",strlen("numbe"))) 
		{$book['num']=4;$book['len']=strlen("numbe");return $book;}
	if(!strncmp($ref,"numb",strlen("numb"))) 
		{$book['num']=4;$book['len']=strlen("numb");return $book;}
	if(!strncmp($ref,"num",strlen("num"))) 
		{$book['num']=4;$book['len']=strlen("num");return $book;}
	if(!strncmp($ref,"nu",strlen("nu"))) 
		{$book['num']=4;$book['len']=strlen("nu");return $book;}

	if(!strncmp($ref,"deuteronomy",strlen("deuteronomy"))) 
		{$book['num']=5;$book['len']=strlen("deuteronomy");return $book;}
	if(!strncmp($ref,"dueteronomy",strlen("dueteronomy"))) 
		{$book['num']=5;$book['len']=strlen("dueteronomy");return $book;}
	if(!strncmp($ref,"duteronomy",strlen("duteronomy"))) 
		{$book['num']=5;$book['len']=strlen("duteronomy");return $book;}
	if(!strncmp($ref,"deuteronom",strlen("deuteronom"))) 
		{$book['num']=5;$book['len']=strlen("deuteronom");return $book;}
	if(!strncmp($ref,"deuterono",strlen("deuterono"))) 
		{$book['num']=5;$book['len']=strlen("deuterono");return $book;}
	if(!strncmp($ref,"deuteron",strlen("deuteron"))) 
		{$book['num']=5;$book['len']=strlen("deuteron");return $book;}
	if(!strncmp($ref,"deutero",strlen("deutero"))) 
		{$book['num']=5;$book['len']=strlen("deutero");return $book;}
	if(!strncmp($ref,"deuter",strlen("deuter"))) 
		{$book['num']=5;$book['len']=strlen("deuter");return $book;}
	if(!strncmp($ref,"deute",strlen("deute"))) 
		{$book['num']=5;$book['len']=strlen("deute");return $book;}
	if(!strncmp($ref,"deut",strlen("deut"))) 
		{$book['num']=5;$book['len']=strlen("deut");return $book;}
	if(!strncmp($ref,"deu",strlen("deu"))) 
		{$book['num']=5;$book['len']=strlen("deu");return $book;}
	if(!strncmp($ref,"de",strlen("de"))) 
		{$book['num']=5;$book['len']=strlen("de");return $book;}
	if(!strncmp($ref,"dt",strlen("dt"))) 
		{$book['num']=5;$book['len']=strlen("dt");return $book;}

	if(!strncmp($ref,"joshua",strlen("joshua"))) 
		{$book['num']=6;$book['len']=strlen("joshua");return $book;}
	if(!strncmp($ref,"joshu",strlen("joshu"))) 
		{$book['num']=6;$book['len']=strlen("joshu");return $book;}
	if(!strncmp($ref,"josh",strlen("josh"))) 
		{$book['num']=6;$book['len']=strlen("josh");return $book;}
	if(!strncmp($ref,"jos",strlen("jos"))) 
		{$book['num']=6;$book['len']=strlen("jos");return $book;}

	if(!strncmp($ref,"judges",strlen("judges"))) 
		{$book['num']=7;$book['len']=strlen("judges");return $book;}
	if(!strncmp($ref,"judge",strlen("judge"))) 
		{$book['num']=7;$book['len']=strlen("judge");return $book;}
	if(!strncmp($ref,"judg",strlen("judg"))) 
		{$book['num']=7;$book['len']=strlen("judg");return $book;}
	if(!strncmp($ref,"jdg",strlen("jdg"))) 
		{$book['num']=7;$book['len']=strlen("jdg");return $book;}

	if(!strncmp($ref,"ruth",strlen("ruth"))) 
		{$book['num']=8;$book['len']=strlen("ruth");return $book;}
	if(!strncmp($ref,"rth",strlen("rth"))) 
		{$book['num']=8;$book['len']=strlen("rth");return $book;}
	if(!strncmp($ref,"ruh",strlen("ruh"))) 
		{$book['num']=8;$book['len']=strlen("ruh");return $book;}
	if(!strncmp($ref,"rut",strlen("rut"))) 
		{$book['num']=8;$book['len']=strlen("rut");return $book;}
	if(!strncmp($ref,"ru",strlen("ru"))) 
		{$book['num']=8;$book['len']=strlen("ru");return $book;}

	if(!strncmp($ref,"firstsamuel",strlen("firstsamuel"))) 
		{$book['num']=9;$book['len']=strlen("firstsamuel");return $book;}
	if(!strncmp($ref,"1samuel",strlen("1samuel"))) 
		{$book['num']=9;$book['len']=strlen("1samuel");return $book;}
	if(!strncmp($ref,"1samue",strlen("1samue"))) 
		{$book['num']=9;$book['len']=strlen("1samue");return $book;}
	if(!strncmp($ref,"1samu",strlen("1samu"))) 
		{$book['num']=9;$book['len']=strlen("1samu");return $book;}
	if(!strncmp($ref,"1sam",strlen("1sam"))) 
		{$book['num']=9;$book['len']=strlen("1sam");return $book;}
	if(!strncmp($ref,"1sa",strlen("1sa"))) 
		{$book['num']=9;$book['len']=strlen("1sa");return $book;}
	if(!strncmp($ref,"1sm",strlen("1sm"))) 
		{$book['num']=9;$book['len']=strlen("1sm");return $book;}
	if(!strncmp($ref,"isamuel",strlen("isamuel"))) 
		{$book['num']=9;$book['len']=strlen("isamuel");return $book;}
	if(!strncmp($ref,"isamue",strlen("isamue"))) 
		{$book['num']=9;$book['len']=strlen("isamue");return $book;}
	if(!strncmp($ref,"isamu",strlen("isamu"))) 
		{$book['num']=9;$book['len']=strlen("isamu");return $book;}
	if(!strncmp($ref,"isam",strlen("isam"))) 
		{$book['num']=9;$book['len']=strlen("isam");return $book;}
	if(!strncmp($ref,"ism",strlen("ism"))) 
		{$book['num']=9;$book['len']=strlen("ism");return $book;}
	if(!strncmp($ref,"samuel",strlen("samuel"))) 
		{$book['num']=9;$book['len']=strlen("samuel");return $book;}

	if(!strncmp($ref,"secondsamuel",strlen("secondsamuel"))) 
		{$book['num']=10;$book['len']=strlen("secondsamuel");return $book;}
	if(!strncmp($ref,"2samuel",strlen("2samuel"))) 
		{$book['num']=10;$book['len']=strlen("2samuel");return $book;}
	if(!strncmp($ref,"2samue",strlen("2samue"))) 
		{$book['num']=10;$book['len']=strlen("2samue");return $book;}
	if(!strncmp($ref,"2samu",strlen("2samu"))) 
		{$book['num']=10;$book['len']=strlen("2samu");return $book;}
	if(!strncmp($ref,"2sam",strlen("2sam"))) 
		{$book['num']=10;$book['len']=strlen("2sam");return $book;}
	if(!strncmp($ref,"2sa",strlen("2sa"))) 
		{$book['num']=10;$book['len']=strlen("2sa");return $book;}
	if(!strncmp($ref,"2sm",strlen("2sm"))) 
		{$book['num']=10;$book['len']=strlen("2sm");return $book;}
	if(!strncmp($ref,"iisamuel",strlen("iisamuel"))) 
		{$book['num']=10;$book['len']=strlen("iisamuel");return $book;}
	if(!strncmp($ref,"iisamue",strlen("iisamue"))) 
		{$book['num']=10;$book['len']=strlen("iisamue");return $book;}
	if(!strncmp($ref,"iisamu",strlen("iisamu"))) 
		{$book['num']=10;$book['len']=strlen("iisamu");return $book;}
	if(!strncmp($ref,"iisam",strlen("iisam"))) 
		{$book['num']=10;$book['len']=strlen("iisam");return $book;}
	if(!strncmp($ref,"iisa",strlen("iisa"))) 
		{$book['num']=10;$book['len']=strlen("iisa");return $book;}
	if(!strncmp($ref,"iism",strlen("iism"))) 
		{$book['num']=10;$book['len']=strlen("iism");return $book;}

	if(!strncmp($ref,"firstkings",strlen("firstkings"))) 
		{$book['num']=11;$book['len']=strlen("firstkings");return $book;}
	if(!strncmp($ref,"1kings",strlen("1kings"))) 
		{$book['num']=11;$book['len']=strlen("1kings");return $book;}
	if(!strncmp($ref,"1king",strlen("1king"))) 
		{$book['num']=11;$book['len']=strlen("1king");return $book;}
	if(!strncmp($ref,"1kin",strlen("1kin"))) 
		{$book['num']=11;$book['len']=strlen("1kin");return $book;}
	if(!strncmp($ref,"1ki",strlen("1ki"))) 
		{$book['num']=11;$book['len']=strlen("1ki");return $book;}
	if(!strncmp($ref,"1kngs",strlen("1kngs"))) 
		{$book['num']=11;$book['len']=strlen("1kngs");return $book;}
	if(!strncmp($ref,"1kng",strlen("1kng"))) 
		{$book['num']=11;$book['len']=strlen("1kng");return $book;}
	if(!strncmp($ref,"1kn",strlen("1kn"))) 
		{$book['num']=11;$book['len']=strlen("1kn");return $book;}
	if(!strncmp($ref,"1kgs",strlen("1kgs"))) 
		{$book['num']=11;$book['len']=strlen("1kgs");return $book;}
	if(!strncmp($ref,"1kg",strlen("1kg"))) 
		{$book['num']=11;$book['len']=strlen("1kg");return $book;}
	if(!strncmp($ref,"ikings",strlen("ikings"))) 
		{$book['num']=11;$book['len']=strlen("ikings");return $book;}
	if(!strncmp($ref,"iking",strlen("iking"))) 
		{$book['num']=11;$book['len']=strlen("iking");return $book;}
	if(!strncmp($ref,"ikin",strlen("ikin"))) 
		{$book['num']=11;$book['len']=strlen("ikin");return $book;}
	if(!strncmp($ref,"iki",strlen("iki"))) 
		{$book['num']=11;$book['len']=strlen("iki");return $book;}
	if(!strncmp($ref,"ikngs",strlen("ikngs"))) 
		{$book['num']=11;$book['len']=strlen("ikngs");return $book;}
	if(!strncmp($ref,"ikng",strlen("ikng"))) 
		{$book['num']=11;$book['len']=strlen("ikng");return $book;}
	if(!strncmp($ref,"ikn",strlen("ikn"))) 
		{$book['num']=11;$book['len']=strlen("ikn");return $book;}
	if(!strncmp($ref,"ikgs",strlen("ikgs"))) 
		{$book['num']=11;$book['len']=strlen("ikgs");return $book;}
	if(!strncmp($ref,"ikg",strlen("ikg"))) 
		{$book['num']=11;$book['len']=strlen("ikg");return $book;}
	if(!strncmp($ref,"kings",strlen("kings"))) 
		{$book['num']=11;$book['len']=strlen("kings");return $book;}

	if(!strncmp($ref,"secondkings",strlen("secondkings"))) 
		{$book['num']=12;$book['len']=strlen("secondkings");return $book;}
	if(!strncmp($ref,"2kings",strlen("2kings"))) 
		{$book['num']=12;$book['len']=strlen("2kings");return $book;}
	if(!strncmp($ref,"2king",strlen("2king"))) 
		{$book['num']=12;$book['len']=strlen("2king");return $book;}
	if(!strncmp($ref,"2kin",strlen("2kin"))) 
		{$book['num']=12;$book['len']=strlen("2kin");return $book;}
	if(!strncmp($ref,"2ki",strlen("2ki"))) 
		{$book['num']=12;$book['len']=strlen("2ki");return $book;}
	if(!strncmp($ref,"2kngs",strlen("2kngs"))) 
		{$book['num']=12;$book['len']=strlen("2kngs");return $book;}
	if(!strncmp($ref,"2kng",strlen("2kng"))) 
		{$book['num']=12;$book['len']=strlen("2kng");return $book;}
	if(!strncmp($ref,"2kn",strlen("2kn"))) 
		{$book['num']=12;$book['len']=strlen("2kn");return $book;}
	if(!strncmp($ref,"2kgs",strlen("2kgs"))) 
		{$book['num']=12;$book['len']=strlen("2kgs");return $book;}
	if(!strncmp($ref,"2kg",strlen("2kg"))) 
		{$book['num']=12;$book['len']=strlen("2kg");return $book;}
	if(!strncmp($ref,"iikings",strlen("iikings"))) 
		{$book['num']=12;$book['len']=strlen("iikings");return $book;}
	if(!strncmp($ref,"iiking",strlen("iiking"))) 
		{$book['num']=12;$book['len']=strlen("iiking");return $book;}
	if(!strncmp($ref,"iikin",strlen("iikin"))) 
		{$book['num']=12;$book['len']=strlen("iikin");return $book;}
	if(!strncmp($ref,"iiki",strlen("iiki"))) 
		{$book['num']=12;$book['len']=strlen("iiki");return $book;}
	if(!strncmp($ref,"iikngs",strlen("iikngs"))) 
		{$book['num']=12;$book['len']=strlen("iikngs");return $book;}
	if(!strncmp($ref,"iikng",strlen("iikng"))) 
		{$book['num']=12;$book['len']=strlen("iikng");return $book;}
	if(!strncmp($ref,"iikn",strlen("iikn"))) 
		{$book['num']=12;$book['len']=strlen("iikn");return $book;}
	if(!strncmp($ref,"iikgs",strlen("iikgs"))) 
		{$book['num']=12;$book['len']=strlen("iikgs");return $book;}
	if(!strncmp($ref,"iikg",strlen("iikg"))) 
		{$book['num']=12;$book['len']=strlen("iikg");return $book;}

	if(!strncmp($ref,"firstchronicles",strlen("firstchronicles"))) 
		{$book['num']=13;$book['len']=strlen("firstchronicles");return $book;}
	if(!strncmp($ref,"1chronicles",strlen("1chronicles"))) 
		{$book['num']=13;$book['len']=strlen("1chronicles");return $book;}
	if(!strncmp($ref,"1chronicle",strlen("1chronicle"))) 
		{$book['num']=13;$book['len']=strlen("1chronicle");return $book;}
	if(!strncmp($ref,"1chronicl",strlen("1chronicl"))) 
		{$book['num']=13;$book['len']=strlen("1chronicl");return $book;}
	if(!strncmp($ref,"1chronic",strlen("1chronic"))) 
		{$book['num']=13;$book['len']=strlen("1chronic");return $book;}
	if(!strncmp($ref,"1chroni",strlen("1chroni"))) 
		{$book['num']=13;$book['len']=strlen("1chroni");return $book;}
	if(!strncmp($ref,"1chron",strlen("1chron"))) 
		{$book['num']=13;$book['len']=strlen("1chron");return $book;}
	if(!strncmp($ref,"1chro",strlen("1chro"))) 
		{$book['num']=13;$book['len']=strlen("1chro");return $book;}
	if(!strncmp($ref,"1chr",strlen("1chr"))) 
		{$book['num']=13;$book['len']=strlen("1chr");return $book;}
	if(!strncmp($ref,"1ch",strlen("1ch"))) 
		{$book['num']=13;$book['len']=strlen("1ch");return $book;}
	if(!strncmp($ref,"ichronicles",strlen("ichronicles"))) 
		{$book['num']=13;$book['len']=strlen("ichronicles");return $book;}
	if(!strncmp($ref,"ichronicle",strlen("ichronicle"))) 
		{$book['num']=13;$book['len']=strlen("ichronicle");return $book;}
	if(!strncmp($ref,"ichronicl",strlen("ichronicl"))) 
		{$book['num']=13;$book['len']=strlen("ichronicl");return $book;}
	if(!strncmp($ref,"ichronic",strlen("ichronic"))) 
		{$book['num']=13;$book['len']=strlen("ichronic");return $book;}
	if(!strncmp($ref,"ichroni",strlen("ichroni"))) 
		{$book['num']=13;$book['len']=strlen("ichroni");return $book;}
	if(!strncmp($ref,"ichron",strlen("ichron"))) 
		{$book['num']=13;$book['len']=strlen("ichron");return $book;}
	if(!strncmp($ref,"ichro",strlen("ichro"))) 
		{$book['num']=13;$book['len']=strlen("ichro");return $book;}
	if(!strncmp($ref,"ichr",strlen("ichr"))) 
		{$book['num']=13;$book['len']=strlen("ichr");return $book;}
	if(!strncmp($ref,"ich",strlen("ich"))) 
		{$book['num']=13;$book['len']=strlen("ich");return $book;}
	if(!strncmp($ref,"chronicles",strlen("chronicles"))) 
		{$book['num']=13;$book['len']=strlen("chronicles");return $book;}

	if(!strncmp($ref,"secondchronicles",strlen("secondchronicles"))) 
		{$book['num']=14;$book['len']=strlen("secondchronicles");return $book;}
	if(!strncmp($ref,"2chronicles",strlen("2chronicles"))) 
		{$book['num']=13;$book['len']=strlen("2chronicles");return $book;}
	if(!strncmp($ref,"2chronicle",strlen("2chronicle"))) 
		{$book['num']=13;$book['len']=strlen("2chronicle");return $book;}
	if(!strncmp($ref,"2chronicl",strlen("2chronicl"))) 
		{$book['num']=13;$book['len']=strlen("2chronicl");return $book;}
	if(!strncmp($ref,"2chronic",strlen("2chronic"))) 
		{$book['num']=13;$book['len']=strlen("2chronic");return $book;}
	if(!strncmp($ref,"2chroni",strlen("2chroni"))) 
		{$book['num']=13;$book['len']=strlen("2chroni");return $book;}
	if(!strncmp($ref,"2chron",strlen("2chron"))) 
		{$book['num']=13;$book['len']=strlen("2chron");return $book;}
	if(!strncmp($ref,"2chro",strlen("2chro"))) 
		{$book['num']=13;$book['len']=strlen("2chro");return $book;}
	if(!strncmp($ref,"2chr",strlen("2chr"))) 
		{$book['num']=13;$book['len']=strlen("2chr");return $book;}
	if(!strncmp($ref,"2ch",strlen("2ch"))) 
		{$book['num']=13;$book['len']=strlen("2ch");return $book;}
	if(!strncmp($ref,"iichronicles",strlen("iichronicles"))) 
		{$book['num']=13;$book['len']=strlen("iichronicles");return $book;}
	if(!strncmp($ref,"iichronicle",strlen("iichronicle"))) 
		{$book['num']=13;$book['len']=strlen("iichronicle");return $book;}
	if(!strncmp($ref,"iichronicl",strlen("iichronicl"))) 
		{$book['num']=13;$book['len']=strlen("iichronicl");return $book;}
	if(!strncmp($ref,"iichronic",strlen("iichronic"))) 
		{$book['num']=13;$book['len']=strlen("iichronic");return $book;}
	if(!strncmp($ref,"iichroni",strlen("iichroni"))) 
		{$book['num']=13;$book['len']=strlen("iichroni");return $book;}
	if(!strncmp($ref,"iichron",strlen("iichron"))) 
		{$book['num']=13;$book['len']=strlen("iichron");return $book;}
	if(!strncmp($ref,"iichro",strlen("iichro"))) 
		{$book['num']=13;$book['len']=strlen("iichro");return $book;}
	if(!strncmp($ref,"iichr",strlen("iichr"))) 
		{$book['num']=13;$book['len']=strlen("iichr");return $book;}
	if(!strncmp($ref,"iich",strlen("iich"))) 
		{$book['num']=13;$book['len']=strlen("iich");return $book;}

	if(!strncmp($ref,"ezra",strlen("ezra"))) 
		{$book['num']=15;$book['len']=strlen("ezra");return $book;}
	if(!strncmp($ref,"ezr",strlen("ezr"))) 
		{$book['num']=15;$book['len']=strlen("ezr");return $book;}

	if(!strncmp($ref,"nehemiah",strlen("nehemiah"))) 
		{$book['num']=16;$book['len']=strlen("nehemiah");return $book;}
	if(!strncmp($ref,"nehamiah",strlen("nehamiah"))) 
		{$book['num']=16;$book['len']=strlen("nehamiah");return $book;}
	if(!strncmp($ref,"nehemia",strlen("nehemia"))) 
		{$book['num']=16;$book['len']=strlen("nehemia");return $book;}
	if(!strncmp($ref,"nehemi",strlen("nehemi"))) 
		{$book['num']=16;$book['len']=strlen("nehemi");return $book;}
	if(!strncmp($ref,"nehem",strlen("nehem"))) 
		{$book['num']=16;$book['len']=strlen("nehem");return $book;}
	if(!strncmp($ref,"nehe",strlen("nehe"))) 
		{$book['num']=16;$book['len']=strlen("nehe");return $book;}
	if(!strncmp($ref,"neh",strlen("neh"))) 
		{$book['num']=16;$book['len']=strlen("neh");return $book;}
	if(!strncmp($ref,"ne",strlen("ne"))) 
		{$book['num']=16;$book['len']=strlen("ne");return $book;}

	if(!strncmp($ref,"esther",strlen("esther"))) 
		{$book['num']=17;$book['len']=strlen("esther");return $book;}
	if(!strncmp($ref,"esthe",strlen("esthe"))) 
		{$book['num']=17;$book['len']=strlen("esthe");return $book;}
	if(!strncmp($ref,"esth",strlen("esth"))) 
		{$book['num']=17;$book['len']=strlen("esth");return $book;}
	if(!strncmp($ref,"est",strlen("est"))) 
		{$book['num']=17;$book['len']=strlen("est");return $book;}
	if(!strncmp($ref,"es",strlen("es"))) 
		{$book['num']=17;$book['len']=strlen("es");return $book;}

	if(!strncmp($ref,"job",strlen("job"))) 
		{$book['num']=18;$book['len']=strlen("job");return $book;}
	if(!strncmp($ref,"jobe",strlen("jobe"))) 
		{$book['num']=18;$book['len']=strlen("jobe");return $book;}

	if(!strncmp($ref,"psalms",strlen("psalms"))) 
		{$book['num']=19;$book['len']=strlen("psalms");return $book;}
	if(!strncmp($ref,"salms",strlen("salms"))) 
		{$book['num']=19;$book['len']=strlen("salms");return $book;}
	if(!strncmp($ref,"psalm",strlen("psalm"))) 
		{$book['num']=19;$book['len']=strlen("psalm");return $book;}
	if(!strncmp($ref,"salm",strlen("salm"))) 
		{$book['num']=19;$book['len']=strlen("salm");return $book;}
	if(!strncmp($ref,"psal",strlen("psal"))) 
		{$book['num']=19;$book['len']=strlen("psal");return $book;}
	if(!strncmp($ref,"psa",strlen("psa"))) 
		{$book['num']=19;$book['len']=strlen("psa");return $book;}
	if(!strncmp($ref,"ps",strlen("ps"))) 
		{$book['num']=19;$book['len']=strlen("ps");return $book;}
	if(!strncmp($ref,"pslms",strlen("pslms"))) 
		{$book['num']=19;$book['len']=strlen("pslms");return $book;}
	if(!strncmp($ref,"pslm",strlen("pslm"))) 
		{$book['num']=19;$book['len']=strlen("pslm");return $book;}
	if(!strncmp($ref,"psl",strlen("psl"))) 
		{$book['num']=19;$book['len']=strlen("psl");return $book;}
	if(!strncmp($ref,"psm",strlen("psm"))) 
		{$book['num']=19;$book['len']=strlen("psm");return $book;}

	if(!strncmp($ref,"proverbs",strlen("proverbs"))) 
		{$book['num']=20;$book['len']=strlen("proverbs");return $book;}
	if(!strncmp($ref,"proverb",strlen("proverb"))) 
		{$book['num']=20;$book['len']=strlen("proverb");return $book;}
	if(!strncmp($ref,"prover",strlen("prover"))) 
		{$book['num']=20;$book['len']=strlen("prover");return $book;}
	if(!strncmp($ref,"prove",strlen("prove"))) 
		{$book['num']=20;$book['len']=strlen("prove");return $book;}
	if(!strncmp($ref,"prov",strlen("prov"))) 
		{$book['num']=20;$book['len']=strlen("prov");return $book;}
	if(!strncmp($ref,"pro",strlen("pro"))) 
		{$book['num']=20;$book['len']=strlen("pro");return $book;}
	if(!strncmp($ref,"pr",strlen("pr"))) 
		{$book['num']=20;$book['len']=strlen("pr");return $book;}
	if(!strncmp($ref,"prvrbs",strlen("prvrbs"))) 
		{$book['num']=20;$book['len']=strlen("prvrbs");return $book;}
	if(!strncmp($ref,"prvrb",strlen("prvrb"))) 
		{$book['num']=20;$book['len']=strlen("prvrb");return $book;}
	if(!strncmp($ref,"prvbs",strlen("prvbs"))) 
		{$book['num']=20;$book['len']=strlen("prvbs");return $book;}
	if(!strncmp($ref,"prvb",strlen("prvb"))) 
		{$book['num']=20;$book['len']=strlen("prvb");return $book;}
	if(!strncmp($ref,"prv",strlen("prv"))) 
		{$book['num']=20;$book['len']=strlen("prv");return $book;}
	if(!strncmp($ref,"prb",strlen("prb"))) 
		{$book['num']=20;$book['len']=strlen("prb");return $book;}

	if(!strncmp($ref,"ecclesiastes",strlen("ecclesiastes"))) 
		{$book['num']=21;$book['len']=strlen("ecclesiastes");return $book;}
	if(!strncmp($ref,"ecclesiaste",strlen("ecclesiaste"))) 
		{$book['num']=21;$book['len']=strlen("ecclesiaste");return $book;}
	if(!strncmp($ref,"ecclesiast",strlen("ecclesiast"))) 
		{$book['num']=21;$book['len']=strlen("ecclesiast");return $book;}
	if(!strncmp($ref,"ecclesias",strlen("ecclesias"))) 
		{$book['num']=21;$book['len']=strlen("ecclesias");return $book;}
	if(!strncmp($ref,"ecclesia",strlen("ecclesia"))) 
		{$book['num']=21;$book['len']=strlen("ecclesia");return $book;}
	if(!strncmp($ref,"ecclesi",strlen("ecclesi"))) 
		{$book['num']=21;$book['len']=strlen("ecclesi");return $book;}
	if(!strncmp($ref,"eccles",strlen("eccles"))) 
		{$book['num']=21;$book['len']=strlen("eccles");return $book;}
	if(!strncmp($ref,"eccle",strlen("eccle"))) 
		{$book['num']=21;$book['len']=strlen("eccle");return $book;}
	if(!strncmp($ref,"eccl",strlen("eccl"))) 
		{$book['num']=21;$book['len']=strlen("eccl");return $book;}
	if(!strncmp($ref,"eclesiastes",strlen("eclesiastes"))) 
		{$book['num']=21;$book['len']=strlen("eclesiastes");return $book;}
	if(!strncmp($ref,"eclesiaste",strlen("eclesiaste"))) 
		{$book['num']=21;$book['len']=strlen("eclesiaste");return $book;}
	if(!strncmp($ref,"eclesiast",strlen("eclesiast"))) 
		{$book['num']=21;$book['len']=strlen("eclesiast");return $book;}
	if(!strncmp($ref,"eclesias",strlen("eclesias"))) 
		{$book['num']=21;$book['len']=strlen("eclesias");return $book;}
	if(!strncmp($ref,"eclesia",strlen("eclesia"))) 
		{$book['num']=21;$book['len']=strlen("eclesia");return $book;}
	if(!strncmp($ref,"eclesi",strlen("eclesi"))) 
		{$book['num']=21;$book['len']=strlen("eclesi");return $book;}
	if(!strncmp($ref,"ecles",strlen("ecles"))) 
		{$book['num']=21;$book['len']=strlen("ecles");return $book;}
	if(!strncmp($ref,"ecle",strlen("ecle"))) 
		{$book['num']=21;$book['len']=strlen("ecle");return $book;}
	if(!strncmp($ref,"ecl",strlen("ecl"))) 
		{$book['num']=21;$book['len']=strlen("ecl");return $book;}
	if(!strncmp($ref,"ecc",strlen("ecc"))) 
		{$book['num']=21;$book['len']=strlen("ecc");return $book;}
	if(!strncmp($ref,"ec",strlen("ec"))) 
		{$book['num']=21;$book['len']=strlen("ec");return $book;}
	if(!strncmp($ref,"eccls",strlen("eccls"))) 
		{$book['num']=21;$book['len']=strlen("eccls");return $book;}

	if(!strncmp($ref,"songofsolomon",strlen("songofsolomon"))) 
		{$book['num']=22;$book['len']=strlen("songofsolomon");return $book;}
	if(!strncmp($ref,"songsolomon",strlen("songsolomon"))) 
		{$book['num']=22;$book['len']=strlen("songsolomon");return $book;}
	if(!strncmp($ref,"solomon",strlen("solomon"))) 
		{$book['num']=22;$book['len']=strlen("solomon");return $book;}
	if(!strncmp($ref,"songofsongs",strlen("songofsongs"))) 
		{$book['num']=22;$book['len']=strlen("songofsongs");return $book;}
	if(!strncmp($ref,"songsongs",strlen("songsongs"))) 
		{$book['num']=22;$book['len']=strlen("songsongs");return $book;}
	if(!strncmp($ref,"songs",strlen("songs"))) 
		{$book['num']=22;$book['len']=strlen("songs");return $book;}
	if(!strncmp($ref,"song",strlen("song"))) 
		{$book['num']=22;$book['len']=strlen("song");return $book;}
	if(!strncmp($ref,"ss",strlen("ss"))) 
		{$book['num']=22;$book['len']=strlen("ss");return $book;}

	if(!strncmp($ref,"isaiah",strlen("isaiah"))) 
		{$book['num']=23;$book['len']=strlen("isaiah");return $book;}
	if(!strncmp($ref,"isaia",strlen("isaia"))) 
		{$book['num']=23;$book['len']=strlen("isaia");return $book;}
	if(!strncmp($ref,"isaih",strlen("isaih"))) 
		{$book['num']=23;$book['len']=strlen("isaih");return $book;}
	if(!strncmp($ref,"isai",strlen("isai"))) 
		{$book['num']=23;$book['len']=strlen("isai");return $book;}
	if(!strncmp($ref,"isa",strlen("isa"))) 
		{$book['num']=23;$book['len']=strlen("isa");return $book;}
	if(!strncmp($ref,"isiah",strlen("isiah"))) 
		{$book['num']=23;$book['len']=strlen("isiah");return $book;}
	if(!strncmp($ref,"isaah",strlen("isaah"))) 
		{$book['num']=23;$book['len']=strlen("isaah");return $book;}

	if(!strncmp($ref,"jeremiah",strlen("jeremiah"))) 
		{$book['num']=24;$book['len']=strlen("jeremiah");return $book;}
	if(!strncmp($ref,"jeremia",strlen("jeremia"))) 
		{$book['num']=24;$book['len']=strlen("jeremia");return $book;}
	if(!strncmp($ref,"jeremi",strlen("jeremi"))) 
		{$book['num']=24;$book['len']=strlen("jeremi");return $book;}
	if(!strncmp($ref,"jerem",strlen("jerem"))) 
		{$book['num']=24;$book['len']=strlen("jerem");return $book;}
	if(!strncmp($ref,"jere",strlen("jere"))) 
		{$book['num']=24;$book['len']=strlen("jere");return $book;}
	if(!strncmp($ref,"jer",strlen("jer"))) 
		{$book['num']=24;$book['len']=strlen("jer");return $book;}
	if(!strncmp($ref,"je",strlen("je"))) 
		{$book['num']=24;$book['len']=strlen("je");return $book;}
	if(!strncmp($ref,"jeramiah",strlen("jeramiah"))) 
		{$book['num']=24;$book['len']=strlen("jeramiah");return $book;}
	if(!strncmp($ref,"jeramia",strlen("jeramia"))) 
		{$book['num']=24;$book['len']=strlen("jeramia");return $book;}
	if(!strncmp($ref,"jerami",strlen("jerami"))) 
		{$book['num']=24;$book['len']=strlen("jerami");return $book;}
	if(!strncmp($ref,"jeram",strlen("jeram"))) 
		{$book['num']=24;$book['len']=strlen("jeram");return $book;}
	if(!strncmp($ref,"jera",strlen("jera"))) 
		{$book['num']=24;$book['len']=strlen("jera");return $book;}
	if(!strncmp($ref,"jaramiah",strlen("jaramiah"))) 
		{$book['num']=24;$book['len']=strlen("jaramiah");return $book;}
	if(!strncmp($ref,"jaramia",strlen("jaramia"))) 
		{$book['num']=24;$book['len']=strlen("jaramia");return $book;}
	if(!strncmp($ref,"jarami",strlen("jarami"))) 
		{$book['num']=24;$book['len']=strlen("jarami");return $book;}
	if(!strncmp($ref,"jaram",strlen("jaram"))) 
		{$book['num']=24;$book['len']=strlen("jaram");return $book;}
	if(!strncmp($ref,"jara",strlen("jara"))) 
		{$book['num']=24;$book['len']=strlen("jara");return $book;}
	if(!strncmp($ref,"jaremiah",strlen("jaremiah"))) 
		{$book['num']=24;$book['len']=strlen("jaremiah");return $book;}
	if(!strncmp($ref,"jaremia",strlen("jaremia"))) 
		{$book['num']=24;$book['len']=strlen("jaremia");return $book;}
	if(!strncmp($ref,"jaremi",strlen("jaremi"))) 
		{$book['num']=24;$book['len']=strlen("jaremi");return $book;}
	if(!strncmp($ref,"jarem",strlen("jarem"))) 
		{$book['num']=24;$book['len']=strlen("jarem");return $book;}
	if(!strncmp($ref,"jare",strlen("jare"))) 
		{$book['num']=24;$book['len']=strlen("jare");return $book;}
	if(!strncmp($ref,"jar",strlen("jar"))) 
		{$book['num']=24;$book['len']=strlen("jar");return $book;}

	if(!strncmp($ref,"lamentations",strlen("lamentations"))) 
		{$book['num']=25;$book['len']=strlen("lamentations");return $book;}
	if(!strncmp($ref,"lamentation",strlen("lamentation"))) 
		{$book['num']=25;$book['len']=strlen("lamentation");return $book;}
	if(!strncmp($ref,"lamentatio",strlen("lamentatio"))) 
		{$book['num']=25;$book['len']=strlen("lamentatio");return $book;}
	if(!strncmp($ref,"lamentati",strlen("lamentati"))) 
		{$book['num']=25;$book['len']=strlen("lamentati");return $book;}
	if(!strncmp($ref,"lamentat",strlen("lamentat"))) 
		{$book['num']=25;$book['len']=strlen("lamentat");return $book;}
	if(!strncmp($ref,"lamenta",strlen("lamenta"))) 
		{$book['num']=25;$book['len']=strlen("lamenta");return $book;}
	if(!strncmp($ref,"lament",strlen("lament"))) 
		{$book['num']=25;$book['len']=strlen("lament");return $book;}
	if(!strncmp($ref,"lamen",strlen("lamen"))) 
		{$book['num']=25;$book['len']=strlen("lamen");return $book;}
	if(!strncmp($ref,"lame",strlen("lame"))) 
		{$book['num']=25;$book['len']=strlen("lame");return $book;}
	if(!strncmp($ref,"lam",strlen("lam"))) 
		{$book['num']=25;$book['len']=strlen("lam");return $book;}
	if(!strncmp($ref,"la",strlen("la"))) 
		{$book['num']=25;$book['len']=strlen("la");return $book;}
	if(!strncmp($ref,"lamentions",strlen("lamentions"))) 
		{$book['num']=25;$book['len']=strlen("lamentions");return $book;}
	if(!strncmp($ref,"lamention",strlen("lamention"))) 
		{$book['num']=25;$book['len']=strlen("lamention");return $book;}
	if(!strncmp($ref,"lmnt",strlen("lmnt"))) 
		{$book['num']=25;$book['len']=strlen("lmnt");return $book;}

	if(!strncmp($ref,"ezekiel",strlen("ezekiel"))) 
		{$book['num']=26;$book['len']=strlen("ezekiel");return $book;}
	if(!strncmp($ref,"ezekie",strlen("ezekie"))) 
		{$book['num']=26;$book['len']=strlen("ezekie");return $book;}
	if(!strncmp($ref,"ezeki",strlen("ezeki"))) 
		{$book['num']=26;$book['len']=strlen("ezeki");return $book;}
	if(!strncmp($ref,"ezek",strlen("ezek"))) 
		{$book['num']=26;$book['len']=strlen("ezek");return $book;}
	if(!strncmp($ref,"eze",strlen("eze"))) 
		{$book['num']=26;$book['len']=strlen("eze");return $book;}
	if(!strncmp($ref,"ezekial",strlen("ezekial"))) 
		{$book['num']=26;$book['len']=strlen("ezekial");return $book;}
	if(!strncmp($ref,"ezekia",strlen("ezekia"))) 
		{$book['num']=26;$book['len']=strlen("ezekia");return $book;}
	if(!strncmp($ref,"zekiel",strlen("zekiel"))) 
		{$book['num']=26;$book['len']=strlen("zekiel");return $book;}

	if(!strncmp($ref,"danniel",strlen("danniel"))) 
		{$book['num']=27;$book['len']=strlen("danniel");return $book;}
	if(!strncmp($ref,"dannie",strlen("dannie"))) 
		{$book['num']=27;$book['len']=strlen("dannie");return $book;}
	if(!strncmp($ref,"danni",strlen("danni"))) 
		{$book['num']=27;$book['len']=strlen("danni");return $book;}
	if(!strncmp($ref,"danny",strlen("danny"))) 
		{$book['num']=27;$book['len']=strlen("danny");return $book;}
	if(!strncmp($ref,"dann",strlen("dann"))) 
		{$book['num']=27;$book['len']=strlen("dann");return $book;}
	if(!strncmp($ref,"daniel",strlen("daniel"))) 
		{$book['num']=27;$book['len']=strlen("daniel");return $book;}
	if(!strncmp($ref,"danial",strlen("danial"))) 
		{$book['num']=27;$book['len']=strlen("danial");return $book;}
	if(!strncmp($ref,"denial",strlen("denial"))) 
		{$book['num']=27;$book['len']=strlen("denial");return $book;}
	if(!strncmp($ref,"danie",strlen("danie"))) 
		{$book['num']=27;$book['len']=strlen("danie");return $book;}
	if(!strncmp($ref,"dani",strlen("dani"))) 
		{$book['num']=27;$book['len']=strlen("dani");return $book;}
	if(!strncmp($ref,"danl",strlen("danl"))) 
		{$book['num']=27;$book['len']=strlen("danl");return $book;}
	if(!strncmp($ref,"dan",strlen("dan"))) 
		{$book['num']=27;$book['len']=strlen("dan");return $book;}
	if(!strncmp($ref,"da",strlen("da"))) 
		{$book['num']=27;$book['len']=strlen("da");return $book;}
	if(!strncmp($ref,"dnl",strlen("dnl"))) 
		{$book['num']=27;$book['len']=strlen("dnl");return $book;}
	if(!strncmp($ref,"dn",strlen("dn"))) 
		{$book['num']=27;$book['len']=strlen("dn");return $book;}
	if(!strncmp($ref,"dl",strlen("dl"))) 
		{$book['num']=27;$book['len']=strlen("dl");return $book;}

	if(!strncmp($ref,"hosea",strlen("hosea"))) 
		{$book['num']=28;$book['len']=strlen("hosea");return $book;}
	if(!strncmp($ref,"hose",strlen("hose"))) 
		{$book['num']=28;$book['len']=strlen("hose");return $book;}
	if(!strncmp($ref,"hos",strlen("hos"))) 
		{$book['num']=28;$book['len']=strlen("hos");return $book;}
	if(!strncmp($ref,"ho",strlen("ho"))) 
		{$book['num']=28;$book['len']=strlen("ho");return $book;}
	if(!strncmp($ref,"hs",strlen("hs"))) 
		{$book['num']=28;$book['len']=strlen("hs");return $book;}
	if(!strncmp($ref,"hosia",strlen("hosia"))) 
		{$book['num']=28;$book['len']=strlen("hosia");return $book;}

	if(!strncmp($ref,"joel",strlen("joel"))) 
		{$book['num']=29;$book['len']=strlen("joel");return $book;}
	if(!strncmp($ref,"joe",strlen("joe"))) 
		{$book['num']=29;$book['len']=strlen("joel");return $book;}
	if(!strncmp($ref,"jole",strlen("jole"))) 
		{$book['num']=29;$book['len']=strlen("jole");return $book;}
	if(!strncmp($ref,"jol",strlen("jol"))) 
		{$book['num']=29;$book['len']=strlen("jol");return $book;}
	if(!strncmp($ref,"jl",strlen("jl"))) 
		{$book['num']=29;$book['len']=strlen("jl");return $book;}

	if(!strncmp($ref,"amos",strlen("amos"))) 
		{$book['num']=30;$book['len']=strlen("amos");return $book;}
	if(!strncmp($ref,"amo",strlen("amo"))) 
		{$book['num']=30;$book['len']=strlen("amo");return $book;}
	if(!strncmp($ref,"ams",strlen("ams"))) 
		{$book['num']=30;$book['len']=strlen("ams");return $book;}
	if(!strncmp($ref,"am",strlen("am"))) 
		{$book['num']=30;$book['len']=strlen("am");return $book;}

	if(!strncmp($ref,"obadiah",strlen("obadiah"))) 
		{$book['num']=31;$book['len']=strlen("obadiah");return $book;}
	if(!strncmp($ref,"obadia",strlen("obadia"))) 
		{$book['num']=31;$book['len']=strlen("obadia");return $book;}
	if(!strncmp($ref,"obadi",strlen("obadi"))) 
		{$book['num']=31;$book['len']=strlen("obadi");return $book;}
	if(!strncmp($ref,"obadaih",strlen("obadaih"))) 
		{$book['num']=31;$book['len']=strlen("obadaih");return $book;}
	if(!strncmp($ref,"obadai",strlen("obadai"))) 
		{$book['num']=31;$book['len']=strlen("obadai");return $book;}
	if(!strncmp($ref,"obada",strlen("obada"))) 
		{$book['num']=31;$book['len']=strlen("obada");return $book;}
	if(!strncmp($ref,"obad",strlen("obad"))) 
		{$book['num']=31;$book['len']=strlen("obad");return $book;}
	if(!strncmp($ref,"oba",strlen("oba"))) 
		{$book['num']=31;$book['len']=strlen("oba");return $book;}
	if(!strncmp($ref,"obodiah",strlen("obodiah"))) 
		{$book['num']=31;$book['len']=strlen("obodiah");return $book;}
	if(!strncmp($ref,"obodia",strlen("obodia"))) 
		{$book['num']=31;$book['len']=strlen("obodia");return $book;}
	if(!strncmp($ref,"obodi",strlen("obodi"))) 
		{$book['num']=31;$book['len']=strlen("obodi");return $book;}
	if(!strncmp($ref,"obod",strlen("obod"))) 
		{$book['num']=31;$book['len']=strlen("obod");return $book;}
	if(!strncmp($ref,"obo",strlen("obo"))) 
		{$book['num']=31;$book['len']=strlen("obo");return $book;}
	if(!strncmp($ref,"ob",strlen("ob"))) 
		{$book['num']=31;$book['len']=strlen("ob");return $book;}

	if(!strncmp($ref,"jonah",strlen("jonah"))) 
		{$book['num']=32;$book['len']=strlen("jonah");return $book;}
	if(!strncmp($ref,"jona",strlen("jona"))) 
		{$book['num']=32;$book['len']=strlen("jona");return $book;}
	if(!strncmp($ref,"jonha",strlen("jonha"))) 
		{$book['num']=32;$book['len']=strlen("jonha");return $book;}
	if(!strncmp($ref,"jonh",strlen("jonh"))) 
		{$book['num']=32;$book['len']=strlen("jonh");return $book;}
	if(!strncmp($ref,"jon",strlen("jon"))) 
		{$book['num']=32;$book['len']=strlen("jon");return $book;}
	if(!strncmp($ref,"jna",strlen("jna"))) 
		{$book['num']=32;$book['len']=strlen("jna");return $book;}

	if(!strncmp($ref,"micah",strlen("micah"))) 
		{$book['num']=33;$book['len']=strlen("micah");return $book;}
	if(!strncmp($ref,"mica",strlen("mica"))) 
		{$book['num']=33;$book['len']=strlen("mica");return $book;}
	if(!strncmp($ref,"mic",strlen("mic"))) 
		{$book['num']=33;$book['len']=strlen("mic");return $book;}
	if(!strncmp($ref,"mi",strlen("mi"))) 
		{$book['num']=33;$book['len']=strlen("mi");return $book;}
	if(!strncmp($ref,"mycah",strlen("mycah"))) 
		{$book['num']=33;$book['len']=strlen("mycah");return $book;}
	if(!strncmp($ref,"myca",strlen("myca"))) 
		{$book['num']=33;$book['len']=strlen("myca");return $book;}
	if(!strncmp($ref,"myc",strlen("myc"))) 
		{$book['num']=33;$book['len']=strlen("myc");return $book;}
	if(!strncmp($ref,"my",strlen("my"))) 
		{$book['num']=33;$book['len']=strlen("my");return $book;}

	if(!strncmp($ref,"nahum",strlen("nahum"))) 
		{$book['num']=34;$book['len']=strlen("nahum");return $book;}
	if(!strncmp($ref,"nahim",strlen("nahim"))) 
		{$book['num']=34;$book['len']=strlen("nahim");return $book;}
	if(!strncmp($ref,"nahem",strlen("nahem"))) 
		{$book['num']=34;$book['len']=strlen("nahem");return $book;}
	if(!strncmp($ref,"nahu",strlen("nahu"))) 
		{$book['num']=34;$book['len']=strlen("nahu");return $book;}
	if(!strncmp($ref,"nahi",strlen("nahi"))) 
		{$book['num']=34;$book['len']=strlen("nahi");return $book;}
	if(!strncmp($ref,"nahe",strlen("nahe"))) 
		{$book['num']=34;$book['len']=strlen("nahe");return $book;}
	if(!strncmp($ref,"nah",strlen("nah"))) 
		{$book['num']=34;$book['len']=strlen("nah");return $book;}
	if(!strncmp($ref,"na",strlen("na"))) 
		{$book['num']=34;$book['len']=strlen("na");return $book;}

	if(!strncmp($ref,"habakkuk",strlen("habakkuk"))) 
		{$book['num']=35;$book['len']=strlen("habakkuk");return $book;}
	if(!strncmp($ref,"habakku",strlen("habakku"))) 
		{$book['num']=35;$book['len']=strlen("habakku");return $book;}
	if(!strncmp($ref,"habakk",strlen("habakk"))) 
		{$book['num']=35;$book['len']=strlen("habakk");return $book;}
	if(!strncmp($ref,"habbakkuk",strlen("habbakkuk"))) 
		{$book['num']=35;$book['len']=strlen("habbakkuk");return $book;}
	if(!strncmp($ref,"habbakku",strlen("habbakku"))) 
		{$book['num']=35;$book['len']=strlen("habbakku");return $book;}
	if(!strncmp($ref,"habbakk",strlen("habbakk"))) 
		{$book['num']=35;$book['len']=strlen("habbakk");return $book;}
	if(!strncmp($ref,"habakuk",strlen("habakuk"))) 
		{$book['num']=35;$book['len']=strlen("habakuk");return $book;}
	if(!strncmp($ref,"habaku",strlen("habaku"))) 
		{$book['num']=35;$book['len']=strlen("habaku");return $book;}
	if(!strncmp($ref,"habak",strlen("habak"))) 
		{$book['num']=35;$book['len']=strlen("habak");return $book;}
	if(!strncmp($ref,"haba",strlen("haba"))) 
		{$book['num']=35;$book['len']=strlen("haba");return $book;}
	if(!strncmp($ref,"habbakuk",strlen("habbakuk"))) 
		{$book['num']=35;$book['len']=strlen("habbakuk");return $book;}
	if(!strncmp($ref,"habbaku",strlen("habbaku"))) 
		{$book['num']=35;$book['len']=strlen("habbaku");return $book;}
	if(!strncmp($ref,"habbak",strlen("habbak"))) 
		{$book['num']=35;$book['len']=strlen("habbak");return $book;}
	if(!strncmp($ref,"habba",strlen("habba"))) 
		{$book['num']=35;$book['len']=strlen("habba");return $book;}
	if(!strncmp($ref,"habb",strlen("habb"))) 
		{$book['num']=35;$book['len']=strlen("habb");return $book;}
	if(!strncmp($ref,"hab",strlen("hab"))) 
		{$book['num']=35;$book['len']=strlen("hab");return $book;}

	if(!strncmp($ref,"zephaniah",strlen("zephaniah"))) 
		{$book['num']=36;$book['len']=strlen("zephaniah");return $book;}
	if(!strncmp($ref,"zephania",strlen("zephania"))) 
		{$book['num']=36;$book['len']=strlen("zephania");return $book;}
	if(!strncmp($ref,"zephani",strlen("zephani"))) 
		{$book['num']=36;$book['len']=strlen("zephani");return $book;}
	if(!strncmp($ref,"zephan",strlen("zephan"))) 
		{$book['num']=36;$book['len']=strlen("zephan");return $book;}
	if(!strncmp($ref,"zepha",strlen("zepha"))) 
		{$book['num']=36;$book['len']=strlen("zepha");return $book;}
	if(!strncmp($ref,"zeph",strlen("zeph"))) 
		{$book['num']=36;$book['len']=strlen("zeph");return $book;}
	if(!strncmp($ref,"zep",strlen("zep"))) 
		{$book['num']=36;$book['len']=strlen("zep");return $book;}
	if(!strncmp($ref,"zph",strlen("zph"))) 
		{$book['num']=36;$book['len']=strlen("zph");return $book;}

	if(!strncmp($ref,"haggai",strlen("haggai"))) 
		{$book['num']=37;$book['len']=strlen("haggai");return $book;}
	if(!strncmp($ref,"hagai",strlen("hagai"))) 
		{$book['num']=37;$book['len']=strlen("hagai");return $book;}
	if(!strncmp($ref,"hagga",strlen("hagga"))) 
		{$book['num']=37;$book['len']=strlen("hagga");return $book;}
	if(!strncmp($ref,"hagg",strlen("hagg"))) 
		{$book['num']=37;$book['len']=strlen("hagg");return $book;}
	if(!strncmp($ref,"haga",strlen("haga"))) 
		{$book['num']=37;$book['len']=strlen("haga");return $book;}
	if(!strncmp($ref,"hag",strlen("hag"))) 
		{$book['num']=37;$book['len']=strlen("hag");return $book;}

	if(!strncmp($ref,"zechariah",strlen("zechariah"))) 
		{$book['num']=38;$book['len']=strlen("zechariah");return $book;}
	if(!strncmp($ref,"zecharia",strlen("zecharia"))) 
		{$book['num']=38;$book['len']=strlen("zecharia");return $book;}
	if(!strncmp($ref,"zechari",strlen("zechari"))) 
		{$book['num']=38;$book['len']=strlen("zechari");return $book;}
	if(!strncmp($ref,"zechar",strlen("zechar"))) 
		{$book['num']=38;$book['len']=strlen("zechar");return $book;}
	if(!strncmp($ref,"zecha",strlen("zecha"))) 
		{$book['num']=38;$book['len']=strlen("zecha");return $book;}
	if(!strncmp($ref,"zech",strlen("zech"))) 
		{$book['num']=38;$book['len']=strlen("zech");return $book;}
	if(!strncmp($ref,"zec",strlen("zec"))) 
		{$book['num']=38;$book['len']=strlen("zec");return $book;}
	if(!strncmp($ref,"zch",strlen("zch"))) 
		{$book['num']=38;$book['len']=strlen("zch");return $book;}

	if(!strncmp($ref,"malachi",strlen("malachi"))) 
		{$book['num']=39;$book['len']=strlen("malachi");return $book;}
	if(!strncmp($ref,"malichi",strlen("malichi"))) 
		{$book['num']=39;$book['len']=strlen("malichi");return $book;}
	if(!strncmp($ref,"malach",strlen("malach"))) 
		{$book['num']=39;$book['len']=strlen("malach");return $book;}
	if(!strncmp($ref,"malich",strlen("malich"))) 
		{$book['num']=39;$book['len']=strlen("malich");return $book;}
	if(!strncmp($ref,"malac",strlen("malac"))) 
		{$book['num']=39;$book['len']=strlen("malac");return $book;}
	if(!strncmp($ref,"malic",strlen("malic"))) 
		{$book['num']=39;$book['len']=strlen("malic");return $book;}
	if(!strncmp($ref,"mala",strlen("mala"))) 
		{$book['num']=39;$book['len']=strlen("mala");return $book;}
	if(!strncmp($ref,"mali",strlen("mali"))) 
		{$book['num']=39;$book['len']=strlen("mali");return $book;}
	if(!strncmp($ref,"mal",strlen("mal"))) 
		{$book['num']=39;$book['len']=strlen("mal");return $book;}

	if(!strncmp($ref,"matthew",strlen("matthew"))) 
		{$book['num']=40;$book['len']=strlen("matthew");return $book;}
	if(!strncmp($ref,"matthe",strlen("matthe"))) 
		{$book['num']=40;$book['len']=strlen("matthe");return $book;}
	if(!strncmp($ref,"matth",strlen("matth"))) 
		{$book['num']=40;$book['len']=strlen("matth");return $book;}
	if(!strncmp($ref,"matt",strlen("matt"))) 
		{$book['num']=40;$book['len']=strlen("matt");return $book;}
	if(!strncmp($ref,"mathew",strlen("mathew"))) 
		{$book['num']=40;$book['len']=strlen("mathew");return $book;}
	if(!strncmp($ref,"mathe",strlen("mathe"))) 
		{$book['num']=40;$book['len']=strlen("mathe");return $book;}
	if(!strncmp($ref,"math",strlen("math"))) 
		{$book['num']=40;$book['len']=strlen("math");return $book;}
	if(!strncmp($ref,"mat",strlen("mat"))) 
		{$book['num']=40;$book['len']=strlen("mat");return $book;}
	if(!strncmp($ref,"mt",strlen("mt"))) 
		{$book['num']=40;$book['len']=strlen("mt");return $book;}

	if(!strncmp($ref,"mark",strlen("mark"))) 
		{$book['num']=41;$book['len']=strlen("mark");return $book;}
	if(!strncmp($ref,"mar",strlen("mar"))) 
		{$book['num']=41;$book['len']=strlen("mar");return $book;}
	if(!strncmp($ref,"mrk",strlen("mrk"))) 
		{$book['num']=41;$book['len']=strlen("mrk");return $book;}
	if(!strncmp($ref,"mk",strlen("mk"))) 
		{$book['num']=41;$book['len']=strlen("mk");return $book;}
	if(!strncmp($ref,"mr",strlen("mr"))) 
		{$book['num']=41;$book['len']=strlen("mr");return $book;}

	if(!strncmp($ref,"luke",strlen("luke"))) 
		{$book['num']=42;$book['len']=strlen("luke");return $book;}
	if(!strncmp($ref,"luk",strlen("luk"))) 
		{$book['num']=42;$book['len']=strlen("luk");return $book;}
	if(!strncmp($ref,"lu",strlen("lu"))) 
		{$book['num']=42;$book['len']=strlen("lu");return $book;}
	if(!strncmp($ref,"lk",strlen("lk"))) 
		{$book['num']=42;$book['len']=strlen("lk");return $book;}

	if(!strncmp($ref,"john",strlen("john"))) 
		{$book['num']=43;$book['len']=strlen("john");return $book;}
	if(!strncmp($ref,"joh",strlen("joh"))) 
		{$book['num']=43;$book['len']=strlen("joh");return $book;}
	if(!strncmp($ref,"jo",strlen("jo"))) 
		{$book['num']=43;$book['len']=strlen("jo");return $book;}
	if(!strncmp($ref,"jn",strlen("jn"))) 
		{$book['num']=43;$book['len']=strlen("jn");return $book;}

	if(!strncmp($ref,"acts",strlen("acts"))) 
		{$book['num']=44;$book['len']=strlen("acts");return $book;}
	if(!strncmp($ref,"act",strlen("act"))) 
		{$book['num']=44;$book['len']=strlen("act");return $book;}
	if(!strncmp($ref,"ac",strlen("ac"))) 
		{$book['num']=44;$book['len']=strlen("ac");return $book;}
	if(!strncmp($ref,"ats",strlen("ats"))) 
		{$book['num']=44;$book['len']=strlen("ats");return $book;}
	if(!strncmp($ref,"at",strlen("at"))) 
		{$book['num']=44;$book['len']=strlen("at");return $book;}

	if(!strncmp($ref,"romans",strlen("romans"))) 
		{$book['num']=45;$book['len']=strlen("romans");return $book;}
	if(!strncmp($ref,"roman",strlen("roman"))) 
		{$book['num']=45;$book['len']=strlen("roman");return $book;}
	if(!strncmp($ref,"roma",strlen("roma"))) 
		{$book['num']=45;$book['len']=strlen("roma");return $book;}
	if(!strncmp($ref,"rom",strlen("rom"))) 
		{$book['num']=45;$book['len']=strlen("rom");return $book;}
	if(!strncmp($ref,"ro",strlen("ro"))) 
		{$book['num']=45;$book['len']=strlen("ro");return $book;}
	if(!strncmp($ref,"rmans",strlen("rmans"))) 
		{$book['num']=45;$book['len']=strlen("rmans");return $book;}
	if(!strncmp($ref,"rman",strlen("rman"))) 
		{$book['num']=45;$book['len']=strlen("rman");return $book;}
	if(!strncmp($ref,"rma",strlen("rma"))) 
		{$book['num']=45;$book['len']=strlen("rma");return $book;}
	if(!strncmp($ref,"rmns",strlen("rmns"))) 
		{$book['num']=45;$book['len']=strlen("rmns");return $book;}
	if(!strncmp($ref,"rmn",strlen("rmn"))) 
		{$book['num']=45;$book['len']=strlen("rmn");return $book;}
	if(!strncmp($ref,"rm",strlen("rm"))) 
		{$book['num']=45;$book['len']=strlen("rm");return $book;}

	if(!strncmp($ref,"corinthians",strlen("corinthians"))) 
		{$book['num']=46;$book['len']=strlen("corinthians");return $book;}
	if(!strncmp($ref,"firstcorinthians",strlen("firstcorinthians"))) 
		{$book['num']=46;$book['len']=strlen("firstcorinthians");return $book;}
	if(!strncmp($ref,"1corinthians",strlen("1corinthians"))) 
		{$book['num']=46;$book['len']=strlen("1corinthians");return $book;}
	if(!strncmp($ref,"1corinthian",strlen("1corinthian"))) 
		{$book['num']=46;$book['len']=strlen("1corinthian");return $book;}
	if(!strncmp($ref,"1corinthia",strlen("1corinthia"))) 
		{$book['num']=46;$book['len']=strlen("1corinthia");return $book;}
	if(!strncmp($ref,"1corinthi",strlen("1corinthi"))) 
		{$book['num']=46;$book['len']=strlen("1corinthi");return $book;}
	if(!strncmp($ref,"1corinth",strlen("1corinth"))) 
		{$book['num']=46;$book['len']=strlen("1corinth");return $book;}
	if(!strncmp($ref,"1corintians",strlen("1corintians"))) 
		{$book['num']=46;$book['len']=strlen("1corintians");return $book;}
	if(!strncmp($ref,"1corintian",strlen("1corintian"))) 
		{$book['num']=46;$book['len']=strlen("1corintian");return $book;}
	if(!strncmp($ref,"1corintia",strlen("1corintia"))) 
		{$book['num']=46;$book['len']=strlen("1corintia");return $book;}
	if(!strncmp($ref,"1corinti",strlen("1corinti"))) 
		{$book['num']=46;$book['len']=strlen("1corinti");return $book;}
	if(!strncmp($ref,"1corint",strlen("1corint"))) 
		{$book['num']=46;$book['len']=strlen("1corint");return $book;}
	if(!strncmp($ref,"1corint",strlen("1corint"))) 
		{$book['num']=46;$book['len']=strlen("1corint");return $book;}
	if(!strncmp($ref,"1corin",strlen("1corin"))) 
		{$book['num']=46;$book['len']=strlen("1corin");return $book;}
	if(!strncmp($ref,"1cori",strlen("1cori"))) 
		{$book['num']=46;$book['len']=strlen("1cori");return $book;}
	if(!strncmp($ref,"1corenthians",strlen("1corenthians"))) 
		{$book['num']=46;$book['len']=strlen("1corenthians");return $book;}
	if(!strncmp($ref,"1corenthian",strlen("1corenthian"))) 
		{$book['num']=46;$book['len']=strlen("1corenthian");return $book;}
	if(!strncmp($ref,"1corenthia",strlen("1corenthia"))) 
		{$book['num']=46;$book['len']=strlen("1corenthia");return $book;}
	if(!strncmp($ref,"1corenthi",strlen("1corenthi"))) 
		{$book['num']=46;$book['len']=strlen("1corenthi");return $book;}
	if(!strncmp($ref,"1corenth",strlen("1corenth"))) 
		{$book['num']=46;$book['len']=strlen("1corenth");return $book;}
	if(!strncmp($ref,"1corentians",strlen("1corentians"))) 
		{$book['num']=46;$book['len']=strlen("1corentians");return $book;}
	if(!strncmp($ref,"1corentian",strlen("1corentian"))) 
		{$book['num']=46;$book['len']=strlen("1corentian");return $book;}
	if(!strncmp($ref,"1corentia",strlen("1corentia"))) 
		{$book['num']=46;$book['len']=strlen("1corentia");return $book;}
	if(!strncmp($ref,"1corenti",strlen("1corenti"))) 
		{$book['num']=46;$book['len']=strlen("1corenti");return $book;}
	if(!strncmp($ref,"1corent",strlen("1corent"))) 
		{$book['num']=46;$book['len']=strlen("1corent");return $book;}
	if(!strncmp($ref,"1corent",strlen("1corent"))) 
		{$book['num']=46;$book['len']=strlen("1corent");return $book;}
	if(!strncmp($ref,"1coren",strlen("1coren"))) 
		{$book['num']=46;$book['len']=strlen("1coren");return $book;}
	if(!strncmp($ref,"1core",strlen("1core"))) 
		{$book['num']=46;$book['len']=strlen("1core");return $book;}
	if(!strncmp($ref,"1cor",strlen("1cor"))) 
		{$book['num']=46;$book['len']=strlen("1cor");return $book;}
	if(!strncmp($ref,"1co",strlen("1co"))) 
		{$book['num']=46;$book['len']=strlen("1co");return $book;}
	if(!strncmp($ref,"icorinthians",strlen("icorinthians"))) 
		{$book['num']=46;$book['len']=strlen("icorinthians");return $book;}
	if(!strncmp($ref,"icorinthian",strlen("icorinthian"))) 
		{$book['num']=46;$book['len']=strlen("icorinthian");return $book;}
	if(!strncmp($ref,"icorinthia",strlen("icorinthia"))) 
		{$book['num']=46;$book['len']=strlen("icorinthia");return $book;}
	if(!strncmp($ref,"icorinthi",strlen("icorinthi"))) 
		{$book['num']=46;$book['len']=strlen("icorinthi");return $book;}
	if(!strncmp($ref,"icorinth",strlen("icorinth"))) 
		{$book['num']=46;$book['len']=strlen("icorinth");return $book;}
	if(!strncmp($ref,"icorintians",strlen("icorintians"))) 
		{$book['num']=46;$book['len']=strlen("icorintians");return $book;}
	if(!strncmp($ref,"icorintian",strlen("icorintian"))) 
		{$book['num']=46;$book['len']=strlen("icorintian");return $book;}
	if(!strncmp($ref,"icorintia",strlen("icorintia"))) 
		{$book['num']=46;$book['len']=strlen("icorintia");return $book;}
	if(!strncmp($ref,"icorinti",strlen("icorinti"))) 
		{$book['num']=46;$book['len']=strlen("icorinti");return $book;}
	if(!strncmp($ref,"icorint",strlen("icorint"))) 
		{$book['num']=46;$book['len']=strlen("icorint");return $book;}
	if(!strncmp($ref,"icorint",strlen("icorint"))) 
		{$book['num']=46;$book['len']=strlen("icorint");return $book;}
	if(!strncmp($ref,"icorin",strlen("icorin"))) 
		{$book['num']=46;$book['len']=strlen("icorin");return $book;}
	if(!strncmp($ref,"icori",strlen("icori"))) 
		{$book['num']=46;$book['len']=strlen("icori");return $book;}
	if(!strncmp($ref,"icorenthians",strlen("icorenthians"))) 
		{$book['num']=46;$book['len']=strlen("icorenthians");return $book;}
	if(!strncmp($ref,"icorenthian",strlen("icorenthian"))) 
		{$book['num']=46;$book['len']=strlen("icorenthian");return $book;}
	if(!strncmp($ref,"icorenthia",strlen("icorenthia"))) 
		{$book['num']=46;$book['len']=strlen("icorenthia");return $book;}
	if(!strncmp($ref,"icorenthi",strlen("icorenthi"))) 
		{$book['num']=46;$book['len']=strlen("icorenthi");return $book;}
	if(!strncmp($ref,"icorenth",strlen("icorenth"))) 
		{$book['num']=46;$book['len']=strlen("icorenth");return $book;}
	if(!strncmp($ref,"icorentians",strlen("icorentians"))) 
		{$book['num']=46;$book['len']=strlen("icorentians");return $book;}
	if(!strncmp($ref,"icorentian",strlen("icorentian"))) 
		{$book['num']=46;$book['len']=strlen("icorentian");return $book;}
	if(!strncmp($ref,"icorentia",strlen("icorentia"))) 
		{$book['num']=46;$book['len']=strlen("icorentia");return $book;}
	if(!strncmp($ref,"icorenti",strlen("icorenti"))) 
		{$book['num']=46;$book['len']=strlen("icorenti");return $book;}
	if(!strncmp($ref,"icorent",strlen("icorent"))) 
		{$book['num']=46;$book['len']=strlen("icorent");return $book;}
	if(!strncmp($ref,"icorent",strlen("icorent"))) 
		{$book['num']=46;$book['len']=strlen("icorent");return $book;}
	if(!strncmp($ref,"icoren",strlen("icoren"))) 
		{$book['num']=46;$book['len']=strlen("icoren");return $book;}
	if(!strncmp($ref,"icore",strlen("icore"))) 
		{$book['num']=46;$book['len']=strlen("icore");return $book;}
	if(!strncmp($ref,"icor",strlen("icor"))) 
		{$book['num']=46;$book['len']=strlen("icor");return $book;}
	if(!strncmp($ref,"ico",strlen("ico"))) 
		{$book['num']=46;$book['len']=strlen("ico");return $book;}

	if(!strncmp($ref,"secondcorinthians",strlen("secondcorinthians"))) 
		{$book['num']=47;$book['len']=strlen("secondcorinthians");return $book;}
	if(!strncmp($ref,"2corinthians",strlen("2corinthians"))) 
		{$book['num']=47;$book['len']=strlen("2corinthians");return $book;}
	if(!strncmp($ref,"2corinthian",strlen("2corinthian"))) 
		{$book['num']=47;$book['len']=strlen("2corinthian");return $book;}
	if(!strncmp($ref,"2corinthia",strlen("2corinthia"))) 
		{$book['num']=47;$book['len']=strlen("2corinthia");return $book;}
	if(!strncmp($ref,"2corinthi",strlen("2corinthi"))) 
		{$book['num']=47;$book['len']=strlen("2corinthi");return $book;}
	if(!strncmp($ref,"2corinth",strlen("2corinth"))) 
		{$book['num']=47;$book['len']=strlen("2corinth");return $book;}
	if(!strncmp($ref,"2corintians",strlen("2corintians"))) 
		{$book['num']=47;$book['len']=strlen("2corintians");return $book;}
	if(!strncmp($ref,"2corintian",strlen("2corintian"))) 
		{$book['num']=47;$book['len']=strlen("2corintian");return $book;}
	if(!strncmp($ref,"2corintia",strlen("2corintia"))) 
		{$book['num']=47;$book['len']=strlen("2corintia");return $book;}
	if(!strncmp($ref,"2corinti",strlen("2corinti"))) 
		{$book['num']=47;$book['len']=strlen("2corinti");return $book;}
	if(!strncmp($ref,"2corint",strlen("2corint"))) 
		{$book['num']=47;$book['len']=strlen("2corint");return $book;}
	if(!strncmp($ref,"2corint",strlen("2corint"))) 
		{$book['num']=47;$book['len']=strlen("2corint");return $book;}
	if(!strncmp($ref,"2corin",strlen("2corin"))) 
		{$book['num']=47;$book['len']=strlen("2corin");return $book;}
	if(!strncmp($ref,"2cori",strlen("2cori"))) 
		{$book['num']=47;$book['len']=strlen("2cori");return $book;}
	if(!strncmp($ref,"2corenthians",strlen("2corenthians"))) 
		{$book['num']=47;$book['len']=strlen("2corenthians");return $book;}
	if(!strncmp($ref,"2corenthian",strlen("2corenthian"))) 
		{$book['num']=47;$book['len']=strlen("2corenthian");return $book;}
	if(!strncmp($ref,"2corenthia",strlen("2corenthia"))) 
		{$book['num']=47;$book['len']=strlen("2corenthia");return $book;}
	if(!strncmp($ref,"2corenthi",strlen("2corenthi"))) 
		{$book['num']=47;$book['len']=strlen("2corenthi");return $book;}
	if(!strncmp($ref,"2corenth",strlen("2corenth"))) 
		{$book['num']=47;$book['len']=strlen("2corenth");return $book;}
	if(!strncmp($ref,"2corentians",strlen("2corentians"))) 
		{$book['num']=47;$book['len']=strlen("2corentians");return $book;}
	if(!strncmp($ref,"2corentian",strlen("2corentian"))) 
		{$book['num']=47;$book['len']=strlen("2corentian");return $book;}
	if(!strncmp($ref,"2corentia",strlen("2corentia"))) 
		{$book['num']=47;$book['len']=strlen("2corentia");return $book;}
	if(!strncmp($ref,"2corenti",strlen("2corenti"))) 
		{$book['num']=47;$book['len']=strlen("2corenti");return $book;}
	if(!strncmp($ref,"2corent",strlen("2corent"))) 
		{$book['num']=47;$book['len']=strlen("2corent");return $book;}
	if(!strncmp($ref,"2corent",strlen("2corent"))) 
		{$book['num']=47;$book['len']=strlen("2corent");return $book;}
	if(!strncmp($ref,"2coren",strlen("2coren"))) 
		{$book['num']=47;$book['len']=strlen("2coren");return $book;}
	if(!strncmp($ref,"2core",strlen("2core"))) 
		{$book['num']=47;$book['len']=strlen("2core");return $book;}
	if(!strncmp($ref,"2cor",strlen("2cor"))) 
		{$book['num']=47;$book['len']=strlen("2cor");return $book;}
	if(!strncmp($ref,"2co",strlen("2co"))) 
		{$book['num']=47;$book['len']=strlen("2co");return $book;}
	if(!strncmp($ref,"iicorinthians",strlen("iicorinthians"))) 
		{$book['num']=47;$book['len']=strlen("iicorinthians");return $book;}
	if(!strncmp($ref,"iicorinthian",strlen("iicorinthian"))) 
		{$book['num']=47;$book['len']=strlen("iicorinthian");return $book;}
	if(!strncmp($ref,"iicorinthia",strlen("iicorinthia"))) 
		{$book['num']=47;$book['len']=strlen("iicorinthia");return $book;}
	if(!strncmp($ref,"iicorinthi",strlen("iicorinthi"))) 
		{$book['num']=47;$book['len']=strlen("iicorinthi");return $book;}
	if(!strncmp($ref,"iicorinth",strlen("iicorinth"))) 
		{$book['num']=47;$book['len']=strlen("iicorinth");return $book;}
	if(!strncmp($ref,"iicorintians",strlen("iicorintians"))) 
		{$book['num']=47;$book['len']=strlen("iicorintians");return $book;}
	if(!strncmp($ref,"iicorintian",strlen("iicorintian"))) 
		{$book['num']=47;$book['len']=strlen("iicorintian");return $book;}
	if(!strncmp($ref,"iicorintia",strlen("iicorintia"))) 
		{$book['num']=47;$book['len']=strlen("iicorintia");return $book;}
	if(!strncmp($ref,"iicorinti",strlen("iicorinti"))) 
		{$book['num']=47;$book['len']=strlen("iicorinti");return $book;}
	if(!strncmp($ref,"iicorint",strlen("iicorint"))) 
		{$book['num']=47;$book['len']=strlen("iicorint");return $book;}
	if(!strncmp($ref,"iicorint",strlen("iicorint"))) 
		{$book['num']=47;$book['len']=strlen("iicorint");return $book;}
	if(!strncmp($ref,"iicorin",strlen("iicorin"))) 
		{$book['num']=47;$book['len']=strlen("iicorin");return $book;}
	if(!strncmp($ref,"iicori",strlen("iicori"))) 
		{$book['num']=47;$book['len']=strlen("iicori");return $book;}
	if(!strncmp($ref,"iicorenthians",strlen("iicorenthians"))) 
		{$book['num']=47;$book['len']=strlen("iicorenthians");return $book;}
	if(!strncmp($ref,"iicorenthian",strlen("iicorenthian"))) 
		{$book['num']=47;$book['len']=strlen("iicorenthian");return $book;}
	if(!strncmp($ref,"iicorenthia",strlen("iicorenthia"))) 
		{$book['num']=47;$book['len']=strlen("iicorenthia");return $book;}
	if(!strncmp($ref,"iicorenthi",strlen("iicorenthi"))) 
		{$book['num']=47;$book['len']=strlen("iicorenthi");return $book;}
	if(!strncmp($ref,"iicorenth",strlen("iicorenth"))) 
		{$book['num']=47;$book['len']=strlen("iicorenth");return $book;}
	if(!strncmp($ref,"iicorentians",strlen("iicorentians"))) 
		{$book['num']=47;$book['len']=strlen("iicorentians");return $book;}
	if(!strncmp($ref,"iicorentian",strlen("iicorentian"))) 
		{$book['num']=47;$book['len']=strlen("iicorentian");return $book;}
	if(!strncmp($ref,"iicorentia",strlen("iicorentia"))) 
		{$book['num']=47;$book['len']=strlen("iicorentia");return $book;}
	if(!strncmp($ref,"iicorenti",strlen("iicorenti"))) 
		{$book['num']=47;$book['len']=strlen("iicorenti");return $book;}
	if(!strncmp($ref,"iicorent",strlen("iicorent"))) 
		{$book['num']=47;$book['len']=strlen("iicorent");return $book;}
	if(!strncmp($ref,"iicorent",strlen("iicorent"))) 
		{$book['num']=47;$book['len']=strlen("iicorent");return $book;}
	if(!strncmp($ref,"iicoren",strlen("iicoren"))) 
		{$book['num']=47;$book['len']=strlen("iicoren");return $book;}
	if(!strncmp($ref,"iicore",strlen("iicore"))) 
		{$book['num']=47;$book['len']=strlen("iicore");return $book;}
	if(!strncmp($ref,"iicor",strlen("iicor"))) 
		{$book['num']=47;$book['len']=strlen("iicor");return $book;}
	if(!strncmp($ref,"iico",strlen("iico"))) 
		{$book['num']=47;$book['len']=strlen("iico");return $book;}

	if(!strncmp($ref,"galatians",strlen("galatians"))) 
		{$book['num']=48;$book['len']=strlen("galatians");return $book;}
	if(!strncmp($ref,"galatian",strlen("galatian"))) 
		{$book['num']=48;$book['len']=strlen("galatian");return $book;}
	if(!strncmp($ref,"galatia",strlen("galatia"))) 
		{$book['num']=48;$book['len']=strlen("galatia");return $book;}
	if(!strncmp($ref,"galations",strlen("galations"))) 
		{$book['num']=48;$book['len']=strlen("galations");return $book;}
	if(!strncmp($ref,"galation",strlen("galation"))) 
		{$book['num']=48;$book['len']=strlen("galation");return $book;}
	if(!strncmp($ref,"galatio",strlen("galatio"))) 
		{$book['num']=48;$book['len']=strlen("galatio");return $book;}
	if(!strncmp($ref,"galati",strlen("galati"))) 
		{$book['num']=48;$book['len']=strlen("galati");return $book;}
	if(!strncmp($ref,"galat",strlen("galat"))) 
		{$book['num']=48;$book['len']=strlen("galat");return $book;}
	if(!strncmp($ref,"gala",strlen("gala"))) 
		{$book['num']=48;$book['len']=strlen("gala");return $book;}
	if(!strncmp($ref,"gal",strlen("gal"))) 
		{$book['num']=48;$book['len']=strlen("gal");return $book;}
	if(!strncmp($ref,"glatians",strlen("glatians"))) 
		{$book['num']=48;$book['len']=strlen("glatians");return $book;}
	if(!strncmp($ref,"glatian",strlen("glatian"))) 
		{$book['num']=48;$book['len']=strlen("glatian");return $book;}
	if(!strncmp($ref,"glatia",strlen("glatia"))) 
		{$book['num']=48;$book['len']=strlen("glatia");return $book;}
	if(!strncmp($ref,"glations",strlen("glations"))) 
		{$book['num']=48;$book['len']=strlen("glations");return $book;}
	if(!strncmp($ref,"glation",strlen("glation"))) 
		{$book['num']=48;$book['len']=strlen("glation");return $book;}
	if(!strncmp($ref,"glatio",strlen("glatio"))) 
		{$book['num']=48;$book['len']=strlen("glatio");return $book;}
	if(!strncmp($ref,"glati",strlen("glati"))) 
		{$book['num']=48;$book['len']=strlen("glati");return $book;}
	if(!strncmp($ref,"glat",strlen("glat"))) 
		{$book['num']=48;$book['len']=strlen("glat");return $book;}
	if(!strncmp($ref,"gla",strlen("gla"))) 
		{$book['num']=48;$book['len']=strlen("gla");return $book;}
	if(!strncmp($ref,"gl",strlen("gl"))) 
		{$book['num']=48;$book['len']=strlen("gl");return $book;}
	if(!strncmp($ref,"ga",strlen("ga"))) 
		{$book['num']=48;$book['len']=strlen("ga");return $book;}

	if(!strncmp($ref,"ephesians",strlen("ephesians"))) 
		{$book['num']=49;$book['len']=strlen("ephesians");return $book;}
	if(!strncmp($ref,"ephesian",strlen("ephesian"))) 
		{$book['num']=49;$book['len']=strlen("ephesian");return $book;}
	if(!strncmp($ref,"ephesia",strlen("ephesia"))) 
		{$book['num']=49;$book['len']=strlen("ephesia");return $book;}
	if(!strncmp($ref,"ephesions",strlen("ephesions"))) 
		{$book['num']=49;$book['len']=strlen("ephesions");return $book;}
	if(!strncmp($ref,"ephesion",strlen("ephesion"))) 
		{$book['num']=49;$book['len']=strlen("ephesion");return $book;}
	if(!strncmp($ref,"ephesio",strlen("ephesio"))) 
		{$book['num']=49;$book['len']=strlen("ephesio");return $book;}
	if(!strncmp($ref,"ephesi",strlen("ephesi"))) 
		{$book['num']=49;$book['len']=strlen("ephesi");return $book;}
	if(!strncmp($ref,"ephes",strlen("ephes"))) 
		{$book['num']=49;$book['len']=strlen("ephes");return $book;}
	if(!strncmp($ref,"ephe",strlen("ephe"))) 
		{$book['num']=49;$book['len']=strlen("ephe");return $book;}
	if(!strncmp($ref,"ephisians",strlen("ephisians"))) 
		{$book['num']=49;$book['len']=strlen("ephisians");return $book;}
	if(!strncmp($ref,"ephisian",strlen("ephisian"))) 
		{$book['num']=49;$book['len']=strlen("ephisian");return $book;}
	if(!strncmp($ref,"ephisia",strlen("ephisia"))) 
		{$book['num']=49;$book['len']=strlen("ephisia");return $book;}
	if(!strncmp($ref,"ephisions",strlen("ephisions"))) 
		{$book['num']=49;$book['len']=strlen("ephisions");return $book;}
	if(!strncmp($ref,"ephision",strlen("ephision"))) 
		{$book['num']=49;$book['len']=strlen("ephision");return $book;}
	if(!strncmp($ref,"ephisio",strlen("ephisio"))) 
		{$book['num']=49;$book['len']=strlen("ephisio");return $book;}
	if(!strncmp($ref,"ephisi",strlen("ephisi"))) 
		{$book['num']=49;$book['len']=strlen("ephisi");return $book;}
	if(!strncmp($ref,"ephis",strlen("ephis"))) 
		{$book['num']=49;$book['len']=strlen("ephis");return $book;}
	if(!strncmp($ref,"ephi",strlen("ephi"))) 
		{$book['num']=49;$book['len']=strlen("ephi");return $book;}
	if(!strncmp($ref,"eph",strlen("eph"))) 
		{$book['num']=49;$book['len']=strlen("eph");return $book;}
	if(!strncmp($ref,"efesians",strlen("efesians"))) 
		{$book['num']=49;$book['len']=strlen("efesians");return $book;}
	if(!strncmp($ref,"efesian",strlen("efesian"))) 
		{$book['num']=49;$book['len']=strlen("efesian");return $book;}
	if(!strncmp($ref,"efesia",strlen("efesia"))) 
		{$book['num']=49;$book['len']=strlen("efesia");return $book;}
	if(!strncmp($ref,"efesions",strlen("efesions"))) 
		{$book['num']=49;$book['len']=strlen("efesions");return $book;}
	if(!strncmp($ref,"efesion",strlen("efesion"))) 
		{$book['num']=49;$book['len']=strlen("efesion");return $book;}
	if(!strncmp($ref,"efesio",strlen("efesio"))) 
		{$book['num']=49;$book['len']=strlen("efesio");return $book;}
	if(!strncmp($ref,"efesi",strlen("efesi"))) 
		{$book['num']=49;$book['len']=strlen("efesi");return $book;}
	if(!strncmp($ref,"efes",strlen("efes"))) 
		{$book['num']=49;$book['len']=strlen("efes");return $book;}
	if(!strncmp($ref,"efe",strlen("efe"))) 
		{$book['num']=49;$book['len']=strlen("efe");return $book;}
	if(!strncmp($ref,"ef",strlen("ef"))) 
		{$book['num']=49;$book['len']=strlen("ef");return $book;}
	if(!strncmp($ref,"ep",strlen("ep"))) 
		{$book['num']=49;$book['len']=strlen("ep");return $book;}

	if(!strncmp($ref,"philippians",strlen("philippians"))) 
		{$book['num']=50;$book['len']=strlen("philippians");return $book;}
	if(!strncmp($ref,"philippian",strlen("philippian"))) 
		{$book['num']=50;$book['len']=strlen("philippian");return $book;}
	if(!strncmp($ref,"philippia",strlen("philippia"))) 
		{$book['num']=50;$book['len']=strlen("philippia");return $book;}
	if(!strncmp($ref,"philippi",strlen("philippi"))) 
		{$book['num']=50;$book['len']=strlen("philippi");return $book;}
	if(!strncmp($ref,"philipians",strlen("philipians"))) 
		{$book['num']=50;$book['len']=strlen("philipians");return $book;}
	if(!strncmp($ref,"philipian",strlen("philipian"))) 
		{$book['num']=50;$book['len']=strlen("philipian");return $book;}
	if(!strncmp($ref,"philipia",strlen("philipia"))) 
		{$book['num']=50;$book['len']=strlen("philipia");return $book;}
	if(!strncmp($ref,"philipi",strlen("philipi"))) 
		{$book['num']=50;$book['len']=strlen("philipi");return $book;}
	if(!strncmp($ref,"philip",strlen("philip"))) 
		{$book['num']=50;$book['len']=strlen("philip");return $book;}
	if(!strncmp($ref,"phili",strlen("phili"))) 
		{$book['num']=50;$book['len']=strlen("phili");return $book;}
	if(!strncmp($ref,"phillippians",strlen("phillippians"))) 
		{$book['num']=50;$book['len']=strlen("phillippians");return $book;}
	if(!strncmp($ref,"phillippian",strlen("phillippian"))) 
		{$book['num']=50;$book['len']=strlen("phillippian");return $book;}
	if(!strncmp($ref,"phillippia",strlen("phillippia"))) 
		{$book['num']=50;$book['len']=strlen("phillippia");return $book;}
	if(!strncmp($ref,"phillippi",strlen("phillippi"))) 
		{$book['num']=50;$book['len']=strlen("phillippi");return $book;}
	if(!strncmp($ref,"phillipians",strlen("phillipians"))) 
		{$book['num']=50;$book['len']=strlen("phillipians");return $book;}
	if(!strncmp($ref,"phillipian",strlen("phillipian"))) 
		{$book['num']=50;$book['len']=strlen("phillipian");return $book;}
	if(!strncmp($ref,"phillipia",strlen("phillipia"))) 
		{$book['num']=50;$book['len']=strlen("phillipia");return $book;}
	if(!strncmp($ref,"phillipi",strlen("phillipi"))) 
		{$book['num']=50;$book['len']=strlen("phillipi");return $book;}
	if(!strncmp($ref,"phillip",strlen("phillip"))) 
		{$book['num']=50;$book['len']=strlen("phillip");return $book;}
	if(!strncmp($ref,"philli",strlen("philli"))) 
		{$book['num']=50;$book['len']=strlen("philli");return $book;}
	if(!strncmp($ref,"phill",strlen("phill"))) 
		{$book['num']=50;$book['len']=strlen("phill");return $book;}
	if(!strncmp($ref,"php",strlen("php"))) 
		{$book['num']=50;$book['len']=strlen("php");return $book;}

	if(!strncmp($ref,"colossians",strlen("colossians"))) 
		{$book['num']=51;$book['len']=strlen("colossians");return $book;}
	if(!strncmp($ref,"colossian",strlen("colossian"))) 
		{$book['num']=51;$book['len']=strlen("colossian");return $book;}
	if(!strncmp($ref,"colossia",strlen("colossia"))) 
		{$book['num']=51;$book['len']=strlen("colossia");return $book;}
	if(!strncmp($ref,"colossions",strlen("colossions"))) 
		{$book['num']=51;$book['len']=strlen("colossions");return $book;}
	if(!strncmp($ref,"colossion",strlen("colossion"))) 
		{$book['num']=51;$book['len']=strlen("colossion");return $book;}
	if(!strncmp($ref,"colossio",strlen("colossio"))) 
		{$book['num']=51;$book['len']=strlen("colossio");return $book;}
	if(!strncmp($ref,"colossi",strlen("colossi"))) 
		{$book['num']=51;$book['len']=strlen("colossi");return $book;}
	if(!strncmp($ref,"colosians",strlen("colosians"))) 
		{$book['num']=51;$book['len']=strlen("colosians");return $book;}
	if(!strncmp($ref,"colosian",strlen("colosian"))) 
		{$book['num']=51;$book['len']=strlen("colosian");return $book;}
	if(!strncmp($ref,"colosia",strlen("colosia"))) 
		{$book['num']=51;$book['len']=strlen("colosia");return $book;}
	if(!strncmp($ref,"colosions",strlen("colosions"))) 
		{$book['num']=51;$book['len']=strlen("colosions");return $book;}
	if(!strncmp($ref,"colosion",strlen("colosion"))) 
		{$book['num']=51;$book['len']=strlen("colosion");return $book;}
	if(!strncmp($ref,"colosio",strlen("colosio"))) 
		{$book['num']=51;$book['len']=strlen("colosio");return $book;}
	if(!strncmp($ref,"colosi",strlen("colosi"))) 
		{$book['num']=51;$book['len']=strlen("colosi");return $book;}
	if(!strncmp($ref,"coloss",strlen("coloss"))) 
		{$book['num']=51;$book['len']=strlen("coloss");return $book;}
	if(!strncmp($ref,"colos",strlen("colos"))) 
		{$book['num']=51;$book['len']=strlen("colos");return $book;}
	if(!strncmp($ref,"colo",strlen("colo"))) 
		{$book['num']=51;$book['len']=strlen("colo");return $book;}
	if(!strncmp($ref,"collossians",strlen("collossians"))) 
		{$book['num']=51;$book['len']=strlen("collossians");return $book;}
	if(!strncmp($ref,"collossian",strlen("collossian"))) 
		{$book['num']=51;$book['len']=strlen("collossian");return $book;}
	if(!strncmp($ref,"collossia",strlen("collossia"))) 
		{$book['num']=51;$book['len']=strlen("collossia");return $book;}
	if(!strncmp($ref,"collossions",strlen("collossions"))) 
		{$book['num']=51;$book['len']=strlen("collossions");return $book;}
	if(!strncmp($ref,"collossion",strlen("collossion"))) 
		{$book['num']=51;$book['len']=strlen("collossion");return $book;}
	if(!strncmp($ref,"collossio",strlen("collossio"))) 
		{$book['num']=51;$book['len']=strlen("collossio");return $book;}
	if(!strncmp($ref,"collossi",strlen("collossi"))) 
		{$book['num']=51;$book['len']=strlen("collossi");return $book;}
	if(!strncmp($ref,"collosians",strlen("collosians"))) 
		{$book['num']=51;$book['len']=strlen("collosians");return $book;}
	if(!strncmp($ref,"collosian",strlen("collosian"))) 
		{$book['num']=51;$book['len']=strlen("collosian");return $book;}
	if(!strncmp($ref,"collosia",strlen("collosia"))) 
		{$book['num']=51;$book['len']=strlen("collosia");return $book;}
	if(!strncmp($ref,"collosions",strlen("collosions"))) 
		{$book['num']=51;$book['len']=strlen("collosions");return $book;}
	if(!strncmp($ref,"collosion",strlen("collosion"))) 
		{$book['num']=51;$book['len']=strlen("collosion");return $book;}
	if(!strncmp($ref,"collosio",strlen("collosio"))) 
		{$book['num']=51;$book['len']=strlen("collosio");return $book;}
	if(!strncmp($ref,"collosi",strlen("collosi"))) 
		{$book['num']=51;$book['len']=strlen("collosi");return $book;}
	if(!strncmp($ref,"colloss",strlen("colloss"))) 
		{$book['num']=51;$book['len']=strlen("colloss");return $book;}
	if(!strncmp($ref,"collos",strlen("collos"))) 
		{$book['num']=51;$book['len']=strlen("collos");return $book;}
	if(!strncmp($ref,"collo",strlen("collo"))) 
		{$book['num']=51;$book['len']=strlen("collo");return $book;}
	if(!strncmp($ref,"coll",strlen("coll"))) 
		{$book['num']=51;$book['len']=strlen("coll");return $book;}
	if(!strncmp($ref,"col",strlen("col"))) 
		{$book['num']=51;$book['len']=strlen("col");return $book;}

	if(!strncmp($ref,"thessalonians",strlen("thessalonians"))) 
		{$book['num']=52;$book['len']=strlen("thessalonians");return $book;}
	if(!strncmp($ref,"firstthessalonians",strlen("firstthessalonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthessalonians");return $book;}
	if(!strncmp($ref,"1thessalonians",strlen("1thessalonians"))) 
		{$book['num']=52;$book['len']=strlen("1thessalonians");return $book;}
	if(!strncmp($ref,"1thessalonian",strlen("1thessalonian"))) 
		{$book['num']=52;$book['len']=strlen("1thessalonian");return $book;}
	if(!strncmp($ref,"1thessalonia",strlen("1thessalonia"))) 
		{$book['num']=52;$book['len']=strlen("1thessalonia");return $book;}
	if(!strncmp($ref,"1thessaloni",strlen("1thessaloni"))) 
		{$book['num']=52;$book['len']=strlen("1thessaloni");return $book;}
	if(!strncmp($ref,"thessaloneans",strlen("thessaloneans"))) 
		{$book['num']=52;$book['len']=strlen("thessaloneans");return $book;}
	if(!strncmp($ref,"firstthessaloneans",strlen("firstthessaloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthessaloneans");return $book;}
	if(!strncmp($ref,"1thessaloneans",strlen("1thessaloneans"))) 
		{$book['num']=52;$book['len']=strlen("1thessaloneans");return $book;}
	if(!strncmp($ref,"1thessalonean",strlen("1thessalonean"))) 
		{$book['num']=52;$book['len']=strlen("1thessalonean");return $book;}
	if(!strncmp($ref,"1thessalonea",strlen("1thessalonea"))) 
		{$book['num']=52;$book['len']=strlen("1thessalonea");return $book;}
	if(!strncmp($ref,"1thessalone",strlen("1thessalone"))) 
		{$book['num']=52;$book['len']=strlen("1thessalone");return $book;}
	if(!strncmp($ref,"1thessalon",strlen("1thessalon"))) 
		{$book['num']=52;$book['len']=strlen("1thessalon");return $book;}
	if(!strncmp($ref,"1thessalo",strlen("1thessalo"))) 
		{$book['num']=52;$book['len']=strlen("1thessalo");return $book;}
	if(!strncmp($ref,"thessallonians",strlen("thessallonians"))) 
		{$book['num']=52;$book['len']=strlen("thessallonians");return $book;}
	if(!strncmp($ref,"firstthessallonians",strlen("firstthessallonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthessallonians");return $book;}
	if(!strncmp($ref,"1thessallonians",strlen("1thessallonians"))) 
		{$book['num']=52;$book['len']=strlen("1thessallonians");return $book;}
	if(!strncmp($ref,"1thessallonian",strlen("1thessallonian"))) 
		{$book['num']=52;$book['len']=strlen("1thessallonian");return $book;}
	if(!strncmp($ref,"1thessallonia",strlen("1thessallonia"))) 
		{$book['num']=52;$book['len']=strlen("1thessallonia");return $book;}
	if(!strncmp($ref,"1thessalloni",strlen("1thessalloni"))) 
		{$book['num']=52;$book['len']=strlen("1thessalloni");return $book;}
	if(!strncmp($ref,"thessalloneans",strlen("thessalloneans"))) 
		{$book['num']=52;$book['len']=strlen("thessalloneans");return $book;}
	if(!strncmp($ref,"firstthessalloneans",strlen("firstthessalloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthessalloneans");return $book;}
	if(!strncmp($ref,"1thessalloneans",strlen("1thessalloneans"))) 
		{$book['num']=52;$book['len']=strlen("1thessalloneans");return $book;}
	if(!strncmp($ref,"1thessallonean",strlen("1thessallonean"))) 
		{$book['num']=52;$book['len']=strlen("1thessallonean");return $book;}
	if(!strncmp($ref,"1thessallonea",strlen("1thessallonea"))) 
		{$book['num']=52;$book['len']=strlen("1thessallonea");return $book;}
	if(!strncmp($ref,"1thessallone",strlen("1thessallone"))) 
		{$book['num']=52;$book['len']=strlen("1thessallone");return $book;}
	if(!strncmp($ref,"1thessallon",strlen("1thessallon"))) 
		{$book['num']=52;$book['len']=strlen("1thessallon");return $book;}
	if(!strncmp($ref,"1thessallo",strlen("1thessallo"))) 
		{$book['num']=52;$book['len']=strlen("1thessallo");return $book;}
	if(!strncmp($ref,"1thessall",strlen("1thessall"))) 
		{$book['num']=52;$book['len']=strlen("1thessall");return $book;}
	if(!strncmp($ref,"1thessal",strlen("1thessal"))) 
		{$book['num']=52;$book['len']=strlen("1thessal");return $book;}
	if(!strncmp($ref,"1thessa",strlen("1thessa"))) 
		{$book['num']=52;$book['len']=strlen("1thessa");return $book;}
	if(!strncmp($ref,"thesalonians",strlen("thesalonians"))) 
		{$book['num']=52;$book['len']=strlen("thesalonians");return $book;}
	if(!strncmp($ref,"firstthesalonians",strlen("firstthesalonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthesalonians");return $book;}
	if(!strncmp($ref,"1thesalonians",strlen("1thesalonians"))) 
		{$book['num']=52;$book['len']=strlen("1thesalonians");return $book;}
	if(!strncmp($ref,"1thesalonian",strlen("1thesalonian"))) 
		{$book['num']=52;$book['len']=strlen("1thesalonian");return $book;}
	if(!strncmp($ref,"1thesalonia",strlen("1thesalonia"))) 
		{$book['num']=52;$book['len']=strlen("1thesalonia");return $book;}
	if(!strncmp($ref,"1thesaloni",strlen("1thesaloni"))) 
		{$book['num']=52;$book['len']=strlen("1thesaloni");return $book;}
	if(!strncmp($ref,"thesaloneans",strlen("thesaloneans"))) 
		{$book['num']=52;$book['len']=strlen("thesaloneans");return $book;}
	if(!strncmp($ref,"firstthesaloneans",strlen("firstthesaloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthesaloneans");return $book;}
	if(!strncmp($ref,"1thesaloneans",strlen("1thesaloneans"))) 
		{$book['num']=52;$book['len']=strlen("1thesaloneans");return $book;}
	if(!strncmp($ref,"1thesalonean",strlen("1thesalonean"))) 
		{$book['num']=52;$book['len']=strlen("1thesalonean");return $book;}
	if(!strncmp($ref,"1thesalonea",strlen("1thesalonea"))) 
		{$book['num']=52;$book['len']=strlen("1thesalonea");return $book;}
	if(!strncmp($ref,"1thesalone",strlen("1thesalone"))) 
		{$book['num']=52;$book['len']=strlen("1thesalone");return $book;}
	if(!strncmp($ref,"1thesalon",strlen("1thesalon"))) 
		{$book['num']=52;$book['len']=strlen("1thesalon");return $book;}
	if(!strncmp($ref,"1thesalo",strlen("1thesalo"))) 
		{$book['num']=52;$book['len']=strlen("1thesalo");return $book;}
	if(!strncmp($ref,"thesallonians",strlen("thesallonians"))) 
		{$book['num']=52;$book['len']=strlen("thesallonians");return $book;}
	if(!strncmp($ref,"firstthesallonians",strlen("firstthesallonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthesallonians");return $book;}
	if(!strncmp($ref,"1thesallonians",strlen("1thesallonians"))) 
		{$book['num']=52;$book['len']=strlen("1thesallonians");return $book;}
	if(!strncmp($ref,"1thesallonian",strlen("1thesallonian"))) 
		{$book['num']=52;$book['len']=strlen("1thesallonian");return $book;}
	if(!strncmp($ref,"1thesallonia",strlen("1thesallonia"))) 
		{$book['num']=52;$book['len']=strlen("1thesallonia");return $book;}
	if(!strncmp($ref,"1thesalloni",strlen("1thesalloni"))) 
		{$book['num']=52;$book['len']=strlen("1thesalloni");return $book;}
	if(!strncmp($ref,"thesalloneans",strlen("thesalloneans"))) 
		{$book['num']=52;$book['len']=strlen("thesalloneans");return $book;}
	if(!strncmp($ref,"firstthesalloneans",strlen("firstthesalloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthesalloneans");return $book;}
	if(!strncmp($ref,"1thesalloneans",strlen("1thesalloneans"))) 
		{$book['num']=52;$book['len']=strlen("1thesalloneans");return $book;}
	if(!strncmp($ref,"1thesallonean",strlen("1thesallonean"))) 
		{$book['num']=52;$book['len']=strlen("1thesallonean");return $book;}
	if(!strncmp($ref,"1thesallonea",strlen("1thesallonea"))) 
		{$book['num']=52;$book['len']=strlen("1thesallonea");return $book;}
	if(!strncmp($ref,"1thesallone",strlen("1thesallone"))) 
		{$book['num']=52;$book['len']=strlen("1thesallone");return $book;}
	if(!strncmp($ref,"1thesallon",strlen("1thesallon"))) 
		{$book['num']=52;$book['len']=strlen("1thesallon");return $book;}
	if(!strncmp($ref,"1thesallo",strlen("1thesallo"))) 
		{$book['num']=52;$book['len']=strlen("1thesallo");return $book;}
	if(!strncmp($ref,"1thesall",strlen("1thesall"))) 
		{$book['num']=52;$book['len']=strlen("1thesall");return $book;}
	if(!strncmp($ref,"1thesal",strlen("1thesal"))) 
		{$book['num']=52;$book['len']=strlen("1thesal");return $book;}
	if(!strncmp($ref,"1thesa",strlen("1thesa"))) 
		{$book['num']=52;$book['len']=strlen("1thesa");return $book;}
	if(!strncmp($ref,"1thess",strlen("1thess"))) 
		{$book['num']=52;$book['len']=strlen("1thess");return $book;}
	if(!strncmp($ref,"1thes",strlen("1thes"))) 
		{$book['num']=52;$book['len']=strlen("1thes");return $book;}
	if(!strncmp($ref,"1the",strlen("1the"))) 
		{$book['num']=52;$book['len']=strlen("1the");return $book;}
	if(!strncmp($ref,"1th",strlen("1th"))) 
		{$book['num']=52;$book['len']=strlen("1th");return $book;}
	if(!strncmp($ref,"1ths",strlen("1ths"))) 
		{$book['num']=52;$book['len']=strlen("1ths");return $book;}
	if(!strncmp($ref,"ithessalonians",strlen("ithessalonians"))) 
		{$book['num']=52;$book['len']=strlen("ithessalonians");return $book;}
	if(!strncmp($ref,"ithessalonian",strlen("ithessalonian"))) 
		{$book['num']=52;$book['len']=strlen("ithessalonian");return $book;}
	if(!strncmp($ref,"ithessalonia",strlen("ithessalonia"))) 
		{$book['num']=52;$book['len']=strlen("ithessalonia");return $book;}
	if(!strncmp($ref,"ithessaloni",strlen("ithessaloni"))) 
		{$book['num']=52;$book['len']=strlen("ithessaloni");return $book;}
	if(!strncmp($ref,"thessaloneans",strlen("thessaloneans"))) 
		{$book['num']=52;$book['len']=strlen("thessaloneans");return $book;}
	if(!strncmp($ref,"firstthessaloneans",strlen("firstthessaloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthessaloneans");return $book;}
	if(!strncmp($ref,"ithessaloneans",strlen("ithessaloneans"))) 
		{$book['num']=52;$book['len']=strlen("ithessaloneans");return $book;}
	if(!strncmp($ref,"ithessalonean",strlen("ithessalonean"))) 
		{$book['num']=52;$book['len']=strlen("ithessalonean");return $book;}
	if(!strncmp($ref,"ithessalonea",strlen("ithessalonea"))) 
		{$book['num']=52;$book['len']=strlen("ithessalonea");return $book;}
	if(!strncmp($ref,"ithessalone",strlen("ithessalone"))) 
		{$book['num']=52;$book['len']=strlen("ithessalone");return $book;}
	if(!strncmp($ref,"ithessalon",strlen("ithessalon"))) 
		{$book['num']=52;$book['len']=strlen("ithessalon");return $book;}
	if(!strncmp($ref,"ithessalo",strlen("ithessalo"))) 
		{$book['num']=52;$book['len']=strlen("ithessalo");return $book;}
	if(!strncmp($ref,"thessallonians",strlen("thessallonians"))) 
		{$book['num']=52;$book['len']=strlen("thessallonians");return $book;}
	if(!strncmp($ref,"firstthessallonians",strlen("firstthessallonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthessallonians");return $book;}
	if(!strncmp($ref,"ithessallonians",strlen("ithessallonians"))) 
		{$book['num']=52;$book['len']=strlen("ithessallonians");return $book;}
	if(!strncmp($ref,"ithessallonian",strlen("ithessallonian"))) 
		{$book['num']=52;$book['len']=strlen("ithessallonian");return $book;}
	if(!strncmp($ref,"ithessallonia",strlen("ithessallonia"))) 
		{$book['num']=52;$book['len']=strlen("ithessallonia");return $book;}
	if(!strncmp($ref,"ithessalloni",strlen("ithessalloni"))) 
		{$book['num']=52;$book['len']=strlen("ithessalloni");return $book;}
	if(!strncmp($ref,"thessalloneans",strlen("thessalloneans"))) 
		{$book['num']=52;$book['len']=strlen("thessalloneans");return $book;}
	if(!strncmp($ref,"firstthessalloneans",strlen("firstthessalloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthessalloneans");return $book;}
	if(!strncmp($ref,"ithessalloneans",strlen("ithessalloneans"))) 
		{$book['num']=52;$book['len']=strlen("ithessalloneans");return $book;}
	if(!strncmp($ref,"ithessallonean",strlen("ithessallonean"))) 
		{$book['num']=52;$book['len']=strlen("ithessallonean");return $book;}
	if(!strncmp($ref,"ithessallonea",strlen("ithessallonea"))) 
		{$book['num']=52;$book['len']=strlen("ithessallonea");return $book;}
	if(!strncmp($ref,"ithessallone",strlen("ithessallone"))) 
		{$book['num']=52;$book['len']=strlen("ithessallone");return $book;}
	if(!strncmp($ref,"ithessallon",strlen("ithessallon"))) 
		{$book['num']=52;$book['len']=strlen("ithessallon");return $book;}
	if(!strncmp($ref,"ithessallo",strlen("ithessallo"))) 
		{$book['num']=52;$book['len']=strlen("ithessallo");return $book;}
	if(!strncmp($ref,"ithessall",strlen("ithessall"))) 
		{$book['num']=52;$book['len']=strlen("ithessall");return $book;}
	if(!strncmp($ref,"ithessal",strlen("ithessal"))) 
		{$book['num']=52;$book['len']=strlen("ithessal");return $book;}
	if(!strncmp($ref,"ithessa",strlen("ithessa"))) 
		{$book['num']=52;$book['len']=strlen("ithessa");return $book;}
	if(!strncmp($ref,"thesalonians",strlen("thesalonians"))) 
		{$book['num']=52;$book['len']=strlen("thesalonians");return $book;}
	if(!strncmp($ref,"firstthesalonians",strlen("firstthesalonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthesalonians");return $book;}
	if(!strncmp($ref,"ithesalonians",strlen("ithesalonians"))) 
		{$book['num']=52;$book['len']=strlen("ithesalonians");return $book;}
	if(!strncmp($ref,"ithesalonian",strlen("ithesalonian"))) 
		{$book['num']=52;$book['len']=strlen("ithesalonian");return $book;}
	if(!strncmp($ref,"ithesalonia",strlen("ithesalonia"))) 
		{$book['num']=52;$book['len']=strlen("ithesalonia");return $book;}
	if(!strncmp($ref,"ithesaloni",strlen("ithesaloni"))) 
		{$book['num']=52;$book['len']=strlen("ithesaloni");return $book;}
	if(!strncmp($ref,"thesaloneans",strlen("thesaloneans"))) 
		{$book['num']=52;$book['len']=strlen("thesaloneans");return $book;}
	if(!strncmp($ref,"firstthesaloneans",strlen("firstthesaloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthesaloneans");return $book;}
	if(!strncmp($ref,"ithesaloneans",strlen("ithesaloneans"))) 
		{$book['num']=52;$book['len']=strlen("ithesaloneans");return $book;}
	if(!strncmp($ref,"ithesalonean",strlen("ithesalonean"))) 
		{$book['num']=52;$book['len']=strlen("ithesalonean");return $book;}
	if(!strncmp($ref,"ithesalonea",strlen("ithesalonea"))) 
		{$book['num']=52;$book['len']=strlen("ithesalonea");return $book;}
	if(!strncmp($ref,"ithesalone",strlen("ithesalone"))) 
		{$book['num']=52;$book['len']=strlen("ithesalone");return $book;}
	if(!strncmp($ref,"ithesalon",strlen("ithesalon"))) 
		{$book['num']=52;$book['len']=strlen("ithesalon");return $book;}
	if(!strncmp($ref,"ithesalo",strlen("ithesalo"))) 
		{$book['num']=52;$book['len']=strlen("ithesalo");return $book;}
	if(!strncmp($ref,"thesallonians",strlen("thesallonians"))) 
		{$book['num']=52;$book['len']=strlen("thesallonians");return $book;}
	if(!strncmp($ref,"firstthesallonians",strlen("firstthesallonians"))) 
		{$book['num']=52;$book['len']=strlen("firstthesallonians");return $book;}
	if(!strncmp($ref,"ithesallonians",strlen("ithesallonians"))) 
		{$book['num']=52;$book['len']=strlen("ithesallonians");return $book;}
	if(!strncmp($ref,"ithesallonian",strlen("ithesallonian"))) 
		{$book['num']=52;$book['len']=strlen("ithesallonian");return $book;}
	if(!strncmp($ref,"ithesallonia",strlen("ithesallonia"))) 
		{$book['num']=52;$book['len']=strlen("ithesallonia");return $book;}
	if(!strncmp($ref,"ithesalloni",strlen("ithesalloni"))) 
		{$book['num']=52;$book['len']=strlen("ithesalloni");return $book;}
	if(!strncmp($ref,"thesalloneans",strlen("thesalloneans"))) 
		{$book['num']=52;$book['len']=strlen("thesalloneans");return $book;}
	if(!strncmp($ref,"firstthesalloneans",strlen("firstthesalloneans"))) 
		{$book['num']=52;$book['len']=strlen("firstthesalloneans");return $book;}
	if(!strncmp($ref,"ithesalloneans",strlen("ithesalloneans"))) 
		{$book['num']=52;$book['len']=strlen("ithesalloneans");return $book;}
	if(!strncmp($ref,"ithesallonean",strlen("ithesallonean"))) 
		{$book['num']=52;$book['len']=strlen("ithesallonean");return $book;}
	if(!strncmp($ref,"ithesallonea",strlen("ithesallonea"))) 
		{$book['num']=52;$book['len']=strlen("ithesallonea");return $book;}
	if(!strncmp($ref,"ithesallone",strlen("ithesallone"))) 
		{$book['num']=52;$book['len']=strlen("ithesallone");return $book;}
	if(!strncmp($ref,"ithesallon",strlen("ithesallon"))) 
		{$book['num']=52;$book['len']=strlen("ithesallon");return $book;}
	if(!strncmp($ref,"ithesallo",strlen("ithesallo"))) 
		{$book['num']=52;$book['len']=strlen("ithesallo");return $book;}
	if(!strncmp($ref,"ithesall",strlen("ithesall"))) 
		{$book['num']=52;$book['len']=strlen("ithesall");return $book;}
	if(!strncmp($ref,"ithesal",strlen("ithesal"))) 
		{$book['num']=52;$book['len']=strlen("ithesal");return $book;}
	if(!strncmp($ref,"ithesa",strlen("ithesa"))) 
		{$book['num']=52;$book['len']=strlen("ithesa");return $book;}
	if(!strncmp($ref,"ithess",strlen("ithess"))) 
		{$book['num']=52;$book['len']=strlen("ithess");return $book;}
	if(!strncmp($ref,"ithes",strlen("ithes"))) 
		{$book['num']=52;$book['len']=strlen("ithes");return $book;}
	if(!strncmp($ref,"ithe",strlen("ithe"))) 
		{$book['num']=52;$book['len']=strlen("ithe");return $book;}
	if(!strncmp($ref,"ith",strlen("ith"))) 
		{$book['num']=52;$book['len']=strlen("ith");return $book;}
	if(!strncmp($ref,"iths",strlen("iths"))) 
		{$book['num']=52;$book['len']=strlen("iths");return $book;}

	if(!strncmp($ref,"secondthessalonians",strlen("secondthessalonians"))) 
		{$book['num']=53;$book['len']=strlen("secondthessalonians");return $book;}
	if(!strncmp($ref,"2thessalonians",strlen("2thessalonians"))) 
		{$book['num']=53;$book['len']=strlen("2thessalonians");return $book;}
	if(!strncmp($ref,"2thessalonian",strlen("2thessalonian"))) 
		{$book['num']=53;$book['len']=strlen("2thessalonian");return $book;}
	if(!strncmp($ref,"2thessalonia",strlen("2thessalonia"))) 
		{$book['num']=53;$book['len']=strlen("2thessalonia");return $book;}
	if(!strncmp($ref,"2thessaloni",strlen("2thessaloni"))) 
		{$book['num']=53;$book['len']=strlen("2thessaloni");return $book;}
	if(!strncmp($ref,"2thessaloneans",strlen("2thessaloneans"))) 
		{$book['num']=53;$book['len']=strlen("2thessaloneans");return $book;}
	if(!strncmp($ref,"2thessalonean",strlen("2thessalonean"))) 
		{$book['num']=53;$book['len']=strlen("2thessalonean");return $book;}
	if(!strncmp($ref,"2thessalonea",strlen("2thessalonea"))) 
		{$book['num']=53;$book['len']=strlen("2thessalonea");return $book;}
	if(!strncmp($ref,"2thessalone",strlen("2thessalone"))) 
		{$book['num']=53;$book['len']=strlen("2thessalone");return $book;}
	if(!strncmp($ref,"2thessalon",strlen("2thessalon"))) 
		{$book['num']=53;$book['len']=strlen("2thessalon");return $book;}
	if(!strncmp($ref,"2thessalo",strlen("2thessalo"))) 
		{$book['num']=53;$book['len']=strlen("2thessalo");return $book;}
	if(!strncmp($ref,"2thessallonians",strlen("2thessallonians"))) 
		{$book['num']=53;$book['len']=strlen("2thessallonians");return $book;}
	if(!strncmp($ref,"2thessallonian",strlen("2thessallonian"))) 
		{$book['num']=53;$book['len']=strlen("2thessallonian");return $book;}
	if(!strncmp($ref,"2thessallonia",strlen("2thessallonia"))) 
		{$book['num']=53;$book['len']=strlen("2thessallonia");return $book;}
	if(!strncmp($ref,"2thessalloni",strlen("2thessalloni"))) 
		{$book['num']=53;$book['len']=strlen("2thessalloni");return $book;}
	if(!strncmp($ref,"2thessalloneans",strlen("2thessalloneans"))) 
		{$book['num']=53;$book['len']=strlen("2thessalloneans");return $book;}
	if(!strncmp($ref,"2thessallonean",strlen("2thessallonean"))) 
		{$book['num']=53;$book['len']=strlen("2thessallonean");return $book;}
	if(!strncmp($ref,"2thessallonea",strlen("2thessallonea"))) 
		{$book['num']=53;$book['len']=strlen("2thessallonea");return $book;}
	if(!strncmp($ref,"2thessallone",strlen("2thessallone"))) 
		{$book['num']=53;$book['len']=strlen("2thessallone");return $book;}
	if(!strncmp($ref,"2thessallon",strlen("2thessallon"))) 
		{$book['num']=53;$book['len']=strlen("2thessallon");return $book;}
	if(!strncmp($ref,"2thessallo",strlen("2thessallo"))) 
		{$book['num']=53;$book['len']=strlen("2thessallo");return $book;}
	if(!strncmp($ref,"2thessall",strlen("2thessall"))) 
		{$book['num']=53;$book['len']=strlen("2thessall");return $book;}
	if(!strncmp($ref,"2thessal",strlen("2thessal"))) 
		{$book['num']=53;$book['len']=strlen("2thessal");return $book;}
	if(!strncmp($ref,"2thessa",strlen("2thessa"))) 
		{$book['num']=53;$book['len']=strlen("2thessa");return $book;}
	if(!strncmp($ref,"2thesalonians",strlen("2thesalonians"))) 
		{$book['num']=53;$book['len']=strlen("2thesalonians");return $book;}
	if(!strncmp($ref,"2thesalonian",strlen("2thesalonian"))) 
		{$book['num']=53;$book['len']=strlen("2thesalonian");return $book;}
	if(!strncmp($ref,"2thesalonia",strlen("2thesalonia"))) 
		{$book['num']=53;$book['len']=strlen("2thesalonia");return $book;}
	if(!strncmp($ref,"2thesaloni",strlen("2thesaloni"))) 
		{$book['num']=53;$book['len']=strlen("2thesaloni");return $book;}
	if(!strncmp($ref,"2thesaloneans",strlen("2thesaloneans"))) 
		{$book['num']=53;$book['len']=strlen("2thesaloneans");return $book;}
	if(!strncmp($ref,"2thesalonean",strlen("2thesalonean"))) 
		{$book['num']=53;$book['len']=strlen("2thesalonean");return $book;}
	if(!strncmp($ref,"2thesalonea",strlen("2thesalonea"))) 
		{$book['num']=53;$book['len']=strlen("2thesalonea");return $book;}
	if(!strncmp($ref,"2thesalone",strlen("2thesalone"))) 
		{$book['num']=53;$book['len']=strlen("2thesalone");return $book;}
	if(!strncmp($ref,"2thesalon",strlen("2thesalon"))) 
		{$book['num']=53;$book['len']=strlen("2thesalon");return $book;}
	if(!strncmp($ref,"2thesalo",strlen("2thesalo"))) 
		{$book['num']=53;$book['len']=strlen("2thesalo");return $book;}
	if(!strncmp($ref,"2thesallonians",strlen("2thesallonians"))) 
		{$book['num']=53;$book['len']=strlen("2thesallonians");return $book;}
	if(!strncmp($ref,"2thesallonian",strlen("2thesallonian"))) 
		{$book['num']=53;$book['len']=strlen("2thesallonian");return $book;}
	if(!strncmp($ref,"2thesallonia",strlen("2thesallonia"))) 
		{$book['num']=53;$book['len']=strlen("2thesallonia");return $book;}
	if(!strncmp($ref,"2thesalloni",strlen("2thesalloni"))) 
		{$book['num']=53;$book['len']=strlen("2thesalloni");return $book;}
	if(!strncmp($ref,"thesalloneans",strlen("thesalloneans"))) 
		{$book['num']=53;$book['len']=strlen("thesalloneans");return $book;}
	if(!strncmp($ref,"firstthesalloneans",strlen("firstthesalloneans"))) 
		{$book['num']=53;$book['len']=strlen("firstthesalloneans");return $book;}
	if(!strncmp($ref,"2thesalloneans",strlen("2thesalloneans"))) 
		{$book['num']=53;$book['len']=strlen("2thesalloneans");return $book;}
	if(!strncmp($ref,"2thesallonean",strlen("2thesallonean"))) 
		{$book['num']=53;$book['len']=strlen("2thesallonean");return $book;}
	if(!strncmp($ref,"2thesallonea",strlen("2thesallonea"))) 
		{$book['num']=53;$book['len']=strlen("2thesallonea");return $book;}
	if(!strncmp($ref,"2thesallone",strlen("2thesallone"))) 
		{$book['num']=53;$book['len']=strlen("2thesallone");return $book;}
	if(!strncmp($ref,"2thesallon",strlen("2thesallon"))) 
		{$book['num']=53;$book['len']=strlen("2thesallon");return $book;}
	if(!strncmp($ref,"2thesallo",strlen("2thesallo"))) 
		{$book['num']=53;$book['len']=strlen("2thesallo");return $book;}
	if(!strncmp($ref,"2thesall",strlen("2thesall"))) 
		{$book['num']=53;$book['len']=strlen("2thesall");return $book;}
	if(!strncmp($ref,"2thesal",strlen("2thesal"))) 
		{$book['num']=53;$book['len']=strlen("2thesal");return $book;}
	if(!strncmp($ref,"2thesa",strlen("2thesa"))) 
		{$book['num']=53;$book['len']=strlen("2thesa");return $book;}
	if(!strncmp($ref,"2thess",strlen("2thess"))) 
		{$book['num']=53;$book['len']=strlen("2thess");return $book;}
	if(!strncmp($ref,"2thes",strlen("2thes"))) 
		{$book['num']=53;$book['len']=strlen("2thes");return $book;}
	if(!strncmp($ref,"2the",strlen("2the"))) 
		{$book['num']=53;$book['len']=strlen("2the");return $book;}
	if(!strncmp($ref,"2th",strlen("2th"))) 
		{$book['num']=53;$book['len']=strlen("2th");return $book;}
	if(!strncmp($ref,"2ths",strlen("2ths"))) 
		{$book['num']=53;$book['len']=strlen("2ths");return $book;}
	if(!strncmp($ref,"iithessalonians",strlen("iithessalonians"))) 
		{$book['num']=53;$book['len']=strlen("iithessalonians");return $book;}
	if(!strncmp($ref,"iithessalonian",strlen("iithessalonian"))) 
		{$book['num']=53;$book['len']=strlen("iithessalonian");return $book;}
	if(!strncmp($ref,"iithessalonia",strlen("iithessalonia"))) 
		{$book['num']=53;$book['len']=strlen("iithessalonia");return $book;}
	if(!strncmp($ref,"iithessaloni",strlen("iithessaloni"))) 
		{$book['num']=53;$book['len']=strlen("iithessaloni");return $book;}
	if(!strncmp($ref,"thessaloneans",strlen("thessaloneans"))) 
		{$book['num']=53;$book['len']=strlen("thessaloneans");return $book;}
	if(!strncmp($ref,"firstthessaloneans",strlen("firstthessaloneans"))) 
		{$book['num']=53;$book['len']=strlen("firstthessaloneans");return $book;}
	if(!strncmp($ref,"iithessaloneans",strlen("iithessaloneans"))) 
		{$book['num']=53;$book['len']=strlen("iithessaloneans");return $book;}
	if(!strncmp($ref,"iithessalonean",strlen("iithessalonean"))) 
		{$book['num']=53;$book['len']=strlen("iithessalonean");return $book;}
	if(!strncmp($ref,"iithessalonea",strlen("iithessalonea"))) 
		{$book['num']=53;$book['len']=strlen("iithessalonea");return $book;}
	if(!strncmp($ref,"iithessalone",strlen("iithessalone"))) 
		{$book['num']=53;$book['len']=strlen("iithessalone");return $book;}
	if(!strncmp($ref,"iithessalon",strlen("iithessalon"))) 
		{$book['num']=53;$book['len']=strlen("iithessalon");return $book;}
	if(!strncmp($ref,"iithessalo",strlen("iithessalo"))) 
		{$book['num']=53;$book['len']=strlen("iithessalo");return $book;}
	if(!strncmp($ref,"thessallonians",strlen("thessallonians"))) 
		{$book['num']=53;$book['len']=strlen("thessallonians");return $book;}
	if(!strncmp($ref,"firstthessallonians",strlen("firstthessallonians"))) 
		{$book['num']=53;$book['len']=strlen("firstthessallonians");return $book;}
	if(!strncmp($ref,"iithessallonians",strlen("iithessallonians"))) 
		{$book['num']=53;$book['len']=strlen("iithessallonians");return $book;}
	if(!strncmp($ref,"iithessallonian",strlen("iithessallonian"))) 
		{$book['num']=53;$book['len']=strlen("iithessallonian");return $book;}
	if(!strncmp($ref,"iithessallonia",strlen("iithessallonia"))) 
		{$book['num']=53;$book['len']=strlen("iithessallonia");return $book;}
	if(!strncmp($ref,"iithessalloni",strlen("iithessalloni"))) 
		{$book['num']=53;$book['len']=strlen("iithessalloni");return $book;}
	if(!strncmp($ref,"iithessalloneans",strlen("iithessalloneans"))) 
		{$book['num']=53;$book['len']=strlen("iithessalloneans");return $book;}
	if(!strncmp($ref,"iithessallonean",strlen("iithessallonean"))) 
		{$book['num']=53;$book['len']=strlen("iithessallonean");return $book;}
	if(!strncmp($ref,"iithessallonea",strlen("iithessallonea"))) 
		{$book['num']=53;$book['len']=strlen("iithessallonea");return $book;}
	if(!strncmp($ref,"iithessallone",strlen("iithessallone"))) 
		{$book['num']=53;$book['len']=strlen("iithessallone");return $book;}
	if(!strncmp($ref,"iithessallon",strlen("iithessallon"))) 
		{$book['num']=53;$book['len']=strlen("iithessallon");return $book;}
	if(!strncmp($ref,"iithessallo",strlen("iithessallo"))) 
		{$book['num']=53;$book['len']=strlen("iithessallo");return $book;}
	if(!strncmp($ref,"iithessall",strlen("iithessall"))) 
		{$book['num']=53;$book['len']=strlen("iithessall");return $book;}
	if(!strncmp($ref,"iithessal",strlen("iithessal"))) 
		{$book['num']=53;$book['len']=strlen("iithessal");return $book;}
	if(!strncmp($ref,"iithessa",strlen("iithessa"))) 
		{$book['num']=53;$book['len']=strlen("iithessa");return $book;}
	if(!strncmp($ref,"thesalonians",strlen("thesalonians"))) 
		{$book['num']=53;$book['len']=strlen("thesalonians");return $book;}
	if(!strncmp($ref,"firstthesalonians",strlen("firstthesalonians"))) 
		{$book['num']=53;$book['len']=strlen("firstthesalonians");return $book;}
	if(!strncmp($ref,"iithesalonians",strlen("iithesalonians"))) 
		{$book['num']=53;$book['len']=strlen("iithesalonians");return $book;}
	if(!strncmp($ref,"iithesalonian",strlen("iithesalonian"))) 
		{$book['num']=53;$book['len']=strlen("iithesalonian");return $book;}
	if(!strncmp($ref,"iithesalonia",strlen("iithesalonia"))) 
		{$book['num']=53;$book['len']=strlen("iithesalonia");return $book;}
	if(!strncmp($ref,"iithesaloni",strlen("iithesaloni"))) 
		{$book['num']=53;$book['len']=strlen("iithesaloni");return $book;}
	if(!strncmp($ref,"thesaloneans",strlen("thesaloneans"))) 
		{$book['num']=53;$book['len']=strlen("thesaloneans");return $book;}
	if(!strncmp($ref,"firstthesaloneans",strlen("firstthesaloneans"))) 
		{$book['num']=53;$book['len']=strlen("firstthesaloneans");return $book;}
	if(!strncmp($ref,"iithesaloneans",strlen("iithesaloneans"))) 
		{$book['num']=53;$book['len']=strlen("iithesaloneans");return $book;}
	if(!strncmp($ref,"iithesalonean",strlen("iithesalonean"))) 
		{$book['num']=53;$book['len']=strlen("iithesalonean");return $book;}
	if(!strncmp($ref,"iithesalonea",strlen("iithesalonea"))) 
		{$book['num']=53;$book['len']=strlen("iithesalonea");return $book;}
	if(!strncmp($ref,"iithesalone",strlen("iithesalone"))) 
		{$book['num']=53;$book['len']=strlen("iithesalone");return $book;}
	if(!strncmp($ref,"iithesalon",strlen("iithesalon"))) 
		{$book['num']=53;$book['len']=strlen("iithesalon");return $book;}
	if(!strncmp($ref,"iithesalo",strlen("iithesalo"))) 
		{$book['num']=53;$book['len']=strlen("iithesalo");return $book;}
	if(!strncmp($ref,"iithesallonians",strlen("iithesallonians"))) 
		{$book['num']=53;$book['len']=strlen("iithesallonians");return $book;}
	if(!strncmp($ref,"iithesallonian",strlen("iithesallonian"))) 
		{$book['num']=53;$book['len']=strlen("iithesallonian");return $book;}
	if(!strncmp($ref,"iithesallonia",strlen("iithesallonia"))) 
		{$book['num']=53;$book['len']=strlen("iithesallonia");return $book;}
	if(!strncmp($ref,"iithesalloni",strlen("iithesalloni"))) 
		{$book['num']=53;$book['len']=strlen("iithesalloni");return $book;}
	if(!strncmp($ref,"thesalloneans",strlen("thesalloneans"))) 
		{$book['num']=53;$book['len']=strlen("thesalloneans");return $book;}
	if(!strncmp($ref,"firstthesalloneans",strlen("firstthesalloneans"))) 
		{$book['num']=53;$book['len']=strlen("firstthesalloneans");return $book;}
	if(!strncmp($ref,"iithesalloneans",strlen("iithesalloneans"))) 
		{$book['num']=53;$book['len']=strlen("iithesalloneans");return $book;}
	if(!strncmp($ref,"iithesallonean",strlen("iithesallonean"))) 
		{$book['num']=53;$book['len']=strlen("iithesallonean");return $book;}
	if(!strncmp($ref,"iithesallonea",strlen("iithesallonea"))) 
		{$book['num']=53;$book['len']=strlen("iithesallonea");return $book;}
	if(!strncmp($ref,"iithesallone",strlen("iithesallone"))) 
		{$book['num']=53;$book['len']=strlen("iithesallone");return $book;}
	if(!strncmp($ref,"iithesallon",strlen("iithesallon"))) 
		{$book['num']=53;$book['len']=strlen("iithesallon");return $book;}
	if(!strncmp($ref,"iithesallo",strlen("iithesallo"))) 
		{$book['num']=53;$book['len']=strlen("iithesallo");return $book;}
	if(!strncmp($ref,"iithesall",strlen("iithesall"))) 
		{$book['num']=53;$book['len']=strlen("iithesall");return $book;}
	if(!strncmp($ref,"iithesal",strlen("iithesal"))) 
		{$book['num']=53;$book['len']=strlen("iithesal");return $book;}
	if(!strncmp($ref,"iithesa",strlen("iithesa"))) 
		{$book['num']=53;$book['len']=strlen("iithesa");return $book;}
	if(!strncmp($ref,"iithess",strlen("iithess"))) 
		{$book['num']=53;$book['len']=strlen("iithess");return $book;}
	if(!strncmp($ref,"iithes",strlen("iithes"))) 
		{$book['num']=53;$book['len']=strlen("iithes");return $book;}
	if(!strncmp($ref,"iithe",strlen("iithe"))) 
		{$book['num']=53;$book['len']=strlen("iithe");return $book;}
	if(!strncmp($ref,"iith",strlen("iith"))) 
		{$book['num']=53;$book['len']=strlen("iith");return $book;}
	if(!strncmp($ref,"iiths",strlen("iiths"))) 
		{$book['num']=53;$book['len']=strlen("iiths");return $book;}

	if(!strncmp($ref,"timothy",strlen("timothy"))) 
		{$book['num']=54;$book['len']=strlen("timothy");return $book;}
	if(!strncmp($ref,"firsttimothy",strlen("firsttimothy"))) 
		{$book['num']=54;$book['len']=strlen("firsttimothy");return $book;}
	if(!strncmp($ref,"1timothy",strlen("1timothy"))) 
		{$book['num']=54;$book['len']=strlen("1timothy");return $book;}
	if(!strncmp($ref,"1timoth",strlen("1timoth"))) 
		{$book['num']=54;$book['len']=strlen("1timoth");return $book;}
	if(!strncmp($ref,"1timot",strlen("1timot"))) 
		{$book['num']=54;$book['len']=strlen("1timot");return $book;}
	if(!strncmp($ref,"1timo",strlen("1timo"))) 
		{$book['num']=54;$book['len']=strlen("1timo");return $book;}
	if(!strncmp($ref,"1tim",strlen("1tim"))) 
		{$book['num']=54;$book['len']=strlen("1tim");return $book;}
	if(!strncmp($ref,"1ti",strlen("1ti"))) 
		{$book['num']=54;$book['len']=strlen("1ti");return $book;}
	if(!strncmp($ref,"itimothy",strlen("itimothy"))) 
		{$book['num']=54;$book['len']=strlen("itimothy");return $book;}
	if(!strncmp($ref,"itimoth",strlen("itimoth"))) 
		{$book['num']=54;$book['len']=strlen("itimoth");return $book;}
	if(!strncmp($ref,"itimot",strlen("itimot"))) 
		{$book['num']=54;$book['len']=strlen("itimot");return $book;}
	if(!strncmp($ref,"itimo",strlen("itimo"))) 
		{$book['num']=54;$book['len']=strlen("itimo");return $book;}
	if(!strncmp($ref,"itim",strlen("itim"))) 
		{$book['num']=54;$book['len']=strlen("itim");return $book;}
	if(!strncmp($ref,"iti",strlen("iti"))) 
		{$book['num']=54;$book['len']=strlen("iti");return $book;}

	if(!strncmp($ref,"secondtimothy",strlen("secondtimothy"))) 
		{$book['num']=55;$book['len']=strlen("secondtimothy");return $book;}
	if(!strncmp($ref,"2timothy",strlen("2timothy"))) 
		{$book['num']=55;$book['len']=strlen("2timothy");return $book;}
	if(!strncmp($ref,"2timoth",strlen("2timoth"))) 
		{$book['num']=55;$book['len']=strlen("2timoth");return $book;}
	if(!strncmp($ref,"2timot",strlen("2timot"))) 
		{$book['num']=55;$book['len']=strlen("2timot");return $book;}
	if(!strncmp($ref,"2timo",strlen("2timo"))) 
		{$book['num']=55;$book['len']=strlen("2timo");return $book;}
	if(!strncmp($ref,"2tim",strlen("2tim"))) 
		{$book['num']=55;$book['len']=strlen("2tim");return $book;}
	if(!strncmp($ref,"2ti",strlen("2ti"))) 
		{$book['num']=55;$book['len']=strlen("2ti");return $book;}
	if(!strncmp($ref,"iitimothy",strlen("iitimothy"))) 
		{$book['num']=55;$book['len']=strlen("iitimothy");return $book;}
	if(!strncmp($ref,"iitimoth",strlen("iitimoth"))) 
		{$book['num']=55;$book['len']=strlen("iitimoth");return $book;}
	if(!strncmp($ref,"iitimot",strlen("iitimot"))) 
		{$book['num']=55;$book['len']=strlen("iitimot");return $book;}
	if(!strncmp($ref,"iitimo",strlen("iitimo"))) 
		{$book['num']=55;$book['len']=strlen("iitimo");return $book;}
	if(!strncmp($ref,"iitim",strlen("iitim"))) 
		{$book['num']=55;$book['len']=strlen("iitim");return $book;}
	if(!strncmp($ref,"iiti",strlen("iiti"))) 
		{$book['num']=55;$book['len']=strlen("iiti");return $book;}

	if(!strncmp($ref,"titus",strlen("titus"))) 
		{$book['num']=56;$book['len']=strlen("titus");return $book;}
	if(!strncmp($ref,"titu",strlen("titu"))) 
		{$book['num']=56;$book['len']=strlen("titu");return $book;}
	if(!strncmp($ref,"titis",strlen("titis"))) 
		{$book['num']=56;$book['len']=strlen("titis");return $book;}
	if(!strncmp($ref,"titi",strlen("titi"))) 
		{$book['num']=56;$book['len']=strlen("titi");return $book;}
	if(!strncmp($ref,"tit",strlen("tit"))) 
		{$book['num']=56;$book['len']=strlen("tit");return $book;}
	if(!strncmp($ref,"ti",strlen("ti"))) 
		{$book['num']=56;$book['len']=strlen("ti");return $book;}
	if(!strncmp($ref,"titis",strlen("titis"))) 
		{$book['num']=56;$book['len']=strlen("titis");return $book;}

	if(!strncmp($ref,"philemon",strlen("philemon"))) 
		{$book['num']=57;$book['len']=strlen("philemon");return $book;}
	if(!strncmp($ref,"philemo",strlen("philemo"))) 
		{$book['num']=57;$book['len']=strlen("philemo");return $book;}
	if(!strncmp($ref,"phileman",strlen("phileman"))) 
		{$book['num']=57;$book['len']=strlen("phileman");return $book;}
	if(!strncmp($ref,"philema",strlen("philema"))) 
		{$book['num']=57;$book['len']=strlen("philema");return $book;}
	if(!strncmp($ref,"philem",strlen("philem"))) 
		{$book['num']=57;$book['len']=strlen("philem");return $book;}
	if(!strncmp($ref,"phile",strlen("phile"))) 
		{$book['num']=57;$book['len']=strlen("phile");return $book;}
	if(!strncmp($ref,"philimon",strlen("philimon"))) 
		{$book['num']=57;$book['len']=strlen("philimon");return $book;}
	if(!strncmp($ref,"philimo",strlen("philimo"))) 
		{$book['num']=57;$book['len']=strlen("philimo");return $book;}
	if(!strncmp($ref,"philiman",strlen("philiman"))) 
		{$book['num']=57;$book['len']=strlen("philiman");return $book;}
	if(!strncmp($ref,"philima",strlen("philima"))) 
		{$book['num']=57;$book['len']=strlen("philima");return $book;}
	if(!strncmp($ref,"philim",strlen("philim"))) 
		{$book['num']=57;$book['len']=strlen("philim");return $book;}
	if(!strncmp($ref,"phillemon",strlen("phillemon"))) 
		{$book['num']=57;$book['len']=strlen("phillemon");return $book;}
	if(!strncmp($ref,"phillemo",strlen("phillemo"))) 
		{$book['num']=57;$book['len']=strlen("phillemo");return $book;}
	if(!strncmp($ref,"philleman",strlen("philleman"))) 
		{$book['num']=57;$book['len']=strlen("philleman");return $book;}
	if(!strncmp($ref,"phillema",strlen("phillema"))) 
		{$book['num']=57;$book['len']=strlen("phillema");return $book;}
	if(!strncmp($ref,"phillem",strlen("phillem"))) 
		{$book['num']=57;$book['len']=strlen("phillem");return $book;}
	if(!strncmp($ref,"phille",strlen("phille"))) 
		{$book['num']=57;$book['len']=strlen("phille");return $book;}
	if(!strncmp($ref,"phillimon",strlen("phillimon"))) 
		{$book['num']=57;$book['len']=strlen("phillimon");return $book;}
	if(!strncmp($ref,"phillimo",strlen("phillimo"))) 
		{$book['num']=57;$book['len']=strlen("phillimo");return $book;}
	if(!strncmp($ref,"philliman",strlen("philliman"))) 
		{$book['num']=57;$book['len']=strlen("philliman");return $book;}
	if(!strncmp($ref,"phillima",strlen("phillima"))) 
		{$book['num']=57;$book['len']=strlen("phillima");return $book;}
	if(!strncmp($ref,"phillim",strlen("phillim"))) 
		{$book['num']=57;$book['len']=strlen("phillim");return $book;}
	if(!strncmp($ref,"phili",strlen("phili"))) 
		{$book['num']=57;$book['len']=strlen("phili");return $book;}
	if(!strncmp($ref,"phlmn",strlen("phlmn"))) 
		{$book['num']=57;$book['len']=strlen("phlmn");return $book;}
	if(!strncmp($ref,"phlm",strlen("phlm"))) 
		{$book['num']=57;$book['len']=strlen("phlm");return $book;}
	if(!strncmp($ref,"phln",strlen("phln"))) 
		{$book['num']=57;$book['len']=strlen("phln");return $book;}

	if(!strncmp($ref,"hebrews",strlen("hebrews"))) 
		{$book['num']=58;$book['len']=strlen("hebrews");return $book;}
	if(!strncmp($ref,"hebrew",strlen("hebrew"))) 
		{$book['num']=58;$book['len']=strlen("hebrew");return $book;}
	if(!strncmp($ref,"hebre",strlen("hebre"))) 
		{$book['num']=58;$book['len']=strlen("hebre");return $book;}
	if(!strncmp($ref,"hebr",strlen("hebr"))) 
		{$book['num']=58;$book['len']=strlen("hebr");return $book;}
	if(!strncmp($ref,"heb",strlen("heb"))) 
		{$book['num']=58;$book['len']=strlen("heb");return $book;}
	if(!strncmp($ref,"he",strlen("he"))) 
		{$book['num']=58;$book['len']=strlen("he");return $book;}
	if(!strncmp($ref,"hbrws",strlen("hbrws"))) 
		{$book['num']=58;$book['len']=strlen("hbrws");return $book;}
	if(!strncmp($ref,"hbrw",strlen("hbrw"))) 
		{$book['num']=58;$book['len']=strlen("hbrw");return $book;}
	if(!strncmp($ref,"hbr",strlen("hbr"))) 
		{$book['num']=58;$book['len']=strlen("hbr");return $book;}

	if(!strncmp($ref,"james",strlen("james"))) 
		{$book['num']=59;$book['len']=strlen("james");return $book;}
	if(!strncmp($ref,"jame",strlen("jame"))) 
		{$book['num']=59;$book['len']=strlen("jame");return $book;}
	if(!strncmp($ref,"jam",strlen("jam"))) 
		{$book['num']=59;$book['len']=strlen("jam");return $book;}
	if(!strncmp($ref,"jas",strlen("jas"))) 
		{$book['num']=59;$book['len']=strlen("jas");return $book;}
	if(!strncmp($ref,"ja",strlen("ja"))) 
		{$book['num']=59;$book['len']=strlen("ja");return $book;}

	if(!strncmp($ref,"peter",strlen("peter"))) 
		{$book['num']=60;$book['len']=strlen("peter");return $book;}
	if(!strncmp($ref,"firstpeter",strlen("firstpeter"))) 
		{$book['num']=60;$book['len']=strlen("firstpeter");return $book;}
	if(!strncmp($ref,"1peter",strlen("1peter"))) 
		{$book['num']=60;$book['len']=strlen("1peter");return $book;}
	if(!strncmp($ref,"1pete",strlen("1pete"))) 
		{$book['num']=60;$book['len']=strlen("1pete");return $book;}
	if(!strncmp($ref,"1pet",strlen("1pet"))) 
		{$book['num']=60;$book['len']=strlen("1pet");return $book;}
	if(!strncmp($ref,"1pe",strlen("1pe"))) 
		{$book['num']=60;$book['len']=strlen("1pe");return $book;}
	if(!strncmp($ref,"ipeter",strlen("ipeter"))) 
		{$book['num']=60;$book['len']=strlen("ipeter");return $book;}
	if(!strncmp($ref,"ipete",strlen("ipete"))) 
		{$book['num']=60;$book['len']=strlen("ipete");return $book;}
	if(!strncmp($ref,"ipet",strlen("ipet"))) 
		{$book['num']=60;$book['len']=strlen("ipet");return $book;}
	if(!strncmp($ref,"ipe",strlen("ipe"))) 
		{$book['num']=60;$book['len']=strlen("ipe");return $book;}

	if(!strncmp($ref,"secondpeter",strlen("secondpeter"))) 
		{$book['num']=61;$book['len']=strlen("secondpeter");return $book;}
	if(!strncmp($ref,"2peter",strlen("2peter"))) 
		{$book['num']=61;$book['len']=strlen("2peter");return $book;}
	if(!strncmp($ref,"2pete",strlen("2pete"))) 
		{$book['num']=61;$book['len']=strlen("2pete");return $book;}
	if(!strncmp($ref,"2pet",strlen("2pet"))) 
		{$book['num']=61;$book['len']=strlen("2pet");return $book;}
	if(!strncmp($ref,"2pe",strlen("2pe"))) 
		{$book['num']=61;$book['len']=strlen("2pe");return $book;}
	if(!strncmp($ref,"iipeter",strlen("iipeter"))) 
		{$book['num']=61;$book['len']=strlen("iipeter");return $book;}
	if(!strncmp($ref,"iipete",strlen("iipete"))) 
		{$book['num']=61;$book['len']=strlen("iipete");return $book;}
	if(!strncmp($ref,"iipet",strlen("iipet"))) 
		{$book['num']=61;$book['len']=strlen("iipet");return $book;}
	if(!strncmp($ref,"iipe",strlen("iipe"))) 
		{$book['num']=61;$book['len']=strlen("iipe");return $book;}

	if(!strncmp($ref,"firstjohn",strlen("firstjohn"))) 
		{$book['num']=62;$book['len']=strlen("firstjohn");return $book;}
	if(!strncmp($ref,"1john",strlen("1john"))) 
		{$book['num']=62;$book['len']=strlen("1john");return $book;}
	if(!strncmp($ref,"1joh",strlen("1joh"))) 
		{$book['num']=62;$book['len']=strlen("1joh");return $book;}
	if(!strncmp($ref,"1jo",strlen("1jo"))) 
		{$book['num']=62;$book['len']=strlen("1jo");return $book;}
	if(!strncmp($ref,"1jn",strlen("1jn"))) 
		{$book['num']=62;$book['len']=strlen("1jn");return $book;}
	if(!strncmp($ref,"ijohn",strlen("ijohn"))) 
		{$book['num']=62;$book['len']=strlen("ijohn");return $book;}
	if(!strncmp($ref,"ijoh",strlen("ijoh"))) 
		{$book['num']=62;$book['len']=strlen("ijoh");return $book;}
	if(!strncmp($ref,"ijo",strlen("ijo"))) 
		{$book['num']=62;$book['len']=strlen("ijo");return $book;}
	if(!strncmp($ref,"ijn",strlen("ijn"))) 
		{$book['num']=62;$book['len']=strlen("ijn");return $book;}

	if(!strncmp($ref,"secondjohn",strlen("secondjohn"))) 
		{$book['num']=63;$book['len']=strlen("secondjohn");return $book;}
	if(!strncmp($ref,"2john",strlen("2john"))) 
		{$book['num']=63;$book['len']=strlen("2john");return $book;}
	if(!strncmp($ref,"2joh",strlen("2joh"))) 
		{$book['num']=63;$book['len']=strlen("2joh");return $book;}
	if(!strncmp($ref,"2jo",strlen("2jo"))) 
		{$book['num']=63;$book['len']=strlen("2jo");return $book;}
	if(!strncmp($ref,"2jn",strlen("2jn"))) 
		{$book['num']=63;$book['len']=strlen("2jn");return $book;}
	if(!strncmp($ref,"iijohn",strlen("iijohn"))) 
		{$book['num']=63;$book['len']=strlen("iijohn");return $book;}
	if(!strncmp($ref,"iijoh",strlen("iijoh"))) 
		{$book['num']=63;$book['len']=strlen("iijoh");return $book;}
	if(!strncmp($ref,"iijo",strlen("iijo"))) 
		{$book['num']=63;$book['len']=strlen("iijo");return $book;}
	if(!strncmp($ref,"iijn",strlen("iijn"))) 
		{$book['num']=63;$book['len']=strlen("iijn");return $book;}

	if(!strncmp($ref,"thirdjohn",strlen("thirdjohn"))) 
		{$book['num']=64;$book['len']=strlen("thirdjohn");return $book;}
	if(!strncmp($ref,"3john",strlen("3john"))) 
		{$book['num']=64;$book['len']=strlen("3john");return $book;}
	if(!strncmp($ref,"3joh",strlen("3joh"))) 
		{$book['num']=64;$book['len']=strlen("3joh");return $book;}
	if(!strncmp($ref,"3jo",strlen("3jo"))) 
		{$book['num']=64;$book['len']=strlen("3jo");return $book;}
	if(!strncmp($ref,"3jn",strlen("3jn"))) 
		{$book['num']=64;$book['len']=strlen("3jn");return $book;}
	if(!strncmp($ref,"iiijohn",strlen("iiijohn"))) 
		{$book['num']=64;$book['len']=strlen("iiijohn");return $book;}
	if(!strncmp($ref,"iiijoh",strlen("iiijoh"))) 
		{$book['num']=64;$book['len']=strlen("iiijoh");return $book;}
	if(!strncmp($ref,"iiijo",strlen("iiijo"))) 
		{$book['num']=64;$book['len']=strlen("iiijo");return $book;}
	if(!strncmp($ref,"iiijn",strlen("iiijn"))) 
		{$book['num']=64;$book['len']=strlen("iiijn");return $book;}

	if(!strncmp($ref,"jude",strlen("jude"))) 
		{$book['num']=65;$book['len']=strlen("jude");return $book;}
	if(!strncmp($ref,"jud",strlen("jud"))) 
		{$book['num']=65;$book['len']=strlen("jud");return $book;}
	if(!strncmp($ref,"jde",strlen("jde"))) 
		{$book['num']=65;$book['len']=strlen("jde");return $book;}

	if(!strncmp($ref,"revelations",strlen("revelations"))) 
		{$book['num']=66;$book['len']=strlen("revelations");return $book;}
	if(!strncmp($ref,"revelation",strlen("revelation"))) 
		{$book['num']=66;$book['len']=strlen("revelation");return $book;}
	if(!strncmp($ref,"revelatio",strlen("revelatio"))) 
		{$book['num']=66;$book['len']=strlen("revelatio");return $book;}
	if(!strncmp($ref,"revelati",strlen("revelati"))) 
		{$book['num']=66;$book['len']=strlen("revelati");return $book;}
	if(!strncmp($ref,"revelat",strlen("revelat"))) 
		{$book['num']=66;$book['len']=strlen("revelat");return $book;}
	if(!strncmp($ref,"revela",strlen("revela"))) 
		{$book['num']=66;$book['len']=strlen("revela");return $book;}
	if(!strncmp($ref,"revel",strlen("revel"))) 
		{$book['num']=66;$book['len']=strlen("revel");return $book;}
	if(!strncmp($ref,"reve",strlen("reve"))) 
		{$book['num']=66;$book['len']=strlen("reve");return $book;}
	if(!strncmp($ref,"revalations",strlen("revalations"))) 
		{$book['num']=66;$book['len']=strlen("revalations");return $book;}
	if(!strncmp($ref,"revalation",strlen("revalation"))) 
		{$book['num']=66;$book['len']=strlen("revalation");return $book;}
	if(!strncmp($ref,"revalatio",strlen("revalatio"))) 
		{$book['num']=66;$book['len']=strlen("revalatio");return $book;}
	if(!strncmp($ref,"revalati",strlen("revalati"))) 
		{$book['num']=66;$book['len']=strlen("revalati");return $book;}
	if(!strncmp($ref,"revalat",strlen("revalat"))) 
		{$book['num']=66;$book['len']=strlen("revalat");return $book;}
	if(!strncmp($ref,"revala",strlen("revala"))) 
		{$book['num']=66;$book['len']=strlen("revala");return $book;}
	if(!strncmp($ref,"reval",strlen("reval"))) 
		{$book['num']=66;$book['len']=strlen("reval");return $book;}
	if(!strncmp($ref,"reva",strlen("reva"))) 
		{$book['num']=66;$book['len']=strlen("reva");return $book;}
	if(!strncmp($ref,"rev",strlen("rev"))) 
		{$book['num']=66;$book['len']=strlen("rev");return $book;}
	if(!strncmp($ref,"rv",strlen("rv"))) 
		{$book['num']=66;$book['len']=strlen("rv");return $book;}
	if(!strncmp($ref,"re",strlen("re"))) 
		{$book['num']=66;$book['len']=strlen("re");return $book;}
	} /* end function check_booknames */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function parse_reference                                             */
/*                                                                      */
/* Looks at the passed in string and parses out of it a Bible reference */
/* of the form # or #:# or Book # or Book #:#.                          */
/*                                                                      */
/* Returns an array with three elements:                                */
/*   ['book'] will contain the book number 1=Genesis 66=Revelations     */
/*   ['chapter'] will contain the chapter number                        */
/*   ['verse'] will contain the verse number                            */
/*                                                                      */
/*----------------------------------------------------------------------*/
function parse_reference($ref)
	{
	$reference['book'] = "";
	$reference['chapter'] = "";
	$reference['verse'] = "";

	/* start by getting rid of extra spaces */
	$ref = str_replace(" ","",$ref);

	/* see if this is just a number */
	if(is_numeric($ref))
		{
		/* assume it's a verse */
		$reference['verse'] = $ref;
		return($reference);
		}
	/* see if it's a chapter:verse pair */
	if(strpos($ref,":"))
		{
		$parts = explode(":",$ref,2);
		/* see whether it includes a book name */
		if(is_numeric($parts[0]))
			{
			$reference['chapter'] = $parts[0];
			$reference['verse'] = $parts[1];
			return($reference);
			} /* end if the first part is numeric - so there's no book name */
		else
			{
			$book = check_booknames($parts[0]);
			$reference['book'] = $book['num'];
			$reference['chapter'] = substr($parts[0],$book['len']);
			$reference['verse'] = $parts[1];
			return($reference);
			} /* end else - it's got a book name at the beginning */				
		} /* there's a : so it's got a chapter and verse */

	/* we're here because there's no : so it's a book name and number (chapter) */

	$book = check_booknames($ref);
	$reference['book'] = $book['num'];
	$reference['chapter'] = substr($ref,$book['len']);
	return($reference);

	return $reference;
	} /* end function parse_reference */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function parse_refstring                                             */
/*                                                                      */
/* Looks at the passed in string and parses out of it a Bible reference */
/* of the form Book #, Book #-#, Book #:#-#, Book #:#-#:#, Book - Book  */
/* Book # = Book #, Book #:# - Book #:#                                 */
/*                                                                      */
/* Returns an array with two elements:                                  */
/*   ['start'] will contain info on the start point                     */
/*   ['end'] will contain info on the end point or will be empty        */
/*                                                                      */
/* Each entry will be of the form bbcccvvv where:                       */
/*   bb is a 2 digit number from 01=Genesis to 66=Revelations           */
/*   ccc is a 3 digit number representing the chapter number            */
/*   vvv is a 3 digit number representing the verse number              */
/*                                                                      */
/*----------------------------------------------------------------------*/
function parse_refstring($ref)
	{
	$start = "00000000";
	$end = "";

	$parts = explode("-",$ref);

	$startref = parse_reference($parts[0]);
	if(strlen($startref['book']) < 1) $startref['book'] = 0;
	if(strlen($startref['chapter']) < 1) $startref['chapter'] = 0;
	if(strlen($startref['verse']) < 1) $startref['verse'] = 0;

	$start = sprintf("%02d%03d%03d",$startref['book'],$startref['chapter'],$startref['verse']);

	if(count($parts) > 1)
		{
		$endref = parse_reference($parts[1]);
		if(strlen($endref['book']) < 1) $endref['book'] = 0;
		if(strlen($endref['chapter']) < 1) $endref['chapter'] = 0;
		if(strlen($endref['verse']) < 1) $endref['verse'] = 0;

		if($endref['book'] == 0) /* either # or #:# */
			{
			$endref['book'] = $startref['book'];
			if($endref['chapter'] == 0) /* just # */
				{
				if($startref['verse'] == 0) /* this is a chapter */
					{
					$endref['chapter'] = $endref['verse'];
					$endref['verse'] = 0;
					}
				else /* this is a verse */
					$endref['chapter'] = $startref['chapter'];
				} /* end if just # */
			} /* end if # or #:# */

		$end = sprintf("%02d%03d%03d",$endref['book'],$endref['chapter'],$endref['verse']);
	
		} /* end if there's a second part */

	$retarray['start'] = $start;
	$retarray['end'] = $end;
	return $retarray;
	} /* end function parse_refstring */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function display_passage                                             */
/*                                                                      */
/* Receives from the Web Service the requested passage and prints it    */
/* out with full translation version name and copyright.                */
/*                                                                      */
/*----------------------------------------------------------------------*/
function display_passage($version,$startbook,$startchapter,$startverse,$endbook,$endchapter,$endverse)
	{
	/****************************************************************/
	/****************************************************************/
	/*                                                              */
	/*    Replace the below with the URL you want to reference      */
	/*    as the Bible reading and searching page.                  */
	/*                                                              */
	/****************************************************************/
	/****************************************************************/
	$biblepage = "BibleExample.php";

	$chapters[1]=50;
	$chapters[2]=40;
	$chapters[3]=27;
	$chapters[4]=36;
	$chapters[5]=34;
	$chapters[6]=24;
	$chapters[7]=21;
	$chapters[8]=4;
	$chapters[9]=31;
	$chapters[10]=24;
	$chapters[11]=22;
	$chapters[12]=25;
	$chapters[13]=29;
	$chapters[14]=36;
	$chapters[15]=10;
	$chapters[16]=13;
	$chapters[17]=10;
	$chapters[18]=42;
	$chapters[19]=150;
	$chapters[20]=31;
	$chapters[21]=12;
	$chapters[22]=8;
	$chapters[23]=66;
	$chapters[24]=52;
	$chapters[25]=5;
	$chapters[26]=48;
	$chapters[27]=12;
	$chapters[28]=14;
	$chapters[29]=3;
	$chapters[30]=9;
	$chapters[31]=1;
	$chapters[32]=4;
	$chapters[33]=7;
	$chapters[34]=3;
	$chapters[35]=3;
	$chapters[36]=3;
	$chapters[37]=2;
	$chapters[38]=14;
	$chapters[39]=4;
	$chapters[40]=28;
	$chapters[41]=16;
	$chapters[42]=24;
	$chapters[43]=21;
	$chapters[44]=28;
	$chapters[45]=16;
	$chapters[46]=16;
	$chapters[47]=13;
	$chapters[48]=6;
	$chapters[49]=6;
	$chapters[50]=4;
	$chapters[51]=4;
	$chapters[52]=5;
	$chapters[53]=3;
	$chapters[54]=6;
	$chapters[55]=4;
	$chapters[56]=3;
	$chapters[57]=1;
	$chapters[58]=13;
	$chapters[59]=5;
	$chapters[60]=5;
	$chapters[61]=3;
	$chapters[62]=5;
	$chapters[63]=1;
	$chapters[64]=1;
	$chapters[65]=1;
	$chapters[66]=22;

	/* handle the case of one chapter books */
	if((strlen($startbook) > 0) AND (strlen($startchapter) < 1))
		if($chapters[$startbook] == 1) $startchapter = 1;

	if($version == "All") $version1 = "KJV";
	else $version1 = $version;

	while(strlen($version1) > 0)
		{
		$url = "http://api.seek-first.com/v1/BibleSearch.php?type=lookup&appid=seekfirst&".
			"startbooknum=$startbook&startchapter=$startchapter&startverse=$startverse&".
			"endbooknum=$endbook&endchapter=$endchapter&endverse=$endverse&version=$version1";
		echo "\n<!-- $url -->\n";
		
		$xml = file_get_contents($url);
			
		$fullnamea = lml_get_element($xml,"VersionName");
		$fullname = $fullnamea['contents'];
		$copyrighta = lml_get_element($xml,"Copyright");
		$copyright = $copyrighta['contents'];
	
		echo "<p><b>$fullname</b></p>\n";
	
		if(strlen($startbook) < 1)
			{
			$result = lml_get_element($xml,"Results");
		
			$lastchapter = 0;
			$lastbook = "None";
			
			while($result = lml_get_element($xml,"Result"))
				{
				$xml = $result['ros'];
				$subresult = lml_get_element($result['contents'],"Book");
				$book = $subresult['contents'];
				$bookc = str_replace(" ","",$book);
				$subresult = lml_get_element($result['contents'],"BookNum");
				$booknum = $subresult['contents'];
				if($book != $lastbook)
					{
					echo "<p><b>$book</b><br />\n";
					for($chapter=1;$chapter<=$chapters[$booknum];$chapter++)
						echo "<a href=$biblepage?".
							"p=".$bookc.$chapter."&".
							"version=$version1>".$chapter."</a> ";
					}
				$lastbook = $book;
				} /* end while looping through results */
			} /* end if startbook NOT provided */
	
		elseif(strlen($startchapter) < 1)
			{
			$result = lml_get_element($xml,"Results");
		
			$lastchapter = 0;
			$lastbook = "None";
			
			while($result = lml_get_element($xml,"Result"))
				{
				$xml = $result['ros'];
				$subresult = lml_get_element($result['contents'],"Book");
				$book = $subresult['contents'];
				$bookc = str_replace(" ","",$book);
				$subresult = lml_get_element($result['contents'],"Chapter");
				$chapter = $subresult['contents'];
				if($book != $lastbook)
					echo "<p><b>$book</b><br />\n";
				echo "<a href=$biblepage?p=".
					$bookc.$chapter."&version=$version1>".$chapter."</a> ";
				$lastbook = $book;
				} /* end while looping through results */
			} /* end if startchapter NOT provided (but startbook is) */
	
		elseif(strstr($xml,"<Results>"))
			{
			$result = lml_get_element($xml,"Results");
			$xml = $result['contents'];
		
			$lastchapter = 0;
			$lastbook = "None";
			
			while($result = lml_get_element($xml,"Result"))
				{
				$xml = $result['ros'];
				$subresult = lml_get_element($result['contents'],"Title");
				if(strlen($subresult['ros']) > 0)
					$title = $subresult['contents'];
				else $title = "";
				$subresult = lml_get_element($result['contents'],"Book");
				$book = $subresult['contents'];
				$subresult = lml_get_element($result['contents'],"Chapter");
				$chapter = $subresult['contents'];
				$subresult = lml_get_element($result['contents'],"Verse");
				$verse = $subresult['contents'];
				$subresult = lml_get_element($result['contents'],"Text");
				$text = $subresult['contents'];
				if(($book != $lastbook) OR ($chapter != $lastchapter))
						echo "</p><p><b>$book $chapter</b><br />\n";
				if(strlen($title) > 0) echo "<br /><div style=\"text-align: center;".
					"font-weight: bold; font-style: italic;\">$title</div><br />\n";
				echo "<sup>$verse</sup> $text<br />\n";
				$lastchapter = $chapter;
				$lastbook = $book;
				} /* end while looping through results */
			echo "</p>\n";
		
			echo "<p><i>$copyright</i></p>\n";
			} /* end else - startbook and startchapter both provided */

		if(($version == "All") AND ($version1 == "YLT")) $version1 = "";
		if(($version == "All") AND ($version1 == "HNV")) $version1 = "YLT";
		if(($version == "All") AND ($version1 == "WEB")) $version1 = "HNV";
		if(($version == "All") AND ($version1 == "ASV")) $version1 = "WEB";
		if(($version == "All") AND ($version1 == "AKJV")) $version1 = "ASV";
		if(($version == "All") AND ($version1 == "KJV")) $version1 = "AKJV";
		if($version != "All") $version1 = "";
		} /* end while looping through versions */
	} /* end function display_passage */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function display_search                                              */
/*                                                                      */
/* Sends a search request to the Web Service, receives back a list of   */
/* matching verses, and displays each, bolding the matching words.      */
/*                                                                      */
/* version,startbook,startchapter,startverse,endbook,endchapter,        */
/* and endverse specify what portion of which translation of the Bible  */
/* to search.                                                           */
/*                                                                      */
/* count indicates how many verses to display.                          */
/* startat indicates where to start displaying (e.g. a search might     */
/* find hundreds of matching verses.  If startat=100 and count=10,      */
/* then the 100th to 109th matching verses will be displayed.           */
/*                                                                      */
/* Returns the total count of search matches.                           */
/*                                                                      */
/*----------------------------------------------------------------------*/
function display_search($version,$startbook,$startchapter,$startverse,
			$endbook,$endchapter,$endverse,$startat,$count,$initquery)
	{
	if($version == "All") $version = "WEB";

	$url = "http://api.seek-first.com/v1/BibleSearch.php?type=search&version=$version&query=".
		urlencode($initquery).
		"&results=$count&start=".($startat)."&startbook=$startbook&startchapter=$startchapter".
		"&startverse=$startverse&endbook=$endbook&endchapter=$endchapter&endverse=$endverse";
	echo "\n<!-- $url -->\n";

	$xml = file_get_contents($url);

	$fullnamea = lml_get_element($xml,"VersionName");
	$fullname = $fullnamea['contents'];
	$copyrighta = lml_get_element($xml,"Copyright");
	$copyright = $copyrighta['contents'];

	if(strstr($xml,"<TotalResults>"))
		{
		$result = lml_get_element($xml,"TotalResults");
		
		$totalcount = $result['contents'];
		$nextset = $startat+$count;
		if($nextset > $totalcount) $nextset = $totalcount;
		$xml = $result['ros'];

		echo "<p>Your query for <b>'$initquery'</b> found ".
			number_format($totalcount)." results.  Results ".($startat+1)." to ".
			$nextset." are:</p>";

		if($result = lml_get_element($xml,"Results"))
			{
			echo "<p><b>$fullname</b></p>\n";
	
			$xml = $result['contents'];

			while($result = lml_get_element($xml,"Result"))
				{
				$xml = $result['ros'];
				$subresult = lml_get_element($result['contents'],"BookNum");
				$booknum = $subresult['contents'];
				$subresult = lml_get_element($result['contents'],"Book");
				$book = $subresult['contents'];
				$subresult = lml_get_element($result['contents'],"Chapter");
				$chapter = $subresult['contents'];
				$subresult = lml_get_element($result['contents'],"Verse");
				$verse = $subresult['contents'];
				echo "<p><b>$book $chapter:$verse</b><br />\n";
				$subresult = lml_get_element($result['contents'],"Text");
				$versetext = $subresult['contents'];

				/* bold the searched for words */
				$parts = explode(" ",$initquery);
				for($i=0;$i<count($parts);$i++)
					{
					/* need to handle any capitalization differences */
					$thisword = $parts[$i];
					$pos = 0;
					$shifttext = " ".$versetext; /* for match at beginning */
					while($pos = @strpos(strtolower($shifttext),strtolower($thisword),$pos))
						{
						$found = substr($shifttext,$pos,strlen($thisword));
						$versetext = str_replace($found,"<b>$found</b>",$versetext);
						$pos = $pos + strlen("<b>".$found."</b>");
						} /* loop through all instances of the search word */
					} /* end for looping through all search words */

				echo $versetext."</p>\n";
				} /* end while looping through results */

			echo "<p><i>$copyright</i></p>\n";
			} /* end if Results */
		else
			{
			echo "No Matches Found.<br />\n";
			$result = lml_get_element($xml,"Error");
			echo $result['contents'];
			}
		} /* end if TotalResults */

	return $totalcount;
	} /* end function display_search */

/*** Constants ***/
$chapters[1]=50;
$chapters[2]=40;
$chapters[3]=27;
$chapters[4]=36;
$chapters[5]=34;
$chapters[6]=24;
$chapters[7]=21;
$chapters[8]=4;
$chapters[9]=31;
$chapters[10]=24;
$chapters[11]=22;
$chapters[12]=25;
$chapters[13]=29;
$chapters[14]=36;
$chapters[15]=10;
$chapters[16]=13;
$chapters[17]=10;
$chapters[18]=42;
$chapters[19]=150;
$chapters[20]=31;
$chapters[21]=12;
$chapters[22]=8;
$chapters[23]=66;
$chapters[24]=52;
$chapters[25]=5;
$chapters[26]=48;
$chapters[27]=12;
$chapters[28]=14;
$chapters[29]=3;
$chapters[30]=9;
$chapters[31]=1;
$chapters[32]=4;
$chapters[33]=7;
$chapters[34]=3;
$chapters[35]=3;
$chapters[36]=3;
$chapters[37]=2;
$chapters[38]=14;
$chapters[39]=4;
$chapters[40]=28;
$chapters[41]=16;
$chapters[42]=24;
$chapters[43]=21;
$chapters[44]=28;
$chapters[45]=16;
$chapters[46]=16;
$chapters[47]=13;
$chapters[48]=6;
$chapters[49]=6;
$chapters[50]=4;
$chapters[51]=4;
$chapters[52]=5;
$chapters[53]=3;
$chapters[54]=6;
$chapters[55]=4;
$chapters[56]=3;
$chapters[57]=1;
$chapters[58]=13;
$chapters[59]=5;
$chapters[60]=5;
$chapters[61]=3;
$chapters[62]=5;
$chapters[63]=1;
$chapters[64]=1;
$chapters[65]=1;
$chapters[66]=22;

$longbook[1] = "Genesis";
$longbook[2] = "Exodus";
$longbook[3] = "Leviticus";
$longbook[4] = "Numbers";
$longbook[5] = "Deuteronomy";
$longbook[6] = "Joshua";
$longbook[7] = "Judges";
$longbook[8] = "Ruth";
$longbook[9] = "I Samuel";
$longbook[10] = "II Samuel";
$longbook[11] = "I Kings";
$longbook[12] = "II Kings";
$longbook[13] = "I Chronicles";
$longbook[14] = "II Chronicles";
$longbook[15] = "Ezra";
$longbook[16] = "Nehemiah";
$longbook[17] = "Esther";
$longbook[18] = "Job";
$longbook[19] = "Psalms";
$longbook[20] = "Proverbs";
$longbook[21] = "Ecclesiastes";
$longbook[22] = "Song of Songs";
$longbook[23] = "Isaiah";
$longbook[24] = "Jeremiah";
$longbook[25] = "Lamentations";
$longbook[26] = "Ezekiel";
$longbook[27] = "Daniel";
$longbook[28] = "Hosea";
$longbook[29] = "Joel";
$longbook[30] = "Amos";
$longbook[31] = "Obadiah";
$longbook[32] = "Jonah";
$longbook[33] = "Micah";
$longbook[34] = "Nahum";
$longbook[35] = "Habakkuk";
$longbook[36] = "Zephaniah";
$longbook[37] = "Haggai";
$longbook[38] = "Zechariah";
$longbook[39] = "Malachi";
$longbook[40] = "Matthew";
$longbook[41] = "Mark";
$longbook[42] = "Luke";
$longbook[43] = "John";
$longbook[44] = "Acts";
$longbook[45] = "Romans";
$longbook[46] = "I Corinthians";
$longbook[47] = "II Corinthians";
$longbook[48] = "Galatians";
$longbook[49] = "Ephesians";
$longbook[50] = "Philippians";
$longbook[51] = "Colossians";
$longbook[52] = "I Thessalonians";
$longbook[53] = "II Thessalonians";
$longbook[54] = "I Timothy";
$longbook[55] = "II Timothy";
$longbook[56] = "Titus";
$longbook[57] = "Philemon";
$longbook[58] = "Hebrews";
$longbook[59] = "James";
$longbook[60] = "I Peter";
$longbook[61] = "II Peter";
$longbook[62] = "I John";
$longbook[63] = "II John";
$longbook[64] = "III John";
$longbook[65] = "Jude";
$longbook[66] = "Revelation";
?>


