<?php
/************************************************************************/
/* Copyright Russell McGuire 2001-2007                                  */
/* Provided under Living Stones Software License Agreement              */
/* By using or sharing this software with others, you agree to be bound */
/* by the terms of that agreement.                                      */
/* E-mail russ.mcguire@seek-first.com if you don't have a copy          */
/************************************************************************/

/************************************************************************/
/* Living Stones Building Block                                         */
/*                                                                      */
/* Name: Manage Sermons                                                 */
/*                                                                      */
/* Description: This is the main interface for managing sermons on the  */
/*   church website.                                                    */
/*                                                                      */
/*   Specifically, this building block enables adding a new sermon to   */
/*   the database.  Attaching files (e.g. sermon notes, audio, video)   */
/*   to the sermon.  And publishing the sermon on your website.         */
/*                                                                      */
/*   Information stored for each sermon includes the pastor, the date,  */
/*   the sermon title, a synopsis, the Bible text(s) for the sermon,    */
/*   and topic(s) to associate this sermon with.                        */
/*                                                                      */
/*   Additionally, this interface controls security - who can access    */
/*   which sermons for which functions (add, edit, read, download...)   */
/*                                                                      */
/************************************************************************/

/************************************************************************/
/* Change the following location if you want uploaded files stored      */
/* somewhere else.                                                      */
/************************************************************************/
$UPLOAD_DIR = "upload"; /* this is relative to the directory where this program resides */

/************************************************************************/
/* Change the following locations if you've renamed the files.          */
/************************************************************************/
$SERMONFILE = "ls_sermon.php";

/************************************************************************/
/* Change the following location if you want the rss or podcast elsewhere. */
/************************************************************************/
$PODCASTFILE = $UPLOAD_DIR."/podcast.xml"; 
$FEEDFILE = $UPLOAD_DIR."/feed.xml"; 

/************************************************************************/
/* IF YOU HAVE THE BIBLE SOFTWARE INSTALLED                             */
/************************************************************************/
/* Remove the /* from the beginning of the next two lines if you have   */
/* the Bible package installed and change the location if you've moved  */
/* it.                                                                  */
/************************************************************************/
/* $BibleURL = "Bible.php?p="; /* */
/* setcookie("BibleURL",$BibleURL); /* */

session_start();

/* get include files */
require_once("./ls_include/DBfunctions.php");
require_once("./ls_include/Authfunctions.php");
require_once("./ls_include/BibleFunctions2.php");
require_once("./ls_include/PodcastFunctions.php");
include("./ls_include/editor/fckeditor.php");

/* connect to the Living Stones database */
open_database();

$thisscript = "http://" . $_SERVER['SERVER_NAME'] . $_SERVER['SCRIPT_NAME'];
$thispage = $_SERVER['SCRIPT_NAME'];
$parts = explode("/",$thispage);
$thispage = $parts[(count($parts)-1)];

$thispathurl = substr($thisscript,0,strrpos($thisscript,"/"));

$blogurl = $thispathurl."/".$FEEDFILE;
$podcasturl = $thispathurl."/".$PODCASTFILE;
$sermonurl = $thispathurl."/".$SERMONFILE;

$query = "SELECT id,dbtable FROM ls_security_objects WHERE object_desc = 'Sermons'";
$result = sql_getresult($query);
$row = sql_getrow($result);
$objecttype = $row[0];
$dbtable = $row[1];

/* find out who this user is, if they have logged in */
$thisuser = $_SESSION["lsuid"];

/* if not already logged in, then we need to log-in */
/***  NOTE: If you've placed the login page somewhere other than ls_login.php, change that reference below ***/
if(strlen($thisuser) < 1) 
	{
	echo "<script language='javascript'>\n";
	echo "window.location = 'ls_login.php?return_path=$thisscript&message=".
		urlencode("Only registered users can access this page.  Please login.")."';\n";
	echo "</script>\n";
	}


/* get the sermon date if one is selected */
$sermonid = $_POST['sermonid'];
if(strlen($sermonid) < 1) $sermonid = 0;
if($sermonid > 0)
	{
	$query = "SELECT sermondate FROM $dbtable WHERE $dbtable.id='$sermonid'";
		$result = sql_getresult($query);
		$row = sql_getrow($result);
		$sermondate = stripslashes($row[0]);
		/* need to get date formatting into the right format */
		$sermondate = date("m/d/Y",strtotime($sermondate));
		}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml11/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Living Stones Manage Sermons</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<link rel="stylesheet" type="text/css" href="./ls_include/lsadmin.css" />

<link rel="stylesheet" type="text/css" href="./ls_include/datePicker.css">
<link rel="stylesheet" type="text/css" href="./ls_include/treeView.css">

<script src="http://lstones.com/jquery-1.1.3.1.js"></script>

<!-- required plugins -->
<script type="text/javascript" src="./ls_include/date.js"></script>
<script type="text/javascript" src="./ls_include/jquery.dimensions.js"></script>
<!--[if IE]><script type="text/javascript" src="./ls_include/jquery.bgiframe.js"></script><![endif]-->

<!-- jquery.datePicker.js -->
<script type="text/javascript" src="./ls_include/jquery.datePicker.js"></script>

<style type="text/css">
/* creates a little calendar icon instead of a text link for "Choose date" */
a.dp-choose-date 
	{
	float: left;
	width: 16px;
	height: 16px;
	padding: 0;
	margin: 5px 3px 0;
	display: block;
	text-indent: -2000px;
	overflow: hidden;
	background: url(http://www.lstones.com/images/calendar.png) no-repeat; 
	}
a.dp-choose-date.dp-disabled 
	{
	background-position: 0 -20px;
	cursor: default;
	}
/* makes the input field shorter once the date picker code
 * has run (to allow space for the calendar icon
 */
input.dp-applied 
	{
	width: 140px;
	float: left;
	}
</style>

<script type="text/javascript" charset="utf-8">
	Date.firstDayOfWeek = 7;
	Date.format = 'mm/dd/yyyy';
	$(function()
		{
		$('.date-picker').datePicker();
		$('.date-picker').dpSetStartDate('01/01/1950');
		<?php if(strlen($sermondate) > 0) 
			echo "$('.date-picker').dpSetSelected('$sermondate');\n";?>
            	});
</script>
<script language="javascript">
jQuery.hasWord = jQuery.className.has;

$(document).ready(function()
	{
	$(".podcast").hide("fast");

	$("a.podcastshow").toggle(
		function()
			{
			$(".podcast").show("fast");
			},
		function()
			{
			$(".podcast").hide("slow");
			}
		);
		
	// TreeView courtesy of http://be.twixt.us/jquery/treeView.php

    	$("ul.tv")
        	.find("li:last-child").addClass("tvil").end()
        	.find("li[ul]").addClass("tvic").swapClass("tvil", "tvilc").append("<div class=\"tvca\">").find("div.tvca").toggle(
                	function(){ $(this).parent("li").swapClass("tvic", "tvie").swapClass("tvilc", "tvile").find(">ul").slideUp("normal"); },
                	function(){ $(this).parent("li").swapClass("tvic", "tvie").swapClass("tvilc", "tvile").find(">ul").slideDown("normal"); }
            		);

 
	$("#selectcheck").toggle(
			function()
				{
				$("td#fileselector").show("fast");
				},
			function()
				{
				$("td#fileselector").hide("slow");
				}
		);
 
	$("#uploadcheck").toggle(
			function()
				{
				$("td#browseselector").show("fast");
				},
			function()
				{
				$("td#browseselector").hide("slow");
				}
		);
	});
		
$.fn.swapClass = function(c1,c2) 
	{
    	return this.each(function() {
        	if ($.hasWord(this, c1)) 
			{
            		$(this).removeClass(c1);
            		$(this).addClass(c2);
        		} 
		else if ($.hasWord(this, c2)) 
			{
            		$(this).removeClass(c2);
            		$(this).addClass(c1);
        		}                    
    		});
	};

this.window.focus();
	</script>


</head>
<body>

<?php

/************************************************************************/
/* Process Inputs                                                       */
/************************************************************************/

$securitylevel = $_POST['securitylevel'];

/************************************************************************/
/* Update security levels                                               */
/************************************************************************/
$updatelevels = $_POST['updatelevels'];
if((strlen($updatelevels) > 0) AND (check_function_auth($thisuser,$objecttype,"Set Levels",1)))
	{ 
	$fieldname = $_POST['fieldname'];
	$fieldauth = $_POST['fieldauth'];
	$level_level = addslashes($_POST['level_level']);
	$level_name = addslashes($_POST['level_name']);
	
	if($securitylevel < 1)
		{
		$query = "INSERT INTO ls_security_levels SET auth_level='$level_level',".
			"auth_name='$level_name',object_type='$objecttype'";
		sql_getresult($query);
		$securitylevel = sql_getid();
		}
	else
		{
		$query = "UPDATE ls_security_levels SET auth_level='$level_level',auth_name='$level_name' ".
			"WHERE id='$securitylevel'";
		sql_getresult($query);
		}

	for($i = 1;$i <= count($fieldname); $i++)
		{
		$readauth = 0;
		$writeauth = 0;
		if($fieldauth[$i] > 0)
			$readauth = 1;
		if($fieldauth[$i] > 1)
			$writeauth = 1;

		$query = "SELECT id FROM ls_security_fields ".
			"WHERE level='$securitylevel' AND fieldname='".$fieldname[$i]."'";
		$result = sql_getresult($query);
		if($row = sql_getrow($result))
			sql_getresult("UPDATE ls_security_fields SET readauth='$readauth',".
				"writeauth='$writeauth' WHERE id='".$row[0]."'");
		else
			sql_getresult("INSERT INTO ls_security_fields SET level='$securitylevel',".
				"fieldname='".$fieldname[$i]."',readauth='$readauth',writeauth='$writeauth'");
		} /* end for looping through fields */


	/* prepare to delete unchecked functions */
	$query = "SELECT id FROM ls_security_functions WHERE object_type='$objecttype'";
	$result = sql_getresult($query);
	while($row = sql_getrow($result))
		{
		$thisid = $row[0];
		$deletefunc[$thisid] = 1;
		}

	for($i = 0;$i < count($allowfunction); $i++)
		{
		/* only those that are checked will show up here */
		/* and only need to make a change if not previously listed */
		$thisid = $allowfunction[$i];
		$deletefunc[$thisid] = 0;

		if(!sql_isrecord("SELECT id FROM ls_security_function_levels WHERE level='$securitylevel' ".
			"AND lsfunction='$thisid'"))
			sql_getresult("INSERT INTO ls_security_function_levels SET level='$securitylevel',".
				"lsfunction='$thisid'");
		} /* end for looping through functions */

	/* delete any unchecked functions that are in the database */
	$query = "SELECT id FROM ls_security_functions WHERE object_type='$objecttype'";
	$result = sql_getresult($query);
	while($row = sql_getrow($result))
		{
		$thisid = $row[0];
		if($deletefunc[$thisid] > 0)
			sql_getresult("DELETE FROM ls_security_function_levels WHERE level='$securitylevel' ".
				"AND lsfunction='$thisid'");
		}
	
	} /* end if updatelevels - security levels updated */

/************************************************************************/
/* Update default security level                                        */
/************************************************************************/
$updatedefault = $_POST['updatedefault'];
if((strlen($updatedefault) > 0) AND (check_function_auth($thisuser,$objecttype,"Set Levels",1)))
	{ 
	$defaultlevel = $_POST['defaultlevel'];
	set_auth(0,$objecttype,0,$defaultlevel);
	} /* end if update default */

/************************************************************************/
/* Update sermon data                                                   */
/************************************************************************/

$update = $_POST['update'];

/* Note: publish is a submit button that should be handled like update, but toggling the publish bit */
$publish = $_POST['publish'];
if(strlen($publish) > 0) $update = $publish;

/* Make note of whether or not this sermon was previously published */
$previously_published = 0;
$update_podcast = 0;

/* Note: sermonid = 0 means data for all sermons, sermonid = -1 means this is a new sermon */

if(strlen($update) > 0)
	{ 
	if($sermonid > 0)
		{ /* existing sermon info has been updated */

		/* get what's currently in the database */
		$query = "SELECT title,sermondate,synopsis,pastor,published,series FROM $dbtable ".
				"WHERE $dbtable.id='$sermonid'";
		$result = sql_getresult($query);
		$row = sql_getrow($result);

		/* now get what was entered */
		$title = addslashes($_POST['title']);

		$sermondate = $_POST['sermondate'];
		/* need to get date formatting into the right format */
		$sermondate = date("Y-m-d",strtotime($sermondate));

		$synopsis = addslashes(($_POST['synopsis1']));
		if(strlen($synopsis) < 1) $synopsis = $row[2];
		/* Check for unsupported characters */
		$synopsis = str_replace("&mdash;","&#151;",$synopsis);
		$synopsis = str_replace("&lsquo;","&#145;",$synopsis);
		$synopsis = str_replace("&rsquo;","&#146;",$synopsis);
		$synopsis = str_replace("&ldquo;","&#147;",$synopsis);
		$synopsis = str_replace("&rdquo;","&#148;",$synopsis);

		$pastor = $_POST['pastor'];
		if(strlen($pastor) < 1) $pastor = $row[3];

		if(strlen($publish) > 0) 
			{
			/* need to toggle published */
			if($row[4] == 1) $published = 0;
			else $published = 1;
			} 
		else
			$published = $row[4];

		$previously_published = $row[4];

		$series = $_POST['series'];
		if(strlen($series) < 1) $series = $row[5];

		/* handle a new series */
		if($series == 0)
			{
			$newseries = addslashes($_POST['newseries']);
			if(strlen($newseries) > 0)
				{
				sql_getresult("INSERT INTO ls_sermon_series SET series='$newseries'");
				$series = sql_getid();
				}
			}

		/* now update the basic sermon data */
		$query = "UPDATE $dbtable SET ".
			"title='$title',".
			"sermondate='$sermondate',".
			"synopsis='$synopsis',".
			"pastor='$pastor',".
			"published='$published',".
			"series='$series' ".
			"WHERE id='$sermonid'";
		sql_getresult($query);

		/* handle topics */
		$topic = $_POST['topic'];
		$newtopic = addslashes($_POST['newtopic']);

		/* add any new topic */
		if(strlen($newtopic) > 0)
			{
			$query = "INSERT INTO ls_sermon_topics SET sermonid='$sermonid', ".
				"topic='$newtopic'";
			sql_getresult($query);
			}
			
		/* prepare to delete unchecked topics */
		$query = "SELECT topic FROM ls_sermon_topics WHERE sermonid='$sermonid'";
		$result = sql_getresult($query);
		while($row = sql_getrow($result))
			{
			$thistopic = $row[0];
			if($thistopic != $newtopic) $deletetopic[$thistopic] = 1;
			}
	
		for($i = 0;$i < count($topic); $i++)
			{
			/* only those that are checked will show up here */
			/* and only need to make a change if not previously listed */
			$thistopic = $topic[$i];
			$deletetopic[$thistopic] = 0;
	
			if(!sql_isrecord("SELECT id FROM ls_sermon_topics WHERE sermonid='$sermonid' ".
				"AND topic='$thistopic'"))
				sql_getresult("INSERT INTO ls_sermon_topics SET sermonid='$sermonid',".
					"topic='$thistopic'");
			} /* end for looping through topics */
	
		/* delete any unchecked functions that are in the database */
		$query = "SELECT id,topic FROM ls_sermon_topics WHERE sermonid='$sermonid'";
		$result = sql_getresult($query);
		while($row = sql_getrow($result))
			{
			$thisid = $row[0];
			$thistopic = $row[1];
			if($deletetopic[$thistopic] > 0)
				sql_getresult("DELETE FROM ls_sermon_topics WHERE id='$thisid'");
			}
		
		/* handle sermon texts */
		$textid = $_POST['textid'];
		$sermontext = $_POST['sermontext'];
		$newtext = addslashes($_POST['newtext']);

		if(strlen($newtext) > 0)
			{
			$refarray = parse_refstring($newtext);
			sql_getresult("INSERT INTO ls_sermon_texts SET ".
				"sermonid='$sermonid',scripturetext='$newtext',".
				"startref='".$refarray['start']."',endref='".$refarray['end']."'");
			} /* end if newtext */

		for($i=0;$i<count($textid);$i++)
			{
			$thistext = addslashes($sermontext[$i]);
			$refarray = parse_refstring($sermontext[$i]);
			if(strlen($thistext) < 1)
				sql_getresult("DELETE FROM ls_sermon_texts WHERE id='$textid[$i]'");
			else
				sql_getresult("UPDATE ls_sermon_texts SET scripturetext='$thistext',".
					"startref='".$refarray['start']."',endref='".$refarray['end']."' ".
					"WHERE id='$textid[$i]'");
			} /* end while looping through texts */

		/* handle associated files */

		/* files selected from the server */
		$selectedfile = $_POST['selectedfile'];
		$selectedfile = addslashes($selectedfile);
		$selectedfiletype = addslashes($_POST['selectedfiletype']);
		if(strlen($selectedfile) > 0)
			{
			$query = "INSERT INTO ls_sermon_files SET ".
				"sermonid='$sermonid',".
				"uploadurl='$selectedfile',".
				"uploadtype='$selectedfiletype',".
				"filesize='0'";
			sql_getresult($query);

			if(($selectedfiletype == "Audio") AND ($published > 0))
				$update_podcast = 1;
			}

		/* files uploaded from the PC */
		/* see if a file was attached */
		$userfilename = $_FILES['userfile']['name'];
		
		if(strlen($userfilename)>0)
			{
			$dir_path = getcwd()."/".$UPLOAD_DIR;
			/* check if the upload directory exists */
			if(!is_dir($UPLOAD_DIR))
				{
				/* if not, try to create it */
				if(!file_exists($dir_path))
					{
					mkdir($dir_path,0777);
					}
				} /* directory doesn't exist */
			if(is_dir($UPLOAD_DIR))
				{ 
				/* if the directory exists, then copy the file to it */
				$filenm = urlencode(basename($_FILES['userfile']['name']));
				$uploadfile = $dir_path . "/" . $filenm;

				/* if that file already exists, then modify the name */
				if(file_exists($uploadfile))
					{
					$now = date("mdyHis");
					$dot = strrpos($uploadfile,".");
					$uploadfile = substr($uploadfile,0,($dot)).$now.
						substr($uploadfile,$dot);
					$dot = strrpos($filenm,".");
					$filenm = substr($filenm,0,($dot-1)).$now.
						substr($filenm,$dot);
					} /* end if file exists */

				if (move_uploaded_file($_FILES['userfile']['tmp_name'], $uploadfile)) 
					{
 					$url = addslashes($thispathurl . "/". $UPLOAD_DIR . "/" . 
						urlencode($filenm));
					$query = "INSERT INTO ls_sermon_files SET ".
						"sermonid='$sermonid',".
						"uploadurl='$url',".
						"uploadtype='$uploadfiletype',".
						"filesize='".$_FILES['userfile']['size']."'";

					sql_getresult($query);
					if(($uploadfiletype == "Audio") AND ($published > 0))
						$update_podcast = 1;
					} /* end if successfully moved the file */
				} /* end if the upload directory is a directory */
			} /* end if there's a file being uploaded */

		/* update any previous files */
		$afileid = $_POST['afileid'];
		$afiletype = $_POST['afiletype'];
		$afileurl = $_POST['afileurl'];

		for($i = 0; $i < count($afileid); $i++)
			{
			$query = "UPDATE ls_sermon_files SET ".
					"uploadtype='".addslashes($afiletype[$i])."',".
					"uploadurl='".addslashes($afileurl[$i])."' ".
					"WHERE id=$afileid[$i]";
			sql_getresult($query);
			}
		
		/* delete any associations being unassociated */
		$disassociate = $_POST['disassociate'];
		for($i = 0;$i < count($disassociate);$i++)
			sql_getresult("DELETE FROM ls_sermon_files WHERE id='$disassociate[$i]'");
			

		} /* end if sermonid > 0 */

	if($sermonid == 0)
		{ /* updating info for all sermons */
		} /* end if sermonid = 0 */

	if($sermonid < 0)
		{ /* new sermon */
		/* get what was entered */
		$title = addslashes($_POST['title']);

		$sermondate = $_POST['sermondate'];
		/* need to get date formatting into the right format */
		$sermondate = date("Y-m-d",strtotime($sermondate));

		$synopsis = addslashes(($_POST['synopsis1']));
		/* Check for unsupported characters */
		$synopsis = str_replace("&mdash;","&#151;",$synopsis);
		$synopsis = str_replace("&lsquo;","&#145;",$synopsis);
		$synopsis = str_replace("&rsquo;","&#146;",$synopsis);
		$synopsis = str_replace("&ldquo;","&#147;",$synopsis);
		$synopsis = str_replace("&rdquo;","&#148;",$synopsis);

		$pastor = $_POST['pastor'];
		
		if(strlen($publish) > 0) 
			$published = 1;
		else
			$published = 0;

		$series = $_POST['series'];

		/* handle a new series */
		if($series == 0)
			{
			$newseries = addslashes($_POST['newseries']);
			if(strlen($newseries) > 0)
				{
				sql_getresult("INSERT INTO ls_sermon_series SET series='$newseries'");
				$series = sql_getid();
				}
			}

		/* now insert the basic sermon data */
		$query = "INSERT INTO $dbtable SET ".
			"title='$title',".
			"sermondate='$sermondate',".
			"synopsis='$synopsis',".
			"pastor='$pastor',".
			"published='$published',".
			"series='$series'";
		sql_getresult($query);

		/* get the id that was assigned to set sermonid */
		$sermonid = sql_getid();

		/* handle topics */
		$topic = $_POST['topic'];
		$newtopic = addslashes($_POST['newtopic']);

		/* add any new topic */
		if(strlen($newtopic) > 0)
			{
			$query = "INSERT INTO ls_sermon_topics SET sermonid='$sermonid', ".
				"topic='$newtopic'";
			sql_getresult($query);
			}
			
		for($i = 0;$i < count($topic); $i++)
			{
			/* only those that are checked will show up here */
			$thistopic = $topic[$i];
	
			sql_getresult("INSERT INTO ls_sermon_topics SET sermonid='$sermonid',".
					"topic='$thistopic'");
			} /* end for looping through topics */

		$newtext = addslashes($_POST['newtext']);

		if(strlen($newtext) > 0)
			{
			$refarray = parse_refstring($newtext);
			sql_getresult("INSERT INTO ls_sermon_texts SET ".
				"sermonid='$sermonid',scripturetext='$newtext',".
				"startref='".$refarray['start']."',endref='".$refarray['end']."'");
			} /* end if newtext */

		} /* end if sermonid < 0 - New Sermon */

	/* if an update was performed and the sermon is published (either now or before), */
	/* then update the rss feed                                                       */
	if($published == 1)
		{
		update_feed($FEEDFILE,$sermonurl);

		if($previously_published < 1)
			{
			/* this is newly published - see if there are audio files */
			$query = "SELECT id FROM ls_sermon_files WHERE sermonid='$sermonid' ".
				"AND uploadtype='Audio'";
			$result = sql_getresult($query);
			if($row = sql_getrow($result)) $update_podcast = 1;
			}
		} /* end if published */

	if($update_podcast > 0)
		update_podcast($PODCASTFILE);

	} /* end if update - sermon data updated */

/************************************************************************/
/* Update users' access to sermon data                                  */
/************************************************************************/
$updateaccess = $_POST['updateaccess'];
if(strlen($updateaccess) > 0)
	{ 
	/* the information should exist in two arrays */
	$secuserid = $_POST['secuserid'];
	$secuserlevel = $_POST['secuserlevel'];

	/* loop through the entries */
	for($i = 0;$i < count($secuserid); $i++)
		{
		set_auth($secuserid[$i],$objecttype,$sermonid,$secuserlevel[$i]);

		/* we also need to set the level for each function */

		/* find the functions that are authorized for this level */
		$q2 = "SELECT lsfunction FROM ls_security_function_levels ".
			"WHERE level='$secuserlevel[$i]'";
		$r2 = sql_getresult($q2);
		while($ro2 = sql_getrow($r2))
			set_auth($secuserid[$i],0,$ro2[0],$secuserlevel[$i]);
		} /* end for looping through functions for this level */
	
	} /* end if updateaccess - users' access to sermon data updated */
?>

<?php
/************************************************************************/
/* The page starts here                                                 */
/************************************************************************/
?>
<div id="Box1">

<div id="Box11">
<a href="http://www.lstones.com/"><img border=0 src="http://www.lstones.com/LivingStones.gif"></a>
</div> <!-- Box11 -->

<div id="Box13">

<div id="Box131">
<span>Manage Sermons</span>
</div> <!-- Box131 -->

</div> <!-- Box13 -->

</div> <!-- Box1 -->

<div id="Box3">

<div id="Box31">
<?php 
/* This will figure out what options to place in the left column menu */
create_admin_menu($thisuser,$thispage,$LS_ADMIN_THRESHOLD);
?>
</div> <!-- Box31 -->

<div id="Box33">
<div id="Box331">
<a href="#" class="podcastshow" style="color: black;">Click for Podcast and RSS Feed info.</a>
<div class="podcast">
<p>Your sermons are also available as an RSS feed for folks who read lots of Weblogs (blogs) and use
a newsreader to keep up with their favorite content sources.  The feed is available here:
<?php echo $blogurl;?></p>
<p>You might also want to consider a service like <a href=http://www.feedburner.com/fb/a/blogs>FeedBurner</a>
to make make it easy to include your latest sermons on your Church homepage or to enable folks to subscribe
to receive your sermons via e-mail</p>
<p>If you have audio files associated with your sermons, then you also have a podcast!  Make sure the following 
information appears somewhere (or lots of places) on your website:<br />
To subscribe to our podcast via iTunes: click on the {advanced} button on the iTunes menu bar and then click {subscribe to podcast} Then copy and paste 
<?php echo $podcasturl;?>  into the window that pops up.<br /><br />
For all other podcatchers, use the following link to subscribe: <?php echo $podcasturl;?><br /></p>
<p>After testing your podcast to make sure it works, you can also submit it to the iTunes store.  
Here are the <a href=http://www.apple.com/itunes/podcasts/techspecs.html>directions from the Apple website:</a></p>
		<p>If you can successfully subscribe to your feed using the Advanced menu in iTunes, you&#146;re ready to submit your feed:</p>
		<ol>
		    <li>Launch iTunes.</li>
		    <li>In the left navigation column, under Inside the Music Store, click on the Podcasts link to go to the Podcasts page.</li>
		    <li>In the left column of the Podcasts page, click on the Submit a Podcast link.</li>

		    <li>Follow the instructions on the <a href="https://phobos.apple.com/WebObjects/MZFinance.woa/wa/publishPodcast">Submit a Podcast</a> page.</li>
		</ol>
		<p>Note that you will need a valid iTunes account, and you will need to be logged into iTunes. If you are not logged in, iTunes will prompt you to do so before accepting your submission. By requiring you to log in, iTunes increases the likelihood of valid contact information for each submission. Your credit card will not be charged for submission of a podcast.</p>
		<p>If you have created an RSS feed with all of the recommended iTunes tags, you will see a summary page immediately after you submit your feed URL.</p>
</div> <!-- podcast -->

<?php
/**********************************************************************/
/* If this user has authorization to define security levels...        */
/* then this is where it happens                                      */
/**********************************************************************/
if(check_function_auth($thisuser,$objecttype,"Set Levels",1))
	{
	echo "<p style=\"background-color: lightblue;\"><b>Manage Sermon Security Levels</b></p>\n";

	/* get the field names */
	$fieldnames = sql_getfields($dbtable);

	/* manage individual security levels */
	
	echo "<form method=POST action=\"$thisscript\">\n";
	if($sermonid > 0) echo "<input type=hidden name=sermonid value=$sermonid>\n";
	echo "<table width=100% border=0 style=\"border-width: 0px;\">\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Level to Manage:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>\n";
	echo "<select name=securitylevel size=1 onChange=\"this.form.submit()\">\n";
	$query = "SELECT id,auth_name,auth_level FROM ls_security_levels ".
		"WHERE object_type='$objecttype' ORDER BY auth_level ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		echo "<option value=$row[0]";
		if($securitylevel == $row[0]) 
			{
			echo " selected";
			$thisname = stripslashes($row[1]);
			$thislevel = $row[2];
			}
		echo ">".stripslashes($row[1])." (".stripslashes($row[2]).")</option>\n";
		}
	echo "<option value=0";
	if($securitylevel == 0) 
		{
		echo " selected";
		}
	echo ">New Level</option>\n";
	echo "</select>\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Level Name:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>".
		"<input type=text size=50 value=\"$thisname\" name=level_name></td>\n";
	echo "</tr>\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Security Level:</th>\n";
	echo "<td style=\"text-align: right;border-width: 0px;\">".
		"<input type=text size=5 value=\"$thislevel\" name=level_level></td>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=2>".
		"Enter a value 0 - 100 (100 = highest security)</td>\n";
	echo "</tr>\n";
	
	/* Note: Skipping field 0 since we don't want to bother folks with the id */
	for($i = 1; $i<count($fieldnames);$i++)
		{
		$query = "SELECT readauth,writeauth FROM ls_security_fields ".
			"WHERE level='$securitylevel' AND fieldname='$fieldnames[$i]'";
		$result = sql_getresult($query);
		$row = sql_getrow($result);

		echo "<tr><td style=\"border-width: 0px;\"></td>\n";
		echo "<td style=\"border-width: 0px;text-align: right;\">".stripslashes($fieldnames[$i]).
			"<input type=hidden name=fieldname[$i] value=\"$fieldnames[$i]\"></td>\n";
		echo "<td style=\"border-width: 0px;text-align: left;\" colspan=2>".
			"<select name=fieldauth[$i] size=1>\n".
			"<option value=0>None</option>\n".
			"<option value=1";
		if(($row[0] > 0) and ($row[1] < 1)) echo " selected";
		echo ">Read Only</option>\n".
			"<option value=2";
		if($row[1] > 0) echo " selected";
		echo ">Read+Write</option>\n".
			"</select></td></tr>\n";
		} /* end while looping through the fields */

	/* Set up to decide which functions this level can perform */
	echo "<tr><td style=\"border-width: 0px;\"></td>\n".
		"<td style=\"border-width: 0px;\"></td>\n".
		"<th style=\"border-width: 0px;text-align: left;\">Allow?</th></tr>\n";

	/* Get all the functions for the building block object type */
	$query = "SELECT id,lsfunction FROM ls_security_functions WHERE object_type='$objecttype' ".
			"ORDER BY lsfunction ASC";
	$result = sql_getresult($query);
	while($row = sql_getrow($result))
		{
		echo "<tr><td style=\"border-width: 0px;\"></td>\n";
		echo "<td style=\"border-width: 0px;text-align: right;\">".stripslashes($row[1]).
			" </td>\n";
		echo "<td style=\"border-width: 0px;text-align: left;\" colspan=2>".
			" <input type=checkbox name=allowfunction[] value=$row[0]";
		if(sql_isrecord("SELECT id FROM ls_security_function_levels WHERE level='$securitylevel' ".
				"AND lsfunction='$row[0]'")) echo " checked";
		echo "></td></tr>\n";
		} /* end while looping through the functions */
	echo "<tr><td colspan=4 style=\"border-width: 0px;\">".
		"<input type=submit name=updatelevels value=\"Update Level\"></td></tr>\n";
	
	echo "</table>\n";
	echo "</form>\n";

	/* define the default security level for all users */

	echo "<p><b>Select the default access that all users will have to all sermons:</b></p>\n";

	$defaultlevel = get_level(0,$objecttype,0);
	echo "<form method=POST action=\"$thisscript\">\n";
	if($sermonid > 0) echo "<input type=hidden name=sermonid value=$sermonid>\n";
	echo "<table border=0 style=\"border-width: 0px;\">\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Default User Access to Published Sermons:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>\n";
	echo "<select name=defaultlevel size=1>\n";
	$query = "SELECT id,auth_name,auth_level FROM ls_security_levels ".
		"WHERE object_type='$objecttype' ORDER BY auth_level ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		echo "<option value=$row[0]";
		if($defaultlevel == $row[0]) 
			{
			echo " selected";
			}
		echo ">".stripslashes($row[1])." (".stripslashes($row[2]).")</option>\n";
		}
	echo "</select>\n";
	echo "</td>\n";
	echo "</tr>\n";
	echo "<tr><td colspan=4 style=\"border-width: 0px;\">".
		"<input type=submit name=updatedefault value=\"Set Default\"></td></tr>\n";
	
	echo "</table>\n";
	echo "</form>\n";

	} /* end if authorized to set levels */
?>
<?php
/**********************************************************************/
/* This section is for the basic sermon settings                      */
/**********************************************************************/
echo "<p style=\"background-color: lightblue;\"><b>Manage Sermons</b></p>\n";
?>
<form id="sermonForm" enctype="multipart/form-data" action="<?php echo $thisscript;?>" method="post" style="overflow: auto;">
<table border=0 style="border-width: 0px;">
<?php
if(($sermonid > 0) OR (check_function_auth($thisuser,$objecttype,"Set Levels",1))
		OR (check_function_auth($thisuser,$objecttype,"Add Sermons",1)))
	{
	if($sermonid > 0)
		{
		$query = "SELECT title,sermondate,synopsis,pastor,published,series FROM $dbtable ".
				"WHERE $dbtable.id='$sermonid'";
		$result = sql_getresult($query);
		$row = sql_getrow($result);
		$title = stripslashes($row[0]);
		$sermondate = stripslashes($row[1]);
		/* need to get date formatting into the right format */
		$sermondate = date("m/d/Y",strtotime($sermondate));
		$synopsis = stripslashes($row[2]);
		$pastor = $row[3];
		$published = $row[4];
		$series = $row[5];
		}
	else
		{
		$title = "";
		$synopsis = "";
		}

	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Select Sermon:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>\n";
	echo "<select name=sermonid size=1 onChange=\"this.form.submit()\">\n";
	
	/* see if this user can add a new sermon */
	if(check_function_auth($thisuser,$objecttype,"Add Sermons",1))
		{
		echo "<option value=-1";
		if($sermonid == -1) 
			{
			echo " selected";
			$title = "New Sermon";
			}
		echo ">Add New Sermon</option>\n";
		} /* end if this is an admin with Add Sermon access */
	
	/* see if this user can set levels */
	if(check_function_auth($thisuser,$objecttype,"Set Levels",1))
		{
		echo "<option value=0";
		if($sermonid == 0) 
			{
			echo " selected";
			$title = "All Sermons";
			}
		echo ">Info for All Sermons</option>\n";
		} /* end if this is an admin with Set Levels access */
	
	$query = "SELECT id,title,sermondate,published FROM $dbtable WHERE id>0 ".
			"ORDER BY published ASC,sermondate DESC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		if(check_auth($thisuser,$objecttype,$row[0],$LS_USER_THRESHOLD))
			{
			echo "<option value=$row[0]";
			$thistitle = stripslashes($row[1]);
			$thissermondate = $row[2];
			/* need to get date formatting into the right format */
			$thissermondate = date("m/d/Y",strtotime($thissermondate));
			if($row[3] > 0) $thispub = "p:";
			else $thispub = "u:";
			if($sermonid == $row[0]) 
				{
				echo " selected";
				$title = $thistitle;
				$sermondate = $thissermondate;
				}
			echo ">$thispub $thistitle ($thissermondate)</option>\n";
			}
		} /* end while looping through sermons */
	echo "</select><input type=submit value=\"Select\">\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"title");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<tr>\n";
		echo "<th style=\"text-align: right;\">Sermon Title:</th>\n";
		echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>";
		if($thisauth > 1) 
			echo "<input type=text size=50 value=\"$title\" name=title></td>\n";
		else 
			echo "$title</td>\n";
		echo "</tr>\n";
		} /* end if authorized to at least view the sermon title */
		
	
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"synopsis");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<tr>\n";
		echo "<th style=\"text-align: right;\" valign=top>Synopsis:</th>\n";
		echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3 valign=top>";
		if($thisauth > 1) 
			{
			/* this uses the OpenSource FCKeditor which is included in the ls_include folder */
			$synopsisEditor = new FCKeditor('synopsis1') ;
			$synopsisEditor->BasePath = './ls_include/editor/';
			$synopsisEditor->Value = $synopsis;
			$synopsisEditor->ToolbarSet = 'LS';
			$synopsisEditor->Height = '200';
			$synopsisEditor->Width = '400';
			$synopsisEditor->Create() ;
			}
		else 
			echo "$synopsis";
		echo "\n</td></tr>\n";
		} /* end if authorized to at least view the synopsis */
		
	echo "<tr>\n";

	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"pastor");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<th style=\"text-align: right;\" valign=top>Pastor:</th>\n";
		echo "<td style=\"text-align: left;border-width: 0px;\" valign=top>";
		if($thisauth > 1) 
			{
			echo "<select name=pastor size=1>\n";
			
			$query = "SELECT id,fullname FROM ls_pastors WHERE id>0 ORDER BY fullname ASC";
			$result = sql_getresult($query);
			while($row=sql_getrow($result))
				{
				echo "<option value=$row[0]";
				if($pastor == $row[0]) 
					{
					echo " selected";
					}
				echo ">".stripslashes($row[1])."</option>\n";
				} /* end while looping through pastors */
			echo "</select>\n";
			}
		else 
			{
			if($pastor > 0)
				{
				$query = "SELECT fullname,bio FROM ls_pastors WHERE id=$pastor";
				$result = sql_getresult($query);
				$row = sql_getrow($result);
				$pastorname = stripslashes($row[0]);
				$pastorbio = stripslashes($row[1]);
				if(strlen($pastorbio) > 0) echo "<a href=$pastorbio>";
				echo $pastorname;
				if(strlen($pastorbio) > 0) echo "</a>";
				}
			}
		echo "</td>\n";
		} /* end if authorized to at least view the pastor */
	else echo "<td colspan=2></td>\n";
	echo "</tr>\n";

	echo "<tr>\n";
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"sermondate");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<th style=\"text-align: right;\" valign=bottom>Sermon Date:</th>\n";
		echo "<td style=\"text-align: left;border-width: 0px;\" valign=bottom>";
		if($thisauth > 1) 
			{
			echo "<input  class=\"date-picker\" type=text id=sermondate name=sermondate ".
				"value='$sermondate'>\n";
			}
		else 
			{
			echo $sermondate;
			}
		echo "</td>\n";
		} /* end if authorized to at least view the date */
	else echo "<td colspan=2></td>\n";

	echo "</tr>\n";

	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"series");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<tr>\n";
		echo "<th style=\"text-align: left;\" valign=top colspan=4>Sermon Series:</th>\n";
		echo "</tr>\n";
		if($thisauth > 1) 
			{
			$query = "SELECT id,series FROM ls_sermon_series WHERE id>0 ORDER BY series ASC";
			$result = sql_getresult($query);
			while($row = sql_getrow($result))
				{
				echo "<tr><td style=\"border-width: 0px;text-align: right;\" >".
					" <input type=radio name=series value='$row[0]'";
				if($series == $row[0]) 
					echo " checked";
				echo "></td>\n";
				echo "<td colspan=3 style=\"border-width: 0px;text-align: left;".
					"\">".stripslashes($row[1])."</td></tr>\n";
				} /* end while looping through topics */
			echo "<tr><td style=\"border-width: 0px;text-align: right;\" >".
				" <input type=radio name=series value='0'";
			if($series < 1) 
				echo " checked";
			echo "></td>\n";
			echo "<td colspan=3 style=\"border-width: 0px;text-align: left;".
				"\">".stripslashes($row[1])."New Series: ";
			echo "<input type=text size=30 name=newseries></td></tr>\n";
			} /* if have auth to edit series */
		elseif($series > 0) 
			{
			$query = "SELECT series FROM ls_sermon_series WHERE id='$series'";
			$result = sql_getresult($query);
			$row = sql_getrow($result);
			echo "<tr><td></td>\n";
			echo "<td colspan=3 style=\"border-width: 0px;text-align: left;".
					"\">".stripslashes($row[0])."</td></tr>\n";
			} /* don't have auth to edit series */
		} /* end if authorized to at least view the series */
		
	/* we'll assume that if they can update the synopsis, they can update the topics */
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"synopsis");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<tr>\n";
		echo "<th style=\"text-align: left;\" valign=top colspan=4>Topics:</th></tr>\n";
		if($thisauth > 1) 
			{
			$query = "SELECT id,topic FROM ls_sermon_topics WHERE id>0 ORDER BY topic ASC";
			$result = sql_getresult($query);
			$last = "";
			while($row = sql_getrow($result))
				{
				if($row[1] != $last)
					{
					$last = $row[1];
					echo "<tr><td style=\"border-width: 0px;text-align: right;\" >".
						" <input type=checkbox name=topic[] value='$last'";
					if(sql_isrecord("SELECT id FROM ls_sermon_topics ".
						"WHERE sermonid='$sermonid' AND topic='$last'")) 
						echo " checked";
					echo "></td>\n";
					echo "<td colspan=3 style=\"border-width: 0px;text-align: left;".
						"\">".stripslashes($row[1])."</td></tr>\n";
					}
				} /* end while looping through topics */
			echo "<tr><td style=\"border-width: 0px;text-align: right;\">New Topic:</td>\n";
			echo "<td colspan=3 style=\"border-width: 0px;text-align: left;\">".
				"<input type=text size=30 name=newtopic></td></tr>\n";
			} /* if have auth to edit topics */
		else 
			{
			$query = "SELECT topic FROM ls_sermon_topics WHERE sermonid='$sermonid' ".
					"ORDER BY topic ASC";
			$result = sql_getresult($query);
			while($row = sql_getrow($result))
				{
				echo "<tr><td></td><td colspan=3 style=\"border-width: 0px;text-align: left;".
					"\">".stripslashes($row[1])."</td></tr>\n";
				} /* end while looping through topics */
			} /* don't have auth to edit topics */
		} /* end if authorized to at least view the topics */
		
	/* we'll assume that if they can update the synopsis, they can update the sermon texts */
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"synopsis");
	if((($thisauth > 0) AND ($sermonid > 0)) OR ($sermonid < 0))
		{		
		echo "<tr>\n";
		echo "<th style=\"text-align: left;\" valign=top colspan=4>Sermon Texts:</th></tr>\n";
		if($thisauth > 1) 
			{
			$query = "SELECT id,scripturetext FROM ls_sermon_texts ".
				"WHERE sermonid='$sermonid' ORDER BY id ASC";
			$result = sql_getresult($query);
			while($row = sql_getrow($result))
				{
				echo "<tr><td style=\"border-width: 0px;text-align: right;\" ></td>\n";
				echo "<td colspan=3 style=\"border-width: 0px;text-align: left;\">".
					"<input type=hidden name=textid[] value=$row[0]>".
					"<input type=text size=30 name=sermontext[] value=\"".
					stripslashes($row[1])."\"></td></tr>\n";
				} /* end while looping through texts */
			echo "<tr><td style=\"border-width: 0px;text-align: right;\">New Text:</td>\n";
			echo "<td colspan=3 style=\"border-width: 0px;text-align: left;\">".
				"<input type=text size=30 name=newtext></td></tr>\n";
			} /* if have auth to edit sermon texts */
		else 
			{
			$query = "SELECT scripturetext FROM ls_sermon_texts WHERE sermonid='$sermonid' ".
					"ORDER BY id ASC";
			$result = sql_getresult($query);
			while($row = sql_getrow($result))
				{
				echo "<tr><td></td><td colspan=3 style=\"border-width: 0px;text-align: left;".
					"\">".stripslashes($row[1])."</td></tr>\n";
				} /* end while looping through texts */
			} /* don't have auth to edit sermon texts */
		} /* end if authorized to at least view the sermon texts */
		
	/* we'll assume that if they can update the synopsis, they can upload and link files */
	/* don't show when adding a new sermon */
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"synopsis");
	if(($thisauth > 0) AND ($sermonid > 0))
		{
		if($thisauth > 1) 
			{
			echo "<tr id=associatedfiles>\n";
			echo "<th style=\"text-align: left;\" valign=top colspan=4>Associated Files:</th></tr>\n";
			$query = "SELECT id,uploadtype,uploadurl FROM ls_sermon_files WHERE sermonid='$sermonid'";
			$result = sql_getresult($query);
			while($row = sql_getrow($result))
				{
				$thisid = $row[0];
				$thistype = stripslashes($row[1]);
				$thisurl = stripslashes($row[2]);
				echo "<input type=hidden name=afileid[] value=$thisid>\n";
				echo "<tr><th style=\"border-width: 0px;text-align: right;\">";
				echo "<select name=afiletype[] size=1>\n";
				echo "<option value='Text/PDF'";
				if($thistype == "Text/PDF") echo " selected";
				echo ">Text/PDF</option>\n";
				echo "<option value=Picture";
				if($thistype == "Picture") echo " selected";
				echo ">Picture</option>\n";
				echo "<option value=Presentation";
				if($thistype == "Presentation") echo " selected";
				echo ">Presentation</option>\n";
				echo "<option value=Audio";
				if($thistype == "Audio") echo " selected";
				echo ">Audio</option>\n";
				echo "<option value=Video";
				if($thistype == "Video") echo " selected";
				echo ">Video</option>\n";
				echo "</select>\n";
				echo "</th>\n";
				echo "<td style=\"border-width: 0px;text-align: left;\" colspan=2>".
					"<input type=text size=50 name=afileurl[] value=$thisurl></td>\n";
				echo "<td style=\"border-width: 0px;text-align: left;\">".
					"<input type=checkbox name=disassociate[] value=$thisid>".
					"Dis-associate</td></tr>\n";
				}
			echo "<tr><td style=\"border-width: 0px;text-align: right;\" >".
				" <input id=\"selectcheck\" type=checkbox></td>\n";
			echo "<td colspan=3 style=\"border-width: 0px;text-align: left;".
				"\">Select File From Server</td></tr>\n";

			echo "<tr><td style=\"border-width: 0px;text-align: right;\" >".
				" <input id=\"uploadcheck\" type=checkbox></td>\n";
			echo "<td colspan=3 style=\"border-width: 0px;text-align: left;".
				"\">Upload File From PC</td></tr>\n";

			echo "<tr>\n";
			echo "<td id=fileselector colspan=5 ".
				"style=\"display: none; text-align: left;\" valign=top>\n";
			echo "<select name=selectedfiletype size=1>\n";
			echo "<option value='Text/PDF'>Text/PDF</option>\n";
			echo "<option value=Picture>Picture</option>\n";
			echo "<option value=Presentation>Presentation</option>\n";
			echo "<option value=Audio>Audio</option>\n";
			echo "<option value=Video>Video</option>\n";
			echo "</select>\n";
			echo "<input type=text size=50 name=selectedfile id=selectedfile><br />\n";
			echo "<ul class=\"tv\">\n";
			$filecounter = 0;
			
			function get_dir_contents($directory,$url,$filecounter)
				{
				if($filecounter != 0) echo "\n<ul>\n";
				$d = dir($directory);

				$filectr = 0;
				$typectr = 0;

				$filecounter = $filecounter+1;
			
				while($entry = $d->read())
					{
					if(substr($entry,0,1) == ".") continue;
									
					$file_isdir = (is_dir($d->path.'/'.$entry)) AND 
							(substr($entry,0,1) != ".");
					if($file_isdir)
						{
						echo "<li>".$entry;
						get_dir_contents($d->path.'/'.$entry,$url."/".$entry,
									$filecounter);
						echo "</li>\n";
						}
					else
						{
						$filenm[$filectr] = $entry;
						$thistype = strrchr($entry,".");
						$filetyp[$filectr] = $thistype;
	
						$newtype = 1;
						for($i = 0;$i < $typectr;$i++)
							if($thistype == $types[$i]) $newtype = 0;
	
						if($newtype > 0)
							$types[$typectr++] = $thistype;

						$fileurl[$filectr] = $url."/".rawurlencode($entry);

						$query = "SELECT id FROM ls_sermon_files WHERE ".
								"uploadurl = '".
								addslashes($fileurl[$filectr]).
								"'";
						if(sql_isrecord($query))
							$fileused[$filectr] = 1;
						else
							$fileused[$filectr] = 0;

						$filectr = $filectr+1;
						} /* end if not directory - build file list */
					} /* end while looping through files in the directory */

				if($filectr < 1) echo " (directory is empty)";

				if($types) sort($types);

				/* first list those that aren't yet associated */
				for($i=0;$i<$typectr;$i++)
					{
					for($j=0;$j<$filectr;$j++)
						{
						if(($fileused[$j] < 1) AND ($filetyp[$j] == $types[$i]))
							echo "<li><a href=\"#associatedfiles\" ".
								"onclick='document.forms[\"sermonForm\"]".
								"[\"selectedfile\"].value=\"".$fileurl[$j].
								"\"' style=\"color: black;\">".$filenm[$j].
								" (unused)</a></li>\n";
						} /* end while looping through files */
					} /* end while looping through file types */
			
				/* now list those that are yet associated */
				for($i=0;$i<$typectr;$i++)
					{
					for($j=0;$j<$filectr;$j++)
						{
						if(($fileused[$j] > 0) AND ($filetyp[$j] == $types[$i]))
							echo "<li><a href=\"#associatedfiles\" ".
								"onclick='document.forms[\"sermonForm\"]".
								"[\"selectedfile\"].value=\"".$fileurl[$j].
								"\"' style=\"color: black;\">".$filenm[$j].
								" (used)</a></li>\n";
						} /* end while looping through files */
					} /* end while looping through file types */

				echo "</ul>\n";
				return $filecounter;
				} /* end function get_dir_contents */
			
			/* find all the root directories on this server */
			$uploadpath = $_SERVER['DOCUMENT_ROOT']."/".$UPLOAD_DIR;
			$rp = realpath($uploadpath);
			if(strlen($rp) < 1)
				{
				/* directory must not exist */
				$uploadpath = realpath($_SERVER['DOCUMENT_ROOT'])."/".$UPLOAD_DIR;
				mkdir($uploadpath,0777);
				$rp = realpath($uploadpath);
				}
			$thisurl = "http://" . $_SERVER['SERVER_NAME']."/".$UPLOAD_DIR;
			
			$filecounter = get_dir_contents($rp,$thisurl,$filecounter);


			echo "</td>\n";
			echo "</tr>\n";


			echo "<tr>\n";
			echo "<td  id=browseselector colspan=5 ".
				"style=\"display: none; text-align: left;\" valign=top>\n";
			echo "<select name=uploadfiletype size=1>\n";
			echo "<option value='Text/PDF'>Text/PDF</option>\n";
			echo "<option value=Picture>Picture</option>\n";
			echo "<option value=Presentation>Presentation</option>\n";
			echo "<option value=Audio>Audio</option>\n";
			echo "<option value=Video>Video</option>\n";
			echo "</select>\n";
			echo "<input type=\"file\" id=\"userfile\" name=\"userfile\"><br />\n".
				"If the file doesn't get added to the list of associated files ".
				"then the upload failed, possibly because of security settings on the ".
				"server.  You likely will need to use FTP to upload the file and then ".
				"select the file from the server.</td>\n";
			echo "</tr>\n";
			} /* if have auth to edit file links */
		else 
			{
			$query = "SELECT id,uploadtype,uploadurl FROM ls_sermon_files WHERE sermonid='$sermonid'";
			$result = sql_getresult($query);
			while($row = sql_getrow($result))
				{
				$thisid = $row[0];
				$thistype = stripslashes($row[1]);
				$thisurl = stripslashes($row[2]);
				echo "<tr><th style=\"border-width: 0px;text-align: right;\">$thistype :</th>\n";
				echo "<td style=\"border-width: 0px;text-align: left;\" colspan=3>$thisurl".
					"</td></tr>\n";
				}
			} /* don't have auth to edit file links */
		} /* end if authorized to at least view the sermon files */
		
	echo "<tr><td colspan=2 style=\"border-width: 0px;text-align: center;\">";
	if($sermonid < 0)
		echo "<input type=submit name=update value=\"Add\">";
	if($sermonid > 0)
		echo "<input type=submit name=update value=\"Update\">";

	echo "</td>\n<td colspan=2 style=\"border-width: 0px;text-align: center;\">";
	/* see if they can "publish" or not */
	$thisauth = get_field_auth($thisuser,$objecttype,$sermonid,"published");
	if(($thisauth > 1) AND ($sermonid > 0))
		{
		if($published < 1)
			echo "<input type=submit name=publish value=\"Publish\">";
		else
			echo "<input type=submit name=publish value=\"Un-Publish\">";
		}		
	echo "</td>\n</tr>\n";
	} /* end if sermonid > 0 */
?>
</table>

</form>
<?php
/**********************************************************************/
/* If this user has admin level for this user...                      */
/* then this is where we define access rights for other users         */
/**********************************************************************/
if(((check_auth($thisuser,$objecttype,$sermonid,$LS_ADMIN_THRESHOLD)) AND ($sermonid > 0)) OR
	(($sermonid == 0) AND (check_function_auth($thisuser,$objecttype,"Set Levels",1))))
	{
	echo "<p style=\"background-color: lightblue;\"><b>Manage Access by Users to $title's Data</b></p>\n";

	echo "<p style=\"color: red;\"><b>Note: Any given user's access is defined by a combination of factors. ".
		"If you change their access, but their access doesn't appear to change, it's because that user ".
		"has a higher level of access:\n<ul style=\"color: red;\">\n".
		"<li>either as part of a group (which you can also control) or</li>".
		"\n<li>as their default level of access for all users (which is ".
		"only controllable by the system administrator).</li>\n</ul>\n</b></p>\n";
	
	/* list the levels for the user's reference */
	echo "<p><b>Security Level Definitions:</b></p>\n";
	echo "<table style=\"border-width: 0px;\">\n";
	echo "<tr><th></th><th>Read-only</th><th>Read+Write</th><th>Allowed To:</th></tr>\n";
	$query = "SELECT id,auth_name,auth_level FROM ls_security_levels WHERE object_type='$objecttype' ".
			"ORDER BY auth_level ASC";
	$result = sql_getresult($query);
	$i = 0;
	while($row = sql_getrow($result))
		{
		/* store values for future reference */
		$levels[$i] = $row[0];
		$levelsname[$i] = stripslashes($row[1]);
		$i = $i+1;

		echo "<tr><th style=\"border: solid black 1px;\">".stripslashes($row[1])." ($row[2])</th>\n";
		echo "<td style=\"border: solid black 1px;padding: 5px;\">";
		$q2 = "SELECT fieldname FROM ls_security_fields WHERE level='$row[0]' ".
			"AND readauth='1' AND writeauth='0' ORDER BY fieldname ASC";
		$r2 = sql_getresult($q2);
		while($ro2 = sql_getrow($r2))
			echo stripslashes($ro2[0])."<br />";
		echo "</td>\n<td style=\"border: solid black 1px;padding: 5px;\">";
		$q2 = "SELECT fieldname FROM ls_security_fields WHERE level='$row[0]' ".
			"AND writeauth='1' ORDER BY fieldname ASC";
		$r2 = sql_getresult($q2);
		while($ro2 = sql_getrow($r2))
			echo stripslashes($ro2[0])."<br />";
		echo "</td>\n";
		echo "<td style=\"border: solid black 1px;padding: 5px;\">";
		$q2 = "SELECT ls_security_functions.lsfunction FROM ls_security_function_levels,".
			"ls_security_functions WHERE ls_security_function_levels.level='$row[0]' ".
			"AND ls_security_functions.id = ls_security_function_levels.lsfunction ".
			"ORDER BY ls_security_functions.lsfunction ASC";
		$r2 = sql_getresult($q2);
		while($ro2 = sql_getrow($r2))
			echo stripslashes($ro2[0])."<br />";
		echo "</td></tr>\n";
		} /* end while looping through levels */
	echo "</table>\n";
	
	/* now, list users and their access */

	echo "<form method=POST action=\"$thisscript\">\n";
	if($sermonid > 0) echo "<input type=hidden name=sermonid value=$sermonid>\n";

	/* start with groups */

	echo "<p><b>Each Group's Access to $title's Data:</b></p>\n";
	echo "<table style=\"border-width: 0px;\">\n";
	$query = "SELECT ls_users.id,FirstName,LastName FROM ls_users,ls_people ".
		"WHERE ls_users.IsGroup > '0' AND ls_people.id=ls_users.PeopleId ORDER BY LastName ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		if(check_auth($thisuser,$objecttype,$row[0],$LS_USER_THRESHOLD))
			{
			$thisuserseclevel = get_level($row[0],$objecttype,$sermonid);

			echo "<tr><td style=\"border-width: 0px;\">";
			echo stripslashes($row[1])." ".stripslashes($row[2]).
				"<input type=hidden name=secuserid[] value=$row[0]></td>\n";
			echo "<td><select name=secuserlevel[] size=1>\n";
			for($i = 0;$i < count($levels);$i++)
				{
				echo "<option value=$levels[$i]";
				if($thisuserseclevel == $levels[$i]) echo " selected";
				echo ">$levelsname[$i]</option>\n";
				} /* end while looping through security levels */
			echo "</select></td></tr>\n";
			} /* end if have at least user access to this user */
		} /* end while looping through all groups */
	echo "</table>\n";

	/* now handle individual users */

	echo "<p><b>Each User's Access to $title's Data:</b></p>\n";
	echo "<table style=\"border-width: 0px;\">\n";
	$query = "SELECT ls_users.id,FirstName,LastName FROM ls_users,ls_people ".
		"WHERE ls_users.IsGroup = '0' AND ls_people.id=ls_users.PeopleId ORDER BY LastName ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		if(check_auth($thisuser,$objecttype,$row[0],$LS_USER_THRESHOLD))
			{
			$thisuserseclevel = get_level($row[0],$objecttype,$sermonid);

			echo "<tr><td style=\"border-width: 0px;\">";
			echo stripslashes($row[1])." ".stripslashes($row[2]).
				"<input type=hidden name=secuserid[] value=$row[0]></td>\n";
			echo "<td><select name=secuserlevel[] size=1>\n";
			for($i = 0;$i < count($levels);$i++)
				{
				echo "<option value=$levels[$i]";
				if($thisuserseclevel == $levels[$i]) echo " selected";
				echo ">$levelsname[$i]</option>\n";
				} /* end while looping through security levels */
			echo "</select></td></tr>\n";
			} /* end if have at least user access to this user */
		} /* end while looping through all users */
	echo "</table>\n";

	/* Add the submit button */
	echo "<table border=0 style=\"border-width: 0px;\">\n";
	echo "<tr><td style=\"border-width: 0px;\">".
		"<input type=submit name=updateaccess value=\"Update User Access\"></td></tr>\n";
	echo "</table>\n";
	echo "</form>\n";
	} /* end if admin level access for this sermon - set access */
?>
</div> <!-- Box331 -->
</div> <!-- Box33 -->

</div> <!-- Box3 -->

<a href="http://www.lstones.com/"><img border=0 src="http://www.lstones.com/LS-sm.gif"></a>
</body>
</html>
